@@ -9,12 +9,6 @@ var annotated_dup =
         [ "RayResultCallback", "struct_ogre_1_1_bullet_1_1_ray_result_callback.html", "struct_ogre_1_1_bullet_1_1_ray_result_callback" ],
         [ "RigidBodyState", "class_ogre_1_1_bullet_1_1_rigid_body_state.html", "class_ogre_1_1_bullet_1_1_rigid_body_state" ]
       ] ],
-      [ "GLSL", "namespace_ogre_1_1_g_l_s_l.html", [
-        [ "GLSLLinkProgram", "class_ogre_1_1_g_l_s_l_1_1_g_l_s_l_link_program.html", "class_ogre_1_1_g_l_s_l_1_1_g_l_s_l_link_program" ],
-        [ "GLSLLinkProgramManager", "class_ogre_1_1_g_l_s_l_1_1_g_l_s_l_link_program_manager.html", "class_ogre_1_1_g_l_s_l_1_1_g_l_s_l_link_program_manager" ],
-        [ "GLSLProgram", "class_ogre_1_1_g_l_s_l_1_1_g_l_s_l_program.html", "class_ogre_1_1_g_l_s_l_1_1_g_l_s_l_program" ],
-        [ "GLSLProgramFactory", "class_ogre_1_1_g_l_s_l_1_1_g_l_s_l_program_factory.html", "class_ogre_1_1_g_l_s_l_1_1_g_l_s_l_program_factory" ]
-      ] ],
       [ "RTShader", "namespace_ogre_1_1_r_t_shader.html", [
         [ "AssignmentAtom", "class_ogre_1_1_r_t_shader_1_1_assignment_atom.html", "class_ogre_1_1_r_t_shader_1_1_assignment_atom" ],
         [ "At", "struct_ogre_1_1_r_t_shader_1_1_at.html", "struct_ogre_1_1_r_t_shader_1_1_at" ],
@@ -150,7 +144,6 @@ var annotated_dup =
       [ "CompositorInstance", "class_ogre_1_1_compositor_instance.html", "class_ogre_1_1_compositor_instance" ],
       [ "CompositorLogic", "class_ogre_1_1_compositor_logic.html", "class_ogre_1_1_compositor_logic" ],
       [ "CompositorManager", "class_ogre_1_1_compositor_manager.html", "class_ogre_1_1_compositor_manager" ],
-      [ "ComPtr", "class_ogre_1_1_com_ptr.html", "class_ogre_1_1_com_ptr" ],
       [ "ConcreteNode", "struct_ogre_1_1_concrete_node.html", "struct_ogre_1_1_concrete_node" ],
       [ "ConfigDialog", "class_ogre_1_1_config_dialog.html", "class_ogre_1_1_config_dialog" ],
       [ "ConfigFile", "class_ogre_1_1_config_file.html", "class_ogre_1_1_config_file" ],
@@ -162,8 +155,6 @@ var annotated_dup =
       [ "ControllerManager", "class_ogre_1_1_controller_manager.html", "class_ogre_1_1_controller_manager" ],
       [ "ControllerValue", "class_ogre_1_1_controller_value.html", "class_ogre_1_1_controller_value" ],
       [ "ConvexBody", "class_ogre_1_1_convex_body.html", "class_ogre_1_1_convex_body" ],
-      [ "CPreprocessor", "class_ogre_1_1_c_preprocessor.html", "class_ogre_1_1_c_preprocessor" ],
-      [ "CreateCallbackWrapper", "struct_ogre_1_1_create_callback_wrapper.html", "struct_ogre_1_1_create_callback_wrapper" ],
       [ "CreateCompositorScriptCompilerEvent", "class_ogre_1_1_create_compositor_script_compiler_event.html", "class_ogre_1_1_create_compositor_script_compiler_event" ],
       [ "CreateGpuProgramScriptCompilerEvent", "class_ogre_1_1_create_gpu_program_script_compiler_event.html", "class_ogre_1_1_create_gpu_program_script_compiler_event" ],
       [ "CreateGpuSharedParametersScriptCompilerEvent", "class_ogre_1_1_create_gpu_shared_parameters_script_compiler_event.html", "class_ogre_1_1_create_gpu_shared_parameters_script_compiler_event" ],
@@ -171,68 +162,9 @@ var annotated_dup =
       [ "CreateParticleSystemScriptCompilerEvent", "class_ogre_1_1_create_particle_system_script_compiler_event.html", "class_ogre_1_1_create_particle_system_script_compiler_event" ],
       [ "CustomCompositionPass", "class_ogre_1_1_custom_composition_pass.html", "class_ogre_1_1_custom_composition_pass" ],
       [ "CylinderEmitter", "class_ogre_1_1_cylinder_emitter.html", "class_ogre_1_1_cylinder_emitter" ],
-      [ "D3D11DepthBuffer", "class_ogre_1_1_d3_d11_depth_buffer.html", "class_ogre_1_1_d3_d11_depth_buffer" ],
-      [ "D3D11Device", "class_ogre_1_1_d3_d11_device.html", "class_ogre_1_1_d3_d11_device" ],
-      [ "D3D11DeviceResource", "class_ogre_1_1_d3_d11_device_resource.html", "class_ogre_1_1_d3_d11_device_resource" ],
-      [ "D3D11DeviceResourceManager", "class_ogre_1_1_d3_d11_device_resource_manager.html", "class_ogre_1_1_d3_d11_device_resource_manager" ],
-      [ "D3D11Driver", "class_ogre_1_1_d3_d11_driver.html", "class_ogre_1_1_d3_d11_driver" ],
-      [ "D3D11DriverList", "class_ogre_1_1_d3_d11_driver_list.html", "class_ogre_1_1_d3_d11_driver_list" ],
-      [ "D3D11HardwareBuffer", "class_ogre_1_1_d3_d11_hardware_buffer.html", "class_ogre_1_1_d3_d11_hardware_buffer" ],
-      [ "D3D11HardwareBufferManager", "class_ogre_1_1_d3_d11_hardware_buffer_manager.html", "class_ogre_1_1_d3_d11_hardware_buffer_manager" ],
-      [ "D3D11HardwareOcclusionQuery", "class_ogre_1_1_d3_d11_hardware_occlusion_query.html", "class_ogre_1_1_d3_d11_hardware_occlusion_query" ],
-      [ "D3D11HardwarePixelBuffer", "class_ogre_1_1_d3_d11_hardware_pixel_buffer.html", "class_ogre_1_1_d3_d11_hardware_pixel_buffer" ],
-      [ "D3D11HLSLProgram", "class_ogre_1_1_d3_d11_h_l_s_l_program.html", "class_ogre_1_1_d3_d11_h_l_s_l_program" ],
-      [ "D3D11HLSLProgramFactory", "class_ogre_1_1_d3_d11_h_l_s_l_program_factory.html", "class_ogre_1_1_d3_d11_h_l_s_l_program_factory" ],
-      [ "D3D11Mappings", "class_ogre_1_1_d3_d11_mappings.html", "class_ogre_1_1_d3_d11_mappings" ],
-      [ "D3D11MultiRenderTarget", "class_ogre_1_1_d3_d11_multi_render_target.html", "class_ogre_1_1_d3_d11_multi_render_target" ],
-      [ "D3D11Plugin", "class_ogre_1_1_d3_d11_plugin.html", "class_ogre_1_1_d3_d11_plugin" ],
-      [ "D3D11RenderingAPIException", "class_ogre_1_1_d3_d11_rendering_a_p_i_exception.html", "class_ogre_1_1_d3_d11_rendering_a_p_i_exception" ],
       [ "D3D11RenderSystem", "class_ogre_1_1_d3_d11_render_system.html", "class_ogre_1_1_d3_d11_render_system" ],
-      [ "D3D11RenderTarget", "class_ogre_1_1_d3_d11_render_target.html", "class_ogre_1_1_d3_d11_render_target" ],
-      [ "D3D11RenderTexture", "class_ogre_1_1_d3_d11_render_texture.html", "class_ogre_1_1_d3_d11_render_texture" ],
-      [ "D3D11RenderToVertexBuffer", "class_ogre_1_1_d3_d11_render_to_vertex_buffer.html", "class_ogre_1_1_d3_d11_render_to_vertex_buffer" ],
-      [ "D3D11RenderWindowBase", "class_ogre_1_1_d3_d11_render_window_base.html", "class_ogre_1_1_d3_d11_render_window_base" ],
-      [ "D3D11RenderWindowSwapChainBased", "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html", "class_ogre_1_1_d3_d11_render_window_swap_chain_based" ],
-      [ "D3D11Sampler", "class_ogre_1_1_d3_d11_sampler.html", "class_ogre_1_1_d3_d11_sampler" ],
-      [ "D3D11StereoDriverAMD", "class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html", "class_ogre_1_1_d3_d11_stereo_driver_a_m_d" ],
-      [ "D3D11StereoDriverBridge", "class_ogre_1_1_d3_d11_stereo_driver_bridge.html", "class_ogre_1_1_d3_d11_stereo_driver_bridge" ],
-      [ "D3D11StereoDriverImpl", "class_ogre_1_1_d3_d11_stereo_driver_impl.html", "class_ogre_1_1_d3_d11_stereo_driver_impl" ],
-      [ "D3D11StereoDriverNVIDIA", "class_ogre_1_1_d3_d11_stereo_driver_n_v_i_d_i_a.html", "class_ogre_1_1_d3_d11_stereo_driver_n_v_i_d_i_a" ],
-      [ "D3D11Texture", "class_ogre_1_1_d3_d11_texture.html", "class_ogre_1_1_d3_d11_texture" ],
-      [ "D3D11TextureManager", "class_ogre_1_1_d3_d11_texture_manager.html", "class_ogre_1_1_d3_d11_texture_manager" ],
-      [ "D3D11VertexDeclaration", "class_ogre_1_1_d3_d11_vertex_declaration.html", "class_ogre_1_1_d3_d11_vertex_declaration" ],
-      [ "D3D11VideoMode", "class_ogre_1_1_d3_d11_video_mode.html", "class_ogre_1_1_d3_d11_video_mode" ],
-      [ "D3D11VideoModeList", "class_ogre_1_1_d3_d11_video_mode_list.html", "class_ogre_1_1_d3_d11_video_mode_list" ],
-      [ "D3D9DepthBuffer", "class_ogre_1_1_d3_d9_depth_buffer.html", "class_ogre_1_1_d3_d9_depth_buffer" ],
-      [ "D3D9Device", "class_ogre_1_1_d3_d9_device.html", "class_ogre_1_1_d3_d9_device" ],
-      [ "D3D9DeviceManager", "class_ogre_1_1_d3_d9_device_manager.html", "class_ogre_1_1_d3_d9_device_manager" ],
-      [ "D3D9Driver", "class_ogre_1_1_d3_d9_driver.html", "class_ogre_1_1_d3_d9_driver" ],
-      [ "D3D9DriverList", "class_ogre_1_1_d3_d9_driver_list.html", "class_ogre_1_1_d3_d9_driver_list" ],
-      [ "D3D9GpuProgram", "class_ogre_1_1_d3_d9_gpu_program.html", "class_ogre_1_1_d3_d9_gpu_program" ],
-      [ "D3D9GpuProgramManager", "class_ogre_1_1_d3_d9_gpu_program_manager.html", "class_ogre_1_1_d3_d9_gpu_program_manager" ],
-      [ "D3D9HardwareBuffer", "class_ogre_1_1_d3_d9_hardware_buffer.html", "class_ogre_1_1_d3_d9_hardware_buffer" ],
-      [ "D3D9HardwareBufferManager", "class_ogre_1_1_d3_d9_hardware_buffer_manager.html", "class_ogre_1_1_d3_d9_hardware_buffer_manager" ],
-      [ "D3D9HardwareOcclusionQuery", "class_ogre_1_1_d3_d9_hardware_occlusion_query.html", "class_ogre_1_1_d3_d9_hardware_occlusion_query" ],
-      [ "D3D9HardwarePixelBuffer", "class_ogre_1_1_d3_d9_hardware_pixel_buffer.html", "class_ogre_1_1_d3_d9_hardware_pixel_buffer" ],
-      [ "D3D9HLSLProgram", "class_ogre_1_1_d3_d9_h_l_s_l_program.html", "class_ogre_1_1_d3_d9_h_l_s_l_program" ],
-      [ "D3D9HLSLProgramFactory", "class_ogre_1_1_d3_d9_h_l_s_l_program_factory.html", "class_ogre_1_1_d3_d9_h_l_s_l_program_factory" ],
-      [ "D3D9Mappings", "class_ogre_1_1_d3_d9_mappings.html", "class_ogre_1_1_d3_d9_mappings" ],
-      [ "D3D9MultiRenderTarget", "class_ogre_1_1_d3_d9_multi_render_target.html", "class_ogre_1_1_d3_d9_multi_render_target" ],
-      [ "D3D9Plugin", "class_ogre_1_1_d3_d9_plugin.html", "class_ogre_1_1_d3_d9_plugin" ],
       [ "D3D9RenderSystem", "class_ogre_1_1_d3_d9_render_system.html", "class_ogre_1_1_d3_d9_render_system" ],
-      [ "D3D9RenderTexture", "class_ogre_1_1_d3_d9_render_texture.html", "class_ogre_1_1_d3_d9_render_texture" ],
-      [ "D3D9RenderWindow", "class_ogre_1_1_d3_d9_render_window.html", "class_ogre_1_1_d3_d9_render_window" ],
-      [ "D3D9Resource", "class_ogre_1_1_d3_d9_resource.html", "class_ogre_1_1_d3_d9_resource" ],
       [ "D3D9ResourceManager", "class_ogre_1_1_d3_d9_resource_manager.html", "class_ogre_1_1_d3_d9_resource_manager" ],
-      [ "D3D9StereoDriverAMD", "class_ogre_1_1_d3_d9_stereo_driver_a_m_d.html", "class_ogre_1_1_d3_d9_stereo_driver_a_m_d" ],
-      [ "D3D9StereoDriverBridge", "class_ogre_1_1_d3_d9_stereo_driver_bridge.html", "class_ogre_1_1_d3_d9_stereo_driver_bridge" ],
-      [ "D3D9StereoDriverImpl", "class_ogre_1_1_d3_d9_stereo_driver_impl.html", "class_ogre_1_1_d3_d9_stereo_driver_impl" ],
-      [ "D3D9StereoDriverNVIDIA", "class_ogre_1_1_d3_d9_stereo_driver_n_v_i_d_i_a.html", "class_ogre_1_1_d3_d9_stereo_driver_n_v_i_d_i_a" ],
-      [ "D3D9Texture", "class_ogre_1_1_d3_d9_texture.html", "class_ogre_1_1_d3_d9_texture" ],
-      [ "D3D9TextureManager", "class_ogre_1_1_d3_d9_texture_manager.html", "class_ogre_1_1_d3_d9_texture_manager" ],
-      [ "D3D9VertexDeclaration", "class_ogre_1_1_d3_d9_vertex_declaration.html", "class_ogre_1_1_d3_d9_vertex_declaration" ],
-      [ "D3D9VideoMode", "class_ogre_1_1_d3_d9_video_mode.html", "class_ogre_1_1_d3_d9_video_mode" ],
-      [ "D3D9VideoModeList", "class_ogre_1_1_d3_d9_video_mode_list.html", "class_ogre_1_1_d3_d9_video_mode_list" ],
       [ "DataStream", "class_ogre_1_1_data_stream.html", "class_ogre_1_1_data_stream" ],
       [ "DebugDrawer", "class_ogre_1_1_debug_drawer.html", "class_ogre_1_1_debug_drawer" ],
       [ "DefaultAxisAlignedBoxSceneQuery", "class_ogre_1_1_default_axis_aligned_box_scene_query.html", "class_ogre_1_1_default_axis_aligned_box_scene_query" ],
@@ -293,102 +225,12 @@ var annotated_dup =
       [ "FrameTimeControllerValue", "class_ogre_1_1_frame_time_controller_value.html", "class_ogre_1_1_frame_time_controller_value" ],
       [ "FreeImageCodec", "class_ogre_1_1_free_image_codec.html", "class_ogre_1_1_free_image_codec" ],
       [ "Frustum", "class_ogre_1_1_frustum.html", "class_ogre_1_1_frustum" ],
-      [ "GL3PlusFBOManager", "class_ogre_1_1_g_l3_plus_f_b_o_manager.html", "class_ogre_1_1_g_l3_plus_f_b_o_manager" ],
-      [ "GL3PlusFBOMultiRenderTarget", "class_ogre_1_1_g_l3_plus_f_b_o_multi_render_target.html", "class_ogre_1_1_g_l3_plus_f_b_o_multi_render_target" ],
-      [ "GL3PlusFBORenderTexture", "class_ogre_1_1_g_l3_plus_f_b_o_render_texture.html", "class_ogre_1_1_g_l3_plus_f_b_o_render_texture" ],
-      [ "GL3PlusFrameBufferObject", "class_ogre_1_1_g_l3_plus_frame_buffer_object.html", "class_ogre_1_1_g_l3_plus_frame_buffer_object" ],
-      [ "GL3PlusHardwareBuffer", "class_ogre_1_1_g_l3_plus_hardware_buffer.html", "class_ogre_1_1_g_l3_plus_hardware_buffer" ],
-      [ "GL3PlusHardwareBufferManager", "class_ogre_1_1_g_l3_plus_hardware_buffer_manager.html", "class_ogre_1_1_g_l3_plus_hardware_buffer_manager" ],
-      [ "GL3PlusHardwareOcclusionQuery", "class_ogre_1_1_g_l3_plus_hardware_occlusion_query.html", "class_ogre_1_1_g_l3_plus_hardware_occlusion_query" ],
-      [ "GL3PlusPixelUtil", "class_ogre_1_1_g_l3_plus_pixel_util.html", "class_ogre_1_1_g_l3_plus_pixel_util" ],
-      [ "GL3PlusPlugin", "class_ogre_1_1_g_l3_plus_plugin.html", "class_ogre_1_1_g_l3_plus_plugin" ],
-      [ "GL3PlusRenderBuffer", "class_ogre_1_1_g_l3_plus_render_buffer.html", "class_ogre_1_1_g_l3_plus_render_buffer" ],
       [ "GL3PlusRenderSystem", "class_ogre_1_1_g_l3_plus_render_system.html", "class_ogre_1_1_g_l3_plus_render_system" ],
-      [ "GL3PlusRenderToVertexBuffer", "class_ogre_1_1_g_l3_plus_render_to_vertex_buffer.html", "class_ogre_1_1_g_l3_plus_render_to_vertex_buffer" ],
-      [ "GL3PlusSampler", "class_ogre_1_1_g_l3_plus_sampler.html", "class_ogre_1_1_g_l3_plus_sampler" ],
-      [ "GL3PlusStateCacheManager", "class_ogre_1_1_g_l3_plus_state_cache_manager.html", "class_ogre_1_1_g_l3_plus_state_cache_manager" ],
-      [ "GL3PlusTexture", "class_ogre_1_1_g_l3_plus_texture.html", "class_ogre_1_1_g_l3_plus_texture" ],
-      [ "GL3PlusTextureBuffer", "class_ogre_1_1_g_l3_plus_texture_buffer.html", "class_ogre_1_1_g_l3_plus_texture_buffer" ],
-      [ "GL3PlusTextureManager", "class_ogre_1_1_g_l3_plus_texture_manager.html", "class_ogre_1_1_g_l3_plus_texture_manager" ],
-      [ "GLArbGpuProgram", "class_ogre_1_1_g_l_arb_gpu_program.html", "class_ogre_1_1_g_l_arb_gpu_program" ],
-      [ "GLContext", "class_ogre_1_1_g_l_context.html", "class_ogre_1_1_g_l_context" ],
-      [ "GLCopyingRenderTexture", "class_ogre_1_1_g_l_copying_render_texture.html", "class_ogre_1_1_g_l_copying_render_texture" ],
-      [ "GLCopyingRTTManager", "class_ogre_1_1_g_l_copying_r_t_t_manager.html", "class_ogre_1_1_g_l_copying_r_t_t_manager" ],
-      [ "GLDepthBufferCommon", "class_ogre_1_1_g_l_depth_buffer_common.html", "class_ogre_1_1_g_l_depth_buffer_common" ],
-      [ "GLES2FBOManager", "class_ogre_1_1_g_l_e_s2_f_b_o_manager.html", "class_ogre_1_1_g_l_e_s2_f_b_o_manager" ],
-      [ "GLES2FBOMultiRenderTarget", "class_ogre_1_1_g_l_e_s2_f_b_o_multi_render_target.html", "class_ogre_1_1_g_l_e_s2_f_b_o_multi_render_target" ],
-      [ "GLES2FBORenderTexture", "class_ogre_1_1_g_l_e_s2_f_b_o_render_texture.html", "class_ogre_1_1_g_l_e_s2_f_b_o_render_texture" ],
-      [ "GLES2FrameBufferObject", "class_ogre_1_1_g_l_e_s2_frame_buffer_object.html", "class_ogre_1_1_g_l_e_s2_frame_buffer_object" ],
-      [ "GLES2HardwareBuffer", "class_ogre_1_1_g_l_e_s2_hardware_buffer.html", "class_ogre_1_1_g_l_e_s2_hardware_buffer" ],
-      [ "GLES2HardwareBufferManager", "class_ogre_1_1_g_l_e_s2_hardware_buffer_manager.html", "class_ogre_1_1_g_l_e_s2_hardware_buffer_manager" ],
-      [ "GLES2HardwareOcclusionQuery", "class_ogre_1_1_g_l_e_s2_hardware_occlusion_query.html", "class_ogre_1_1_g_l_e_s2_hardware_occlusion_query" ],
-      [ "GLES2PixelUtil", "class_ogre_1_1_g_l_e_s2_pixel_util.html", "class_ogre_1_1_g_l_e_s2_pixel_util" ],
-      [ "GLES2Plugin", "class_ogre_1_1_g_l_e_s2_plugin.html", "class_ogre_1_1_g_l_e_s2_plugin" ],
-      [ "GLES2RenderBuffer", "class_ogre_1_1_g_l_e_s2_render_buffer.html", "class_ogre_1_1_g_l_e_s2_render_buffer" ],
       [ "GLES2RenderSystem", "class_ogre_1_1_g_l_e_s2_render_system.html", "class_ogre_1_1_g_l_e_s2_render_system" ],
-      [ "GLES2RenderToVertexBuffer", "class_ogre_1_1_g_l_e_s2_render_to_vertex_buffer.html", "class_ogre_1_1_g_l_e_s2_render_to_vertex_buffer" ],
-      [ "GLES2StateCacheManager", "class_ogre_1_1_g_l_e_s2_state_cache_manager.html", "class_ogre_1_1_g_l_e_s2_state_cache_manager" ],
-      [ "GLES2Texture", "class_ogre_1_1_g_l_e_s2_texture.html", "class_ogre_1_1_g_l_e_s2_texture" ],
-      [ "GLES2TextureBuffer", "class_ogre_1_1_g_l_e_s2_texture_buffer.html", "class_ogre_1_1_g_l_e_s2_texture_buffer" ],
-      [ "GLES2TextureManager", "class_ogre_1_1_g_l_e_s2_texture_manager.html", "class_ogre_1_1_g_l_e_s2_texture_manager" ],
-      [ "GLFBOManager", "class_ogre_1_1_g_l_f_b_o_manager.html", "class_ogre_1_1_g_l_f_b_o_manager" ],
-      [ "GLFBOMultiRenderTarget", "class_ogre_1_1_g_l_f_b_o_multi_render_target.html", "class_ogre_1_1_g_l_f_b_o_multi_render_target" ],
-      [ "GLFBORenderTexture", "class_ogre_1_1_g_l_f_b_o_render_texture.html", "class_ogre_1_1_g_l_f_b_o_render_texture" ],
-      [ "GLFrameBufferObject", "class_ogre_1_1_g_l_frame_buffer_object.html", "class_ogre_1_1_g_l_frame_buffer_object" ],
-      [ "GLFrameBufferObjectCommon", "class_ogre_1_1_g_l_frame_buffer_object_common.html", "class_ogre_1_1_g_l_frame_buffer_object_common" ],
-      [ "GLGpuNvparseProgram", "class_ogre_1_1_g_l_gpu_nvparse_program.html", "class_ogre_1_1_g_l_gpu_nvparse_program" ],
-      [ "GLGpuProgram", "class_ogre_1_1_g_l_gpu_program.html", "class_ogre_1_1_g_l_gpu_program" ],
-      [ "GLGpuProgramBase", "struct_ogre_1_1_g_l_gpu_program_base.html", "struct_ogre_1_1_g_l_gpu_program_base" ],
-      [ "GLGpuProgramManager", "class_ogre_1_1_g_l_gpu_program_manager.html", "class_ogre_1_1_g_l_gpu_program_manager" ],
-      [ "GLHardwareBufferManager", "class_ogre_1_1_g_l_hardware_buffer_manager.html", "class_ogre_1_1_g_l_hardware_buffer_manager" ],
-      [ "GLHardwareOcclusionQuery", "class_ogre_1_1_g_l_hardware_occlusion_query.html", "class_ogre_1_1_g_l_hardware_occlusion_query" ],
-      [ "GLHardwarePixelBufferCommon", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html", "class_ogre_1_1_g_l_hardware_pixel_buffer_common" ],
-      [ "GLHardwareVertexBuffer", "class_ogre_1_1_g_l_hardware_vertex_buffer.html", "class_ogre_1_1_g_l_hardware_vertex_buffer" ],
-      [ "GLNativeSupport", "class_ogre_1_1_g_l_native_support.html", "class_ogre_1_1_g_l_native_support" ],
-      [ "GLPBRenderTexture", "class_ogre_1_1_g_l_p_b_render_texture.html", "class_ogre_1_1_g_l_p_b_render_texture" ],
-      [ "GLPBRTTManager", "class_ogre_1_1_g_l_p_b_r_t_t_manager.html", "class_ogre_1_1_g_l_p_b_r_t_t_manager" ],
-      [ "GLPBuffer", "class_ogre_1_1_g_l_p_buffer.html", "class_ogre_1_1_g_l_p_buffer" ],
-      [ "GLPixelUtil", "class_ogre_1_1_g_l_pixel_util.html", "class_ogre_1_1_g_l_pixel_util" ],
-      [ "GLPlugin", "class_ogre_1_1_g_l_plugin.html", "class_ogre_1_1_g_l_plugin" ],
-      [ "GLRenderBuffer", "class_ogre_1_1_g_l_render_buffer.html", "class_ogre_1_1_g_l_render_buffer" ],
       [ "GLRenderSystem", "class_ogre_1_1_g_l_render_system.html", "class_ogre_1_1_g_l_render_system" ],
-      [ "GLRenderSystemCommon", "class_ogre_1_1_g_l_render_system_common.html", "class_ogre_1_1_g_l_render_system_common" ],
-      [ "GLRenderTarget", "class_ogre_1_1_g_l_render_target.html", "class_ogre_1_1_g_l_render_target" ],
-      [ "GLRenderTexture", "class_ogre_1_1_g_l_render_texture.html", "class_ogre_1_1_g_l_render_texture" ],
-      [ "GLRenderToVertexBuffer", "class_ogre_1_1_g_l_render_to_vertex_buffer.html", "class_ogre_1_1_g_l_render_to_vertex_buffer" ],
-      [ "GLRenderToVertexBufferCommon", "class_ogre_1_1_g_l_render_to_vertex_buffer_common.html", null ],
-      [ "GLRTTManager", "class_ogre_1_1_g_l_r_t_t_manager.html", "class_ogre_1_1_g_l_r_t_t_manager" ],
       [ "GLSLangPlugin", "class_ogre_1_1_g_l_s_lang_plugin.html", "class_ogre_1_1_g_l_s_lang_plugin" ],
       [ "GLSLangProgram", "class_ogre_1_1_g_l_s_lang_program.html", "class_ogre_1_1_g_l_s_lang_program" ],
       [ "GLSLangProgramFactory", "class_ogre_1_1_g_l_s_lang_program_factory.html", "class_ogre_1_1_g_l_s_lang_program_factory" ],
-      [ "GLSLESCgProgram", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html", "class_ogre_1_1_g_l_s_l_e_s_cg_program" ],
-      [ "GLSLESCgProgramFactory", "class_ogre_1_1_g_l_s_l_e_s_cg_program_factory.html", "class_ogre_1_1_g_l_s_l_e_s_cg_program_factory" ],
-      [ "GLSLESLinkProgram", "class_ogre_1_1_g_l_s_l_e_s_link_program.html", "class_ogre_1_1_g_l_s_l_e_s_link_program" ],
-      [ "GLSLESProgram", "class_ogre_1_1_g_l_s_l_e_s_program.html", "class_ogre_1_1_g_l_s_l_e_s_program" ],
-      [ "GLSLESProgramCommon", "class_ogre_1_1_g_l_s_l_e_s_program_common.html", "class_ogre_1_1_g_l_s_l_e_s_program_common" ],
-      [ "GLSLESProgramFactory", "class_ogre_1_1_g_l_s_l_e_s_program_factory.html", "class_ogre_1_1_g_l_s_l_e_s_program_factory" ],
-      [ "GLSLESProgramManager", "class_ogre_1_1_g_l_s_l_e_s_program_manager.html", "class_ogre_1_1_g_l_s_l_e_s_program_manager" ],
-      [ "GLSLESProgramPipeline", "class_ogre_1_1_g_l_s_l_e_s_program_pipeline.html", "class_ogre_1_1_g_l_s_l_e_s_program_pipeline" ],
-      [ "GLSLMonolithicProgram", "class_ogre_1_1_g_l_s_l_monolithic_program.html", "class_ogre_1_1_g_l_s_l_monolithic_program" ],
-      [ "GLSLProgram", "class_ogre_1_1_g_l_s_l_program.html", "class_ogre_1_1_g_l_s_l_program" ],
-      [ "GLSLProgramCommon", "class_ogre_1_1_g_l_s_l_program_common.html", "class_ogre_1_1_g_l_s_l_program_common" ],
-      [ "GLSLProgramManager", "class_ogre_1_1_g_l_s_l_program_manager.html", "class_ogre_1_1_g_l_s_l_program_manager" ],
-      [ "GLSLProgramManagerCommon", "class_ogre_1_1_g_l_s_l_program_manager_common.html", "class_ogre_1_1_g_l_s_l_program_manager_common" ],
-      [ "GLSLSeparableProgram", "class_ogre_1_1_g_l_s_l_separable_program.html", "class_ogre_1_1_g_l_s_l_separable_program" ],
-      [ "GLSLShader", "class_ogre_1_1_g_l_s_l_shader.html", "class_ogre_1_1_g_l_s_l_shader" ],
-      [ "GLSLShaderCommon", "class_ogre_1_1_g_l_s_l_shader_common.html", "class_ogre_1_1_g_l_s_l_shader_common" ],
-      [ "GLSLShaderFactory", "class_ogre_1_1_g_l_s_l_shader_factory.html", "class_ogre_1_1_g_l_s_l_shader_factory" ],
-      [ "GLStateCacheManager", "class_ogre_1_1_g_l_state_cache_manager.html", "class_ogre_1_1_g_l_state_cache_manager" ],
-      [ "GLStateCacheManagerCommon", "class_ogre_1_1_g_l_state_cache_manager_common.html", "class_ogre_1_1_g_l_state_cache_manager_common" ],
-      [ "GLSurfaceDesc", "struct_ogre_1_1_g_l_surface_desc.html", "struct_ogre_1_1_g_l_surface_desc" ],
-      [ "GLTexture", "class_ogre_1_1_g_l_texture.html", "class_ogre_1_1_g_l_texture" ],
-      [ "GLTextureBuffer", "class_ogre_1_1_g_l_texture_buffer.html", "class_ogre_1_1_g_l_texture_buffer" ],
-      [ "GLTextureCommon", "class_ogre_1_1_g_l_texture_common.html", "class_ogre_1_1_g_l_texture_common" ],
-      [ "GLTextureManager", "class_ogre_1_1_g_l_texture_manager.html", "class_ogre_1_1_g_l_texture_manager" ],
-      [ "GLUniformCache", "class_ogre_1_1_g_l_uniform_cache.html", "class_ogre_1_1_g_l_uniform_cache" ],
-      [ "GLUniformReference", "struct_ogre_1_1_g_l_uniform_reference.html", "struct_ogre_1_1_g_l_uniform_reference" ],
-      [ "GLVertexArrayObject", "class_ogre_1_1_g_l_vertex_array_object.html", "class_ogre_1_1_g_l_vertex_array_object" ],
-      [ "GLWindow", "class_ogre_1_1_g_l_window.html", "class_ogre_1_1_g_l_window" ],
       [ "GlyphInfo", "struct_ogre_1_1_glyph_info.html", "struct_ogre_1_1_glyph_info" ],
       [ "GpuConstantDefinition", "struct_ogre_1_1_gpu_constant_definition.html", "struct_ogre_1_1_gpu_constant_definition" ],
       [ "GpuLogicalBufferStruct", "struct_ogre_1_1_gpu_logical_buffer_struct.html", "struct_ogre_1_1_gpu_logical_buffer_struct" ],
@@ -503,24 +345,7 @@ var annotated_dup =
       [ "MeshManager", "class_ogre_1_1_mesh_manager.html", "class_ogre_1_1_mesh_manager" ],
       [ "MeshSerializer", "class_ogre_1_1_mesh_serializer.html", "class_ogre_1_1_mesh_serializer" ],
       [ "MeshSerializerListener", "class_ogre_1_1_mesh_serializer_listener.html", "class_ogre_1_1_mesh_serializer_listener" ],
-      [ "MetalDepthBuffer", "class_ogre_1_1_metal_depth_buffer.html", "class_ogre_1_1_metal_depth_buffer" ],
-      [ "MetalDevice", "struct_ogre_1_1_metal_device.html", "struct_ogre_1_1_metal_device" ],
-      [ "MetalHardwareBufferCommon", "class_ogre_1_1_metal_hardware_buffer_common.html", "class_ogre_1_1_metal_hardware_buffer_common" ],
-      [ "MetalHardwareBufferManager", "class_ogre_1_1_metal_hardware_buffer_manager.html", "class_ogre_1_1_metal_hardware_buffer_manager" ],
-      [ "MetalHardwarePixelBuffer", "class_ogre_1_1_metal_hardware_pixel_buffer.html", "class_ogre_1_1_metal_hardware_pixel_buffer" ],
-      [ "MetalMappings", "class_ogre_1_1_metal_mappings.html", "class_ogre_1_1_metal_mappings" ],
-      [ "MetalMultiRenderTarget", "class_ogre_1_1_metal_multi_render_target.html", "class_ogre_1_1_metal_multi_render_target" ],
-      [ "MetalPlugin", "class_ogre_1_1_metal_plugin.html", "class_ogre_1_1_metal_plugin" ],
-      [ "MetalProgram", "class_ogre_1_1_metal_program.html", "class_ogre_1_1_metal_program" ],
-      [ "MetalProgramFactory", "class_ogre_1_1_metal_program_factory.html", "class_ogre_1_1_metal_program_factory" ],
       [ "MetalRenderSystem", "class_ogre_1_1_metal_render_system.html", "class_ogre_1_1_metal_render_system" ],
-      [ "MetalRenderTargetCommon", "class_ogre_1_1_metal_render_target_common.html", "class_ogre_1_1_metal_render_target_common" ],
-      [ "MetalRenderTexture", "class_ogre_1_1_metal_render_texture.html", "class_ogre_1_1_metal_render_texture" ],
-      [ "MetalRenderWindow", "class_ogre_1_1_metal_render_window.html", "class_ogre_1_1_metal_render_window" ],
-      [ "MetalSampler", "class_ogre_1_1_metal_sampler.html", "class_ogre_1_1_metal_sampler" ],
-      [ "MetalTexture", "class_ogre_1_1_metal_texture.html", "class_ogre_1_1_metal_texture" ],
-      [ "MetalTextureBuffer", "class_ogre_1_1_metal_texture_buffer.html", "class_ogre_1_1_metal_texture_buffer" ],
-      [ "MetalTextureManager", "class_ogre_1_1_metal_texture_manager.html", "class_ogre_1_1_metal_texture_manager" ],
       [ "MovableObject", "class_ogre_1_1_movable_object.html", "class_ogre_1_1_movable_object" ],
       [ "MovableObjectFactory", "class_ogre_1_1_movable_object_factory.html", "class_ogre_1_1_movable_object_factory" ],
       [ "MovableObjectLodChangedEvent", "struct_ogre_1_1_movable_object_lod_changed_event.html", "struct_ogre_1_1_movable_object_lod_changed_event" ],
@@ -528,7 +353,6 @@ var annotated_dup =
       [ "multimap", "struct_ogre_1_1multimap.html", "struct_ogre_1_1multimap" ],
       [ "MultiRenderTarget", "class_ogre_1_1_multi_render_target.html", "class_ogre_1_1_multi_render_target" ],
       [ "NameGenerator", "class_ogre_1_1_name_generator.html", "class_ogre_1_1_name_generator" ],
-      [ "NoAddRefRelease", "class_ogre_1_1_no_add_ref_release.html", null ],
       [ "Node", "class_ogre_1_1_node.html", "class_ogre_1_1_node" ],
       [ "NodeAnimationTrack", "class_ogre_1_1_node_animation_track.html", "class_ogre_1_1_node_animation_track" ],
       [ "NumericAnimationTrack", "class_ogre_1_1_numeric_animation_track.html", "class_ogre_1_1_numeric_animation_track" ],
@@ -730,8 +554,6 @@ var annotated_dup =
       [ "SPFMNone", "struct_ogre_1_1_s_p_f_m_none.html", "struct_ogre_1_1_s_p_f_m_none" ],
       [ "Sphere", "class_ogre_1_1_sphere.html", "class_ogre_1_1_sphere" ],
       [ "SphereSceneQuery", "class_ogre_1_1_sphere_scene_query.html", "class_ogre_1_1_sphere_scene_query" ],
-      [ "SPIRVShader", "class_ogre_1_1_s_p_i_r_v_shader.html", "class_ogre_1_1_s_p_i_r_v_shader" ],
-      [ "SPIRVShaderFactory", "class_ogre_1_1_s_p_i_r_v_shader_factory.html", "class_ogre_1_1_s_p_i_r_v_shader_factory" ],
       [ "StaticCache", "class_ogre_1_1_static_cache.html", "class_ogre_1_1_static_cache" ],
       [ "StaticFaceGroup", "struct_ogre_1_1_static_face_group.html", "struct_ogre_1_1_static_face_group" ],
       [ "StaticGeometry", "class_ogre_1_1_static_geometry.html", "class_ogre_1_1_static_geometry" ],
@@ -770,13 +592,7 @@ var annotated_dup =
       [ "TextureUnitState", "class_ogre_1_1_texture_unit_state.html", "class_ogre_1_1_texture_unit_state" ],
       [ "TimeIndex", "class_ogre_1_1_time_index.html", "class_ogre_1_1_time_index" ],
       [ "Timer", "class_ogre_1_1_timer.html", "class_ogre_1_1_timer" ],
-      [ "TinyDepthBuffer", "class_ogre_1_1_tiny_depth_buffer.html", "class_ogre_1_1_tiny_depth_buffer" ],
-      [ "TinyHardwarePixelBuffer", "class_ogre_1_1_tiny_hardware_pixel_buffer.html", "class_ogre_1_1_tiny_hardware_pixel_buffer" ],
-      [ "TinyPlugin", "class_ogre_1_1_tiny_plugin.html", "class_ogre_1_1_tiny_plugin" ],
       [ "TinyRenderSystem", "class_ogre_1_1_tiny_render_system.html", "class_ogre_1_1_tiny_render_system" ],
-      [ "TinyTexture", "class_ogre_1_1_tiny_texture.html", "class_ogre_1_1_tiny_texture" ],
-      [ "TinyTextureManager", "class_ogre_1_1_tiny_texture_manager.html", "class_ogre_1_1_tiny_texture_manager" ],
-      [ "TinyWindow", "class_ogre_1_1_tiny_window.html", "class_ogre_1_1_tiny_window" ],
       [ "TransformBase", "class_ogre_1_1_transform_base.html", "class_ogre_1_1_transform_base" ],
       [ "TransformBaseReal", "struct_ogre_1_1_transform_base_real.html", "struct_ogre_1_1_transform_base_real" ],
       [ "TransformKeyFrame", "class_ogre_1_1_transform_key_frame.html", "class_ogre_1_1_transform_key_frame" ],
@@ -784,8 +600,8 @@ var annotated_dup =
       [ "UnimplementedException", "class_ogre_1_1_unimplemented_exception.html", "class_ogre_1_1_unimplemented_exception" ],
       [ "UserObjectBindings", "class_ogre_1_1_user_object_bindings.html", "class_ogre_1_1_user_object_bindings" ],
       [ "VariableAccessAbstractNode", "class_ogre_1_1_variable_access_abstract_node.html", "class_ogre_1_1_variable_access_abstract_node" ],
-      [ "vector", "struct_ogre_1_1vector.html", "struct_ogre_1_1vector" ],
       [ "Vector", "class_ogre_1_1_vector.html", "class_ogre_1_1_vector" ],
+      [ "vector", "struct_ogre_1_1vector.html", "struct_ogre_1_1vector" ],
       [ "VectorBase", "struct_ogre_1_1_vector_base.html", "struct_ogre_1_1_vector_base" ],
       [ "VectorBase< 2, Real >", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4" ],
       [ "VectorBase< 3, Real >", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4" ],
@@ -802,29 +618,10 @@ var annotated_dup =
       [ "VertexElement", "class_ogre_1_1_vertex_element.html", "class_ogre_1_1_vertex_element" ],
       [ "VertexMorphKeyFrame", "class_ogre_1_1_vertex_morph_key_frame.html", "class_ogre_1_1_vertex_morph_key_frame" ],
       [ "VertexPoseKeyFrame", "class_ogre_1_1_vertex_pose_key_frame.html", "class_ogre_1_1_vertex_pose_key_frame" ],
-      [ "VideoMode", "struct_ogre_1_1_video_mode.html", "struct_ogre_1_1_video_mode" ],
       [ "ViewPoint", "struct_ogre_1_1_view_point.html", "struct_ogre_1_1_view_point" ],
       [ "Viewport", "class_ogre_1_1_viewport.html", "class_ogre_1_1_viewport" ],
       [ "VisibleObjectsBoundsInfo", "struct_ogre_1_1_visible_objects_bounds_info.html", "struct_ogre_1_1_visible_objects_bounds_info" ],
-      [ "VulkanDescriptorPool", "class_ogre_1_1_vulkan_descriptor_pool.html", "class_ogre_1_1_vulkan_descriptor_pool" ],
-      [ "VulkanDevice", "struct_ogre_1_1_vulkan_device.html", "struct_ogre_1_1_vulkan_device" ],
-      [ "VulkanFrameBufferDescValue", "struct_ogre_1_1_vulkan_frame_buffer_desc_value.html", "struct_ogre_1_1_vulkan_frame_buffer_desc_value" ],
-      [ "VulkanHardwareBuffer", "class_ogre_1_1_vulkan_hardware_buffer.html", "class_ogre_1_1_vulkan_hardware_buffer" ],
-      [ "VulkanHardwareBufferManager", "class_ogre_1_1_vulkan_hardware_buffer_manager.html", "class_ogre_1_1_vulkan_hardware_buffer_manager" ],
-      [ "VulkanHardwarePixelBuffer", "class_ogre_1_1_vulkan_hardware_pixel_buffer.html", "class_ogre_1_1_vulkan_hardware_pixel_buffer" ],
-      [ "VulkanMappings", "class_ogre_1_1_vulkan_mappings.html", "class_ogre_1_1_vulkan_mappings" ],
-      [ "VulkanPlugin", "class_ogre_1_1_vulkan_plugin.html", "class_ogre_1_1_vulkan_plugin" ],
-      [ "VulkanProgram", "class_ogre_1_1_vulkan_program.html", "class_ogre_1_1_vulkan_program" ],
-      [ "VulkanProgramFactory", "class_ogre_1_1_vulkan_program_factory.html", "class_ogre_1_1_vulkan_program_factory" ],
-      [ "VulkanQueue", "class_ogre_1_1_vulkan_queue.html", "class_ogre_1_1_vulkan_queue" ],
-      [ "VulkanRenderPassDescriptor", "class_ogre_1_1_vulkan_render_pass_descriptor.html", "class_ogre_1_1_vulkan_render_pass_descriptor" ],
       [ "VulkanRenderSystem", "class_ogre_1_1_vulkan_render_system.html", "class_ogre_1_1_vulkan_render_system" ],
-      [ "VulkanRenderTexture", "class_ogre_1_1_vulkan_render_texture.html", "class_ogre_1_1_vulkan_render_texture" ],
-      [ "VulkanSampler", "class_ogre_1_1_vulkan_sampler.html", "class_ogre_1_1_vulkan_sampler" ],
-      [ "VulkanTextureGpu", "class_ogre_1_1_vulkan_texture_gpu.html", "class_ogre_1_1_vulkan_texture_gpu" ],
-      [ "VulkanTextureGpuManager", "class_ogre_1_1_vulkan_texture_gpu_manager.html", "class_ogre_1_1_vulkan_texture_gpu_manager" ],
-      [ "VulkanTextureGpuWindow", "class_ogre_1_1_vulkan_texture_gpu_window.html", "class_ogre_1_1_vulkan_texture_gpu_window" ],
-      [ "VulkanWindow", "class_ogre_1_1_vulkan_window.html", "class_ogre_1_1_vulkan_window" ],
       [ "WaveformControllerFunction", "class_ogre_1_1_waveform_controller_function.html", "class_ogre_1_1_waveform_controller_function" ],
       [ "WireBoundingBox", "class_ogre_1_1_wire_bounding_box.html", "class_ogre_1_1_wire_bounding_box" ],
       [ "WorkQueue", "class_ogre_1_1_work_queue.html", "class_ogre_1_1_work_queue" ],
@@ -881,6 +678,5 @@ var annotated_dup =
     [ "bsp_plane_t", "structbsp__plane__t.html", "structbsp__plane__t" ],
     [ "bsp_shader_t", "structbsp__shader__t.html", "structbsp__shader__t" ],
     [ "bsp_vertex_t", "structbsp__vertex__t.html", "structbsp__vertex__t" ],
-    [ "bsp_vis_t", "structbsp__vis__t.html", "structbsp__vis__t" ],
-    [ "OgreMetalView", "interface_ogre_metal_view.html", "interface_ogre_metal_view" ]
+    [ "bsp_vis_t", "structbsp__vis__t.html", "structbsp__vis__t" ]
 ];
\ No newline at end of file
