@@ -1,9 +1,7 @@
 var class_ogre_1_1_bullet_1_1_dynamics_world =
 [
     [ "DynamicsWorld", "class_ogre_1_1_bullet_1_1_dynamics_world.html#a7e72c8cb32eff9d058447ea7198f65ef", null ],
-    [ "~DynamicsWorld", "class_ogre_1_1_bullet_1_1_dynamics_world.html#ac2d90be56bf89f88b796a91fc399bf0c", null ],
     [ "DynamicsWorld", "class_ogre_1_1_bullet_1_1_dynamics_world.html#a54d4cbf8c35c17149c7287ad4d05b88e", null ],
     [ "addRigidBody", "class_ogre_1_1_bullet_1_1_dynamics_world.html#afcafa5a4a6ba86014b0a1273d9584e25", null ],
-    [ "getBtWorld", "class_ogre_1_1_bullet_1_1_dynamics_world.html#a3ef0f4b137145278b7901ac79cebaac6", null ],
-    [ "rayTest", "class_ogre_1_1_bullet_1_1_dynamics_world.html#a350e9a135437edb7b11b0667eac0bd75", null ]
+    [ "getBtWorld", "class_ogre_1_1_bullet_1_1_dynamics_world.html#a3ef0f4b137145278b7901ac79cebaac6", null ]
 ];
\ No newline at end of file
