@@ -119,11 +119,11 @@ var group___general =
       [ "display", "class_ogre_1_1_config_dialog.html#ac870ab35ef00d99a44a837dd757bdece", null ]
     ] ],
     [ "Ogre::ConfigFile", "class_ogre_1_1_config_file.html", [
-      [ "SettingsMultiMap", "class_ogre_1_1_config_file.html#ad30a1dd3f08d58aa688fbe998041125b", null ],
-      [ "SettingsIterator", "class_ogre_1_1_config_file.html#a6105a5709c33af54b991490159fb7cd3", null ],
-      [ "SettingsBySection", "class_ogre_1_1_config_file.html#ae678a4fe2060b301595443e176471a4a", null ],
-      [ "SettingsBySection_", "class_ogre_1_1_config_file.html#a2f86d3b17b599838443302eebfc8efe3", null ],
-      [ "SectionIterator", "class_ogre_1_1_config_file.html#abadac1f8e7a115ae777aff915d00c949", null ],
+      [ "SettingsMultiMap", "class_ogre_1_1_config_file.html#a7c64847e5235249d699b38a36c8fd2db", null ],
+      [ "SettingsIterator", "class_ogre_1_1_config_file.html#adf764e20ebcf5c52d0ea887b1468a283", null ],
+      [ "SettingsBySection", "class_ogre_1_1_config_file.html#a77b98c7359f2ff7b67b9039e8979a2ac", null ],
+      [ "SettingsBySection_", "class_ogre_1_1_config_file.html#a1c93ac229f0693f0831579c0657ab290", null ],
+      [ "SectionIterator", "class_ogre_1_1_config_file.html#aa0167bf5f0a33e109d2de01a6a14f2f0", null ],
       [ "ConfigFile", "class_ogre_1_1_config_file.html#ae9cea1fe4ad70279841635eb892ba514", null ],
       [ "load", "class_ogre_1_1_config_file.html#a361167ade63602d0cf242ee24a10b4a8", null ],
       [ "load", "class_ogre_1_1_config_file.html#a5b28053a489365f4b30d4d9c166443b8", null ],
@@ -364,7 +364,7 @@ var group___general =
       [ "hierarchicalLvl", "struct_ogre_1_1_profile_history.html#ac2585d85ca3195ef12c7c8cdb75427da", null ]
     ] ],
     [ "Ogre::ProfileInstance", "class_ogre_1_1_profile_instance.html", [
-      [ "ProfileChildren", "class_ogre_1_1_profile_instance.html#a212bbe3dac1e17cd50420d728b0c6469", null ],
+      [ "ProfileChildren", "class_ogre_1_1_profile_instance.html#a9e270128c004dafcc20e537b81cc337c", null ],
       [ "ProfileInstance", "class_ogre_1_1_profile_instance.html#a4921211276e29e72155077235687cf54", null ],
       [ "~ProfileInstance", "class_ogre_1_1_profile_instance.html#af16b392bd516cb3acacc99d598d0ad39", null ],
       [ "logResults", "class_ogre_1_1_profile_instance.html#af43228f1e8e2ab70809bbb14d27ae773", null ],
@@ -430,10 +430,10 @@ var group___general =
       [ "miscParams", "struct_ogre_1_1_render_window_description.html#a9d041f83279956a42785c6894bea178a", null ]
     ] ],
     [ "Ogre::Root", "class_ogre_1_1_root.html", [
-      [ "MovableObjectFactoryMap", "class_ogre_1_1_root.html#a1c51501e89aea4db92a59daaa8d0415c", null ],
-      [ "PluginLibList", "class_ogre_1_1_root.html#a98e491a5f6661ea592418f792aac6afb", null ],
-      [ "PluginInstanceList", "class_ogre_1_1_root.html#a00f7e97f5bca559586f494aee9b95a33", null ],
-      [ "MovableObjectFactoryIterator", "class_ogre_1_1_root.html#a1d4436f211080a71ef1072ee05a9b348", null ],
+      [ "MovableObjectFactoryMap", "class_ogre_1_1_root.html#aa63b41f580aca52c3f35279dd06234fc", null ],
+      [ "PluginLibList", "class_ogre_1_1_root.html#a33f7c5af7a51aff1d28a8d7f16253d57", null ],
+      [ "PluginInstanceList", "class_ogre_1_1_root.html#a9bd411bb1456e55ca634a67ef003e691", null ],
+      [ "MovableObjectFactoryIterator", "class_ogre_1_1_root.html#a724ee7dcbdb7b8052420df2fecd07c0d", null ],
       [ "Root", "class_ogre_1_1_root.html#a293d1580c95101d72f2155e3fe2237bf", null ],
       [ "~Root", "class_ogre_1_1_root.html#ae093f91224577ccb051ac3d8e84c6db8", null ],
       [ "saveConfig", "class_ogre_1_1_root.html#adc6946eb808dd76774d2c95ae1e0c6d9", null ],
@@ -556,7 +556,9 @@ var group___general =
     ] ],
     [ "Ogre::SimpleParamCommand< _Class, const String &, getter, setter >", "class_ogre_1_1_simple_param_command_3_01___class_00_01const_01_string_01_6_00_01getter_00_01setter_01_4.html", [
       [ "doGet", "class_ogre_1_1_simple_param_command_3_01___class_00_01const_01_string_01_6_00_01getter_00_01setter_01_4.html#aad3aa9c19d5ee9d99cc680ba84162082", null ],
-      [ "doSet", "class_ogre_1_1_simple_param_command_3_01___class_00_01const_01_string_01_6_00_01getter_00_01setter_01_4.html#a5f19051871ee808c8efad85a47e80521", null ]
+      [ "doSet", "class_ogre_1_1_simple_param_command_3_01___class_00_01const_01_string_01_6_00_01getter_00_01setter_01_4.html#a5f19051871ee808c8efad85a47e80521", null ],
+      [ "doGet", "class_ogre_1_1_simple_param_command.html#a29ff02942b19b51153abd53a878e244a", null ],
+      [ "doSet", "class_ogre_1_1_simple_param_command.html#a9727fda386f95b2bb29bf41c553bd944", null ]
     ] ],
     [ "Ogre::Singleton< T >", "class_ogre_1_1_singleton.html", [
       [ "Singleton", "class_ogre_1_1_singleton.html#a2b0622a1223ac3a0c6b9c53e787b8d93", null ],
@@ -635,7 +637,7 @@ var group___general =
       [ "cleanupDictionary", "class_ogre_1_1_string_interface.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8", null ]
     ] ],
     [ "Ogre::StringUtil", "class_ogre_1_1_string_util.html", [
-      [ "StrStreamType", "class_ogre_1_1_string_util.html#a84b278f519cb5e5a2ae0c1f25fb8952e", null ],
+      [ "StrStreamType", "class_ogre_1_1_string_util.html#a665d79932d54b48b83acff563de7a9e5", null ],
       [ "trim", "class_ogre_1_1_string_util.html#ae36e8b6e19fef623f59d56772ed1dd7e", null ],
       [ "split", "class_ogre_1_1_string_util.html#ab1866eeae090e9d97daf953d99dbace8", null ],
       [ "tokenise", "class_ogre_1_1_string_util.html#a954a5f07b7e9bc0be5130bf148fa1d6f", null ],
@@ -698,7 +700,7 @@ var group___general =
         [ "mMessages", "struct_ogre_1_1_work_queue_1_1_response.html#aa79894f8c3badaddc48064f4b35141be", null ],
         [ "mData", "struct_ogre_1_1_work_queue_1_1_response.html#a04980c518c8e22f1f669e6b543a10e20", null ]
       ] ],
-      [ "RequestID", "class_ogre_1_1_work_queue.html#a0bdef005c63c8af1c3ded55f04c38ae1", null ],
+      [ "RequestID", "class_ogre_1_1_work_queue.html#a1908257e726af6caa80f1a6cd5682d76", null ],
       [ "WorkQueue", "class_ogre_1_1_work_queue.html#a522d959bdec37026c5ad9eb2e2b189cc", null ],
       [ "~WorkQueue", "class_ogre_1_1_work_queue.html#a2e7a64f2d114bf2828355e83e43f8172", null ],
       [ "getWorkerThreadCount", "class_ogre_1_1_work_queue.html#a5684e530c6670b4bd08941ad06d9471a", null ],
