@@ -110,9 +110,9 @@ var group___math =
       [ "intWrite", "class_ogre_1_1_bitwise.html#afa88e9d32bbc468ac3ee803ee4228ca1", null ],
       [ "intRead", "class_ogre_1_1_bitwise.html#ad0fcaa2e4f445d1e9c1fb69291061dec", null ],
       [ "floatToHalf", "class_ogre_1_1_bitwise.html#aa02a9c5a117baf2da38ad562c2130681", null ],
-      [ "floatToHalfI", "class_ogre_1_1_bitwise.html#ad98268f6e1288301c0471e345e98cd1e", null ],
+      [ "floatToHalfI", "class_ogre_1_1_bitwise.html#ae135638c0cf50cd81dc6355325e0ed21", null ],
       [ "halfToFloat", "class_ogre_1_1_bitwise.html#abb3cbaa74865420859ba7b1061f8d3f3", null ],
-      [ "halfToFloatI", "class_ogre_1_1_bitwise.html#a7ccd62b11c082f76d4972e27896c6028", null ]
+      [ "halfToFloatI", "class_ogre_1_1_bitwise.html#ae009f79c8946b451ca7ea2ec599eaf3b", null ]
     ] ],
     [ "Ogre::ConvexBody", "class_ogre_1_1_convex_body.html", [
       [ "PolygonList", "class_ogre_1_1_convex_body.html#a4a13eb065fe856b0354d523394e9dfaa", null ],
@@ -137,7 +137,6 @@ var group___math =
       [ "mergePolygons", "class_ogre_1_1_convex_body.html#a4d33db4b9003a76a299649cede0c5557", null ],
       [ "operator==", "class_ogre_1_1_convex_body.html#a4e593920ea98ece61095ff1db3ad3150", null ],
       [ "operator!=", "class_ogre_1_1_convex_body.html#a575cb975ec5246022b2069991295ea42", null ],
-      [ "logInfo", "class_ogre_1_1_convex_body.html#a9f1b0dc680efee357dab08072d21d80f", null ],
       [ "_initialisePool", "class_ogre_1_1_convex_body.html#a59fb24ee9a509ade6490ad1d9aac16d7", null ],
       [ "_destroyPool", "class_ogre_1_1_convex_body.html#a0858a878ce677241ef5632b04a7ffea4", null ],
       [ "operator<<", "class_ogre_1_1_convex_body.html#a721a3cee58ba77cfed605fb589360e31", null ]
@@ -206,24 +205,24 @@ var group___math =
     ] ],
     [ "Ogre::EdgeData", "class_ogre_1_1_edge_data.html", [
       [ "Edge", "struct_ogre_1_1_edge_data_1_1_edge.html", [
-        [ "triIndex", "struct_ogre_1_1_edge_data_1_1_edge.html#ac5a9a9bc9dfc4d301058ee4e5c407f8f", null ],
-        [ "vertIndex", "struct_ogre_1_1_edge_data_1_1_edge.html#aad95e9ee5714e7413367fe6c8ba5dd20", null ],
-        [ "sharedVertIndex", "struct_ogre_1_1_edge_data_1_1_edge.html#a01c602e99ec1f7296cca73595e0ab55e", null ],
+        [ "triIndex", "struct_ogre_1_1_edge_data_1_1_edge.html#a6ba1f2209d1e9014c76c6acc8f626b96", null ],
+        [ "vertIndex", "struct_ogre_1_1_edge_data_1_1_edge.html#aa04881db8275f906b6209b67f77463ab", null ],
+        [ "sharedVertIndex", "struct_ogre_1_1_edge_data_1_1_edge.html#af8e9e2d2507bd8781c1b34020b4e774a", null ],
         [ "degenerate", "struct_ogre_1_1_edge_data_1_1_edge.html#a83b46b6487ee08a92449c8698fc8fc11", null ]
       ] ],
       [ "EdgeGroup", "struct_ogre_1_1_edge_data_1_1_edge_group.html", [
-        [ "vertexSet", "struct_ogre_1_1_edge_data_1_1_edge_group.html#a86c3d3704b9370b9601be1b1ef21316f", null ],
+        [ "vertexSet", "struct_ogre_1_1_edge_data_1_1_edge_group.html#a438a681003c85af04799a2f31988e7e9", null ],
         [ "vertexData", "struct_ogre_1_1_edge_data_1_1_edge_group.html#a1564edb1edb8ee140fd14ee683cae134", null ],
-        [ "triStart", "struct_ogre_1_1_edge_data_1_1_edge_group.html#ac1492097f952ad47429aed81471d1308", null ],
-        [ "triCount", "struct_ogre_1_1_edge_data_1_1_edge_group.html#a41b7c17951a90ca2a2518b497749fccf", null ],
+        [ "triStart", "struct_ogre_1_1_edge_data_1_1_edge_group.html#a30fb6c301c0f8cb5ffb940a31a6d6941", null ],
+        [ "triCount", "struct_ogre_1_1_edge_data_1_1_edge_group.html#af2d92af1d37412b1d16347129411659b", null ],
         [ "edges", "struct_ogre_1_1_edge_data_1_1_edge_group.html#ac1cefca66bbcb95e3a5b8967bbcd94f2", null ]
       ] ],
       [ "Triangle", "struct_ogre_1_1_edge_data_1_1_triangle.html", [
         [ "Triangle", "struct_ogre_1_1_edge_data_1_1_triangle.html#ac676a82255cafa821af2f4143160f2b1", null ],
-        [ "indexSet", "struct_ogre_1_1_edge_data_1_1_triangle.html#a77b9a1e73bea6c8cdbe3197a1311ad38", null ],
-        [ "vertexSet", "struct_ogre_1_1_edge_data_1_1_triangle.html#a8bf63fc09c7508d4c4863168442520db", null ],
-        [ "vertIndex", "struct_ogre_1_1_edge_data_1_1_triangle.html#af3610ee6a688cccc061392263bde1929", null ],
-        [ "sharedVertIndex", "struct_ogre_1_1_edge_data_1_1_triangle.html#a7d4ef75a8c204871c1829dbae25e5f7d", null ]
+        [ "indexSet", "struct_ogre_1_1_edge_data_1_1_triangle.html#a9d88cf8afcd62b9ee2c85cd7d1a4b47b", null ],
+        [ "vertexSet", "struct_ogre_1_1_edge_data_1_1_triangle.html#ac923c944013258cd8935c0e3650f2cc3", null ],
+        [ "vertIndex", "struct_ogre_1_1_edge_data_1_1_triangle.html#a56a6f686b4e40b69da5a356445cbf258", null ],
+        [ "sharedVertIndex", "struct_ogre_1_1_edge_data_1_1_triangle.html#a4aee7f563ba413db670ec0713476400d", null ]
       ] ],
       [ "TriangleFaceNormalList", "class_ogre_1_1_edge_data.html#a64e153ea58ec4f80064986f2d9db201d", null ],
       [ "TriangleLightFacingList", "class_ogre_1_1_edge_data.html#a40386af98df21e634c60b85d4434684b", null ],
@@ -246,7 +245,8 @@ var group___math =
       [ "addVertexData", "class_ogre_1_1_edge_list_builder.html#a9845e2f91660819164a627c661f5d107", null ],
       [ "addIndexData", "class_ogre_1_1_edge_list_builder.html#ae4af3550dfe4948680078a087377bfbf", null ],
       [ "build", "class_ogre_1_1_edge_list_builder.html#aa76568f1c0c49f3f9ff16dfb304f1571", null ],
-      [ "log", "class_ogre_1_1_edge_list_builder.html#a66aa1d48de5385be8233c8733af99186", null ]
+      [ "log", "class_ogre_1_1_edge_list_builder.html#a66aa1d48de5385be8233c8733af99186", null ],
+      [ "geometryLess", "class_ogre_1_1_edge_list_builder.html#a99d7b191452d6c4848576f0f3703e0a6", null ]
     ] ],
     [ "Ogre::Math", "class_ogre_1_1_math.html", [
       [ "RandomValueProvider", "class_ogre_1_1_math_1_1_random_value_provider.html", [
@@ -294,9 +294,9 @@ var group___math =
       [ "Sqrt", "class_ogre_1_1_math.html#a6bd8cafd36d77c6132c8e0d5061bf6d6", null ],
       [ "Sqrt", "class_ogre_1_1_math.html#a0945a29fc442a83685cff2998b02c348", null ],
       [ "InvSqrt", "class_ogre_1_1_math.html#a4d91be9e4d4f6bb826488f12d70a14f4", null ],
-      [ "UnitRandom", "class_ogre_1_1_math.html#a17da3bb870f8654628d6f429a144aea1", null ],
-      [ "RangeRandom", "class_ogre_1_1_math.html#a2de1fc1467a3b402bf435fd48cff356f", null ],
-      [ "SymmetricRandom", "class_ogre_1_1_math.html#a800db34eeeedfa6e6f40f003081c4e7e", null ],
+      [ "UnitRandom", "class_ogre_1_1_math.html#ac59f83c8d52180fb9e408bb92d808533", null ],
+      [ "RangeRandom", "class_ogre_1_1_math.html#afedce6fa2a819ea7a2420e10fb00a189", null ],
+      [ "SymmetricRandom", "class_ogre_1_1_math.html#aa7ee519f461ac44adb2a2c110fb8c194", null ],
       [ "SetRandomValueProvider", "class_ogre_1_1_math.html#a95f03d27b8c0fc1c7f7b947b3146c581", null ],
       [ "Tan", "class_ogre_1_1_math.html#a864447996cc63df237ce7c0a54796212", null ],
       [ "Tan", "class_ogre_1_1_math.html#a13b430149fbd5765175f59a6520cfc03", null ],
@@ -319,7 +319,6 @@ var group___math =
       [ "intersects", "class_ogre_1_1_math.html#aceb1ac86a8b0b4762ab0f0c97151f753", null ],
       [ "intersects", "group___math.html#gab3e9b9df69bd3255f3b64254e66c3321", null ],
       [ "intersects", "class_ogre_1_1_math.html#a144ae6243207c465be665a58082c878e", null ],
-      [ "intersects", "class_ogre_1_1_math.html#ab2ac15f1cb4470672165af53d2d40cf4", null ],
       [ "intersects", "group___math.html#ga04786a5e338650d6eafc987b394d221c", null ],
       [ "RealEqual", "class_ogre_1_1_math.html#a890336e0e4b6914024bfefd79c08f432", null ],
       [ "calculateTangentSpaceVector", "class_ogre_1_1_math.html#a115235aa59b977879a3b889169c7b0f0", null ],
@@ -418,15 +417,12 @@ var group___math =
       [ "IDENTITY", "class_ogre_1_1_matrix4.html#af2f61127dd1911c9ac2b4cbc0b4f3668", null ],
       [ "CLIPSPACE2DTOIMAGESPACE", "class_ogre_1_1_matrix4.html#a08a798c0d8c8290dbc0287ca6561f549", null ]
     ] ],
-    [ "Ogre::NumericSolver", "class_ogre_1_1_numeric_solver.html", [
-      [ "solveNxNLinearSysDestr", "class_ogre_1_1_numeric_solver.html#a094e15a506a810ec76f61869673249d3", null ]
-    ] ],
     [ "Ogre::OptimisedUtil", "class_ogre_1_1_optimised_util.html", [
       [ "OptimisedUtil", "class_ogre_1_1_optimised_util.html#a4f137d0ced0f82abd042d9b4eb99b105", null ],
       [ "~OptimisedUtil", "class_ogre_1_1_optimised_util.html#a7d548511ecbd6b39d6d1689ce30db8f2", null ],
       [ "getImplementation", "class_ogre_1_1_optimised_util.html#a6ccca012f8a3041746c0694c8ed595b2", null ],
       [ "softwareVertexSkinning", "class_ogre_1_1_optimised_util.html#ae0e1fe21bead4433568514258a2fb965", null ],
-      [ "softwareVertexMorph", "class_ogre_1_1_optimised_util.html#a431efac44c070695de7011243b13b7af", null ],
+      [ "softwareVertexMorph", "class_ogre_1_1_optimised_util.html#a3d72d88494aee0c16ddc21c7c169b0ea", null ],
       [ "concatenateAffineMatrices", "class_ogre_1_1_optimised_util.html#aa625f93ec757b2820935369c9884c45d", null ],
       [ "calculateFaceNormals", "class_ogre_1_1_optimised_util.html#a7fa20b34357e375a489383f0ccb4a15c", null ],
       [ "calculateLightFacing", "class_ogre_1_1_optimised_util.html#a9270e6273fcf190d039030bd5de1df2f", null ],
@@ -496,17 +492,17 @@ var group___math =
     [ "Ogre::Quaternion", "class_ogre_1_1_quaternion.html", [
       [ "Quaternion", "class_ogre_1_1_quaternion.html#ab58dc0c4c04d0579ce9321a719f10d5c", null ],
       [ "Quaternion", "class_ogre_1_1_quaternion.html#a2914eb2c4929ca33650c73d6c0241e59", null ],
-      [ "Quaternion", "class_ogre_1_1_quaternion.html#ac9d8f10fbe774266b497bb3cd94afc8b", null ],
+      [ "Quaternion", "class_ogre_1_1_quaternion.html#a9b45997a81d85662350808b7043d535d", null ],
       [ "Quaternion", "class_ogre_1_1_quaternion.html#acdcb70a4f122452b6fa70d7cf5ce3cf3", null ],
       [ "Quaternion", "class_ogre_1_1_quaternion.html#a7f25c623d95186b58f6367dcd097a5ba", null ],
       [ "Quaternion", "class_ogre_1_1_quaternion.html#a1140011dc0793a81c55f2d078c8c964c", null ],
       [ "Quaternion", "class_ogre_1_1_quaternion.html#a3ccc60338011887023b397a02a7f3336", null ],
-      [ "Quaternion", "class_ogre_1_1_quaternion.html#ada6a795014b78dac392b4f6ee95cca62", null ],
+      [ "Quaternion", "class_ogre_1_1_quaternion.html#a1ca81bd9d57e43cf23582c898e5fdd34", null ],
       [ "swap", "class_ogre_1_1_quaternion.html#a54dcd575915c7b7ddb65b8cb249de521", null ],
-      [ "operator[]", "class_ogre_1_1_quaternion.html#a17f1a856b85c07d9f8cc8358f4850de9", null ],
-      [ "operator[]", "class_ogre_1_1_quaternion.html#abda7292b2d6260b48995bdfb36e650fe", null ],
-      [ "ptr", "class_ogre_1_1_quaternion.html#ae0c599051d1bbf85e4485a324e06eb3c", null ],
-      [ "ptr", "class_ogre_1_1_quaternion.html#ab879c439f0bae628904eeb49d96a451c", null ],
+      [ "operator[]", "class_ogre_1_1_quaternion.html#a390c026412bb0e687f20cfe1bc0ada66", null ],
+      [ "operator[]", "class_ogre_1_1_quaternion.html#a8807c9887101c06763af12b57f9caa49", null ],
+      [ "ptr", "class_ogre_1_1_quaternion.html#a8233292eaf0b5ae0e9f76af16de2e6ba", null ],
+      [ "ptr", "class_ogre_1_1_quaternion.html#ae93aacfa270c23b597e9d03431498927", null ],
       [ "FromRotationMatrix", "class_ogre_1_1_quaternion.html#ae6c3bfed7176355cf2461567f89a15b1", null ],
       [ "ToRotationMatrix", "class_ogre_1_1_quaternion.html#a6005735392c9b07901b8fe160c959f46", null ],
       [ "FromAngleAxis", "class_ogre_1_1_quaternion.html#ac3328c1bb86d17e870c57d52720e2e32", null ],
@@ -523,13 +519,13 @@ var group___math =
       [ "operator+", "class_ogre_1_1_quaternion.html#aac3debd2245b0dcefff4ce2fda46eef1", null ],
       [ "operator-", "class_ogre_1_1_quaternion.html#a98993e6f63209a39149d132623bbf41b", null ],
       [ "operator*", "class_ogre_1_1_quaternion.html#af05da43b746cf5b9bc2dcaf3aa4db2b9", null ],
-      [ "operator*", "class_ogre_1_1_quaternion.html#a93055115c607f65bb6eefade1656ae2c", null ],
+      [ "operator*", "class_ogre_1_1_quaternion.html#af6725db29a7dbc5d6a9071b86ce43714", null ],
       [ "operator-", "class_ogre_1_1_quaternion.html#a24b15dc994247753b7a8064b6a13e2d6", null ],
       [ "operator==", "class_ogre_1_1_quaternion.html#af292a9ed18e3da0bda0fbe114f60cdec", null ],
       [ "operator!=", "class_ogre_1_1_quaternion.html#aec199d4e6af6c82c4026d012eae570cb", null ],
-      [ "Dot", "class_ogre_1_1_quaternion.html#a0944c2a3f92298f9b5403a6b3f1c331b", null ],
-      [ "Norm", "class_ogre_1_1_quaternion.html#afa625c96c21dd12394d4ae1bcf792601", null ],
-      [ "normalise", "class_ogre_1_1_quaternion.html#a55503b3b82bad400c3d0c74456c82b29", null ],
+      [ "Dot", "class_ogre_1_1_quaternion.html#a9e14e6aa96e714397b31929299ca681d", null ],
+      [ "Norm", "class_ogre_1_1_quaternion.html#a353aafd21ec10c8c07f04472ae6c32b8", null ],
+      [ "normalise", "class_ogre_1_1_quaternion.html#aee94ec9c7de50fe7f774ae4c7e760b65", null ],
       [ "Inverse", "class_ogre_1_1_quaternion.html#ae370a6b879cf4d03fb85d8ce510705c1", null ],
       [ "UnitInverse", "class_ogre_1_1_quaternion.html#a821a464cce9a81d5d20c620025043851", null ],
       [ "Exp", "class_ogre_1_1_quaternion.html#ae9c8590b89ed8c8b48a5f188383aeadc", null ],
@@ -539,22 +535,22 @@ var group___math =
       [ "getPitch", "class_ogre_1_1_quaternion.html#ae4ffd43e74b8b07ddfbc5810a9e6e7ad", null ],
       [ "getYaw", "class_ogre_1_1_quaternion.html#a15c912e62c9abcb3335de205cdf30c2d", null ],
       [ "equals", "class_ogre_1_1_quaternion.html#aaf249bc76b399f92c0c2f93377b032ab", null ],
-      [ "orientationEquals", "class_ogre_1_1_quaternion.html#a8f89d39271da216b0c5b9375afc80b0c", null ],
+      [ "orientationEquals", "class_ogre_1_1_quaternion.html#a1df622b500ec13bf405155274e23aa32", null ],
       [ "Slerp", "class_ogre_1_1_quaternion.html#ab0c47f1a7308ac4c17db9f9ddb6e4a72", null ],
       [ "SlerpExtraSpins", "class_ogre_1_1_quaternion.html#a25fb3bc0f11e6a676fb5c47347a79579", null ],
       [ "Intermediate", "class_ogre_1_1_quaternion.html#a838d0736819d496073d99f3f74d0cac1", null ],
       [ "Squad", "class_ogre_1_1_quaternion.html#a5f43da8b8aa579e02035eecff89e16a5", null ],
       [ "nlerp", "class_ogre_1_1_quaternion.html#a16987149991882e148170fe3f1c7da4b", null ],
       [ "isNaN", "class_ogre_1_1_quaternion.html#ac566d9e46f5c1b6368047c132e82a829", null ],
-      [ "operator*", "class_ogre_1_1_quaternion.html#ab0b2050272ab83353a620410d40075d8", null ],
+      [ "operator*", "class_ogre_1_1_quaternion.html#a4aea5016e6a48eebee6a31f0a298825e", null ],
       [ "operator<<", "class_ogre_1_1_quaternion.html#a34071780e500a7d64d02a29a41fb6991", null ],
-      [ "msEpsilon", "class_ogre_1_1_quaternion.html#a22dbde3786cbac794fe77c3cc0035ad9", null ],
+      [ "msEpsilon", "class_ogre_1_1_quaternion.html#a6b53296360cc166c62533cff8f1edcc2", null ],
       [ "ZERO", "class_ogre_1_1_quaternion.html#a44f3c000c8f1ea2759c2e724e04bf86b", null ],
       [ "IDENTITY", "class_ogre_1_1_quaternion.html#a441b8d52549e1dedec27420325a313ef", null ],
-      [ "w", "class_ogre_1_1_quaternion.html#ac88591d3076fc8bb2f0d373801c9971e", null ],
-      [ "x", "class_ogre_1_1_quaternion.html#a64260ec27b906a629ce102e8bf96f8b7", null ],
-      [ "y", "class_ogre_1_1_quaternion.html#ac57b1d08204bda6c189dccf4ece80817", null ],
-      [ "z", "class_ogre_1_1_quaternion.html#a3aa2caf369851e7535a431ee0e9841d5", null ]
+      [ "w", "class_ogre_1_1_quaternion.html#af3424f1e07092c0ffe293d18b277a04f", null ],
+      [ "x", "class_ogre_1_1_quaternion.html#a32c5680516b41bc4ba3159bf4d4abaf1", null ],
+      [ "y", "class_ogre_1_1_quaternion.html#aa7328cd3883a92ee9c9322805d038f11", null ],
+      [ "z", "class_ogre_1_1_quaternion.html#a31ec84a931236554c0c17e37bf5ace97", null ]
     ] ],
     [ "Ogre::Radian", "class_ogre_1_1_radian.html", [
       [ "Radian", "class_ogre_1_1_radian.html#a60fa2965b76b7dda53384610683d5c54", null ],
@@ -667,7 +663,8 @@ var group___math =
       [ "getSplitMirrored", "class_ogre_1_1_tangent_space_calc.html#aff282be1144cc20f9eb669fcb33393c2", null ],
       [ "setSplitRotated", "class_ogre_1_1_tangent_space_calc.html#a3b9ef4ec951f3a95e40697d7c6637a7d", null ],
       [ "getSplitRotated", "class_ogre_1_1_tangent_space_calc.html#a2108f7fcd81d75bf2417f2ca45244f3e", null ],
-      [ "build", "class_ogre_1_1_tangent_space_calc.html#a57b5fd6b859dd9378bcebeb6882352d1", null ]
+      [ "build", "class_ogre_1_1_tangent_space_calc.html#a6a40ae15c9fd4912a8bd63b91997bbe8", null ],
+      [ "build", "class_ogre_1_1_tangent_space_calc.html#aef80f3ebc3e34e9fc0cca9a7ebb25d8b", null ]
     ] ],
     [ "Ogre::TransformBase< rows, T >", "class_ogre_1_1_transform_base.html", [
       [ "TransformBase", "class_ogre_1_1_transform_base.html#acf3bcb9d0a7bffe8a2de6bb629db7c22", null ],
@@ -699,7 +696,7 @@ var group___math =
       [ "Vector", "class_ogre_1_1_vector.html#ae6f3059c85986465741bf40fbe5ae348", null ],
       [ "Vector", "class_ogre_1_1_vector.html#af56d266815fd97c34840189945b67cfa", null ],
       [ "Vector", "class_ogre_1_1_vector.html#a8d9fe8c6b9bcb237278eae92a5e95a58", null ],
-      [ "Vector", "class_ogre_1_1_vector.html#a546a336592df20866c2bb52fa615ddf0", null ],
+      [ "Vector", "class_ogre_1_1_vector.html#a965a21067d3f872afec2621d81b798bb", null ],
       [ "Vector", "class_ogre_1_1_vector.html#a389e8be5818ba2c48c525441ce862f06", null ],
       [ "Vector", "class_ogre_1_1_vector.html#a08b4b207bff9bb43d77fe6133a0e4980", null ],
       [ "Vector", "class_ogre_1_1_vector.html#a921c3ae9fd07f00bf5abcf39de7e5640", null ],
@@ -761,6 +758,10 @@ var group___math =
     [ "Ogre::VectorBase< 2, Real >", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html", [
       [ "VectorBase", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#abdef156b8ae9ca99b2f6e63e545f93a3", null ],
       [ "VectorBase", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#ae2f35d4cb19c32de559b6815badd425b", null ],
+      [ "VectorBase", "struct_ogre_1_1_vector_base.html#a3d840979e2f40a0c01c5bac850977da0", null ],
+      [ "VectorBase", "struct_ogre_1_1_vector_base.html#a4780e28e244b3fb69d259d161b01e9a1", null ],
+      [ "VectorBase", "struct_ogre_1_1_vector_base.html#a9b095dcc7d2812780a6cbc1163568785", null ],
+      [ "VectorBase", "struct_ogre_1_1_vector_base.html#af9ea7a5d9919e101efcca5e41b5d2705", null ],
       [ "ptr", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a4386098987c58adbe2dd4fedb0d19eed", null ],
       [ "ptr", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a0c9cad7eaa9ffc11623f4bc6ae915ff2", null ],
       [ "midPoint", "group___math.html#ga4345346666fd54473efb51a8d194f5e0", null ],
@@ -768,6 +769,8 @@ var group___math =
       [ "perpendicular", "group___math.html#ga00e57f3eda32e31277c439e6a9c929a1", null ],
       [ "randomDeviant", "group___math.html#gaba43517feb82c40ccf1cc571f519866c", null ],
       [ "angleTo", "group___math.html#ga7a92915df275eae8161441024d88c815", null ],
+      [ "ptr", "struct_ogre_1_1_vector_base.html#a68f9ad334839138f1bf767a517f6ba0b", null ],
+      [ "ptr", "struct_ogre_1_1_vector_base.html#a9caacd16230bd6ac7c00bcf40b05b055", null ],
       [ "x", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a95a20cb8d244732ea5dadff4b8da7111", null ],
       [ "y", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a5661dd38b03840383dc1a0cbea9199d9", null ],
       [ "ZERO", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#af6df06c614a141cc90fb9fe28b0c34f9", null ],
@@ -775,16 +778,20 @@ var group___math =
       [ "UNIT_Y", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#ab771b243b99665aaff02505c273be9ee", null ],
       [ "NEGATIVE_UNIT_X", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a1786bcda5c79f91d70d8d0789ed6ee66", null ],
       [ "NEGATIVE_UNIT_Y", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a5cf013c152017f5af5e3b4b0a93d726c", null ],
-      [ "UNIT_SCALE", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a979837f10b7068528efc6802742f5509", null ]
+      [ "UNIT_SCALE", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a979837f10b7068528efc6802742f5509", null ],
+      [ "data", "struct_ogre_1_1_vector_base.html#a1b21ec054398dd1389acf0be59e287a5", null ]
     ] ],
     [ "Ogre::VectorBase< 3, Real >", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html", [
       [ "VectorBase", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#afcd99d9db1e0e25bab9f7bea0d4a190a", null ],
       [ "VectorBase", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a9099515f00fb4c790492037a4816c1a9", null ],
+      [ "VectorBase", "struct_ogre_1_1_vector_base.html#a3d840979e2f40a0c01c5bac850977da0", null ],
+      [ "VectorBase", "struct_ogre_1_1_vector_base.html#a4780e28e244b3fb69d259d161b01e9a1", null ],
+      [ "VectorBase", "struct_ogre_1_1_vector_base.html#a9b095dcc7d2812780a6cbc1163568785", null ],
+      [ "VectorBase", "struct_ogre_1_1_vector_base.html#af9ea7a5d9919e101efcca5e41b5d2705", null ],
       [ "ptr", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a7f6ccde75703a0965eb4bce5f99eeac2", null ],
       [ "ptr", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#ad4f4f774fd3c8c2072e659ab36b12f93", null ],
       [ "crossProduct", "group___math.html#gafe9157bbe30e69645edd5c3eddea141f", null ],
       [ "perpendicular", "group___math.html#ga5b50a2b2697ec1ac684d66af82a03296", null ],
-      [ "operator=", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a370e08e612cf8542391bc98def779a98", null ],
       [ "absDotProduct", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a2e8982298226fccf166445c68506f087", null ],
       [ "midPoint", "group___math.html#ga929562516cfb30c38030d9df84945bf3", null ],
       [ "randomDeviant", "group___math.html#ga4f54a2dd6b60dd327fcc8347fc4d853d", null ],
@@ -792,6 +799,8 @@ var group___math =
       [ "positionCloses", "group___math.html#ga24dd46458beb0ea8175bfbf916f09e47", null ],
       [ "directionEquals", "group___math.html#gad67db81d99c63e2483ff8bc314bfd36c", null ],
       [ "primaryAxis", "group___math.html#gad52e72c687842e8475a5f24cde8cd858", null ],
+      [ "ptr", "struct_ogre_1_1_vector_base.html#a68f9ad334839138f1bf767a517f6ba0b", null ],
+      [ "ptr", "struct_ogre_1_1_vector_base.html#a9caacd16230bd6ac7c00bcf40b05b055", null ],
       [ "x", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a2e6b3a89e26268bde6f6347f363a6bd1", null ],
       [ "y", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a5c89e45e32e3cf01cc54dc05ad6704e5", null ],
       [ "z", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a0a242b15c4c3a7181cc5a371b3f86fe3", null ],
@@ -802,20 +811,26 @@ var group___math =
       [ "NEGATIVE_UNIT_X", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#aff2d9ac3a0f7653fc9e5dcef71e80397", null ],
       [ "NEGATIVE_UNIT_Y", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a42a88148edf0e38db8a1fb4ab5d5b499", null ],
       [ "NEGATIVE_UNIT_Z", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#ab7cc41b4120afa20f7d74d918ea35dc3", null ],
-      [ "UNIT_SCALE", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a89fbc371d11d0363db247d6ef1fa7afa", null ]
+      [ "UNIT_SCALE", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a89fbc371d11d0363db247d6ef1fa7afa", null ],
+      [ "data", "struct_ogre_1_1_vector_base.html#a1b21ec054398dd1389acf0be59e287a5", null ]
     ] ],
     [ "Ogre::VectorBase< 4, Real >", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html", [
       [ "VectorBase", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a50e16e1f758092ba72398d1f71d0bc60", null ],
       [ "VectorBase", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#ad1269630b80565f80da462630bd7d5ad", null ],
+      [ "VectorBase", "struct_ogre_1_1_vector_base.html#a3d840979e2f40a0c01c5bac850977da0", null ],
+      [ "VectorBase", "struct_ogre_1_1_vector_base.html#a4780e28e244b3fb69d259d161b01e9a1", null ],
+      [ "VectorBase", "struct_ogre_1_1_vector_base.html#a9b095dcc7d2812780a6cbc1163568785", null ],
+      [ "VectorBase", "struct_ogre_1_1_vector_base.html#af9ea7a5d9919e101efcca5e41b5d2705", null ],
       [ "ptr", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a687504a38534d7a9cf95fcc56a0ec048", null ],
       [ "ptr", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a363e2d1a068e15325d2f36251c194415", null ],
-      [ "operator=", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#adc51bff167c65c6a79f5e12c4ddd781a", null ],
-      [ "operator=", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a03d16ff06765af1084977325611d6a0f", null ],
+      [ "ptr", "struct_ogre_1_1_vector_base.html#a68f9ad334839138f1bf767a517f6ba0b", null ],
+      [ "ptr", "struct_ogre_1_1_vector_base.html#a9caacd16230bd6ac7c00bcf40b05b055", null ],
       [ "x", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#ab251c7a2d54e44ad406b99f94fb7bcfd", null ],
       [ "y", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a91aaf7e577df85ef9bb8ec991e85475d", null ],
       [ "z", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a522a1880968a4814d3fca4eeb2a24e29", null ],
       [ "w", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a6816f6bd970974e2fa9e1b0289a7994d", null ],
-      [ "ZERO", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#ac3d942ae568cc586e83f0ea4415bad64", null ]
+      [ "ZERO", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#ac3d942ae568cc586e83f0ea4415bad64", null ],
+      [ "data", "struct_ogre_1_1_vector_base.html#a1b21ec054398dd1389acf0be59e287a5", null ]
     ] ],
     [ "Ogre::RayTestResult", "group___math.html#ga3f791f5ff19bd8395f0008085e68bf10", null ],
     [ "Ogre::PlaneList", "group___math.html#ga4cfa65f236aec1767fc85022e87059a0", null ],
