@@ -106,6 +106,7 @@ var hierarchy =
       [ "Ogre::ConfigFile", "class_ogre_1_1_config_file.html", null ]
     ] ],
     [ "ControllerAlloc", null, [
+      [ "Ogre::Controller< float >", "class_ogre_1_1_controller.html", null ],
       [ "Ogre::ControllerFunction< float >", "class_ogre_1_1_controller_function.html", [
         [ "Ogre::AnimationControllerFunction", "class_ogre_1_1_animation_controller_function.html", null ],
         [ "Ogre::LinearControllerFunction", "class_ogre_1_1_linear_controller_function.html", null ],
@@ -340,12 +341,13 @@ var hierarchy =
     [ "Ogre::EntityMaterialLodChangedEvent", "struct_ogre_1_1_entity_material_lod_changed_event.html", null ],
     [ "Ogre::EntityMeshLodChangedEvent", "struct_ogre_1_1_entity_mesh_lod_changed_event.html", null ],
     [ "Ogre::ExceptionFactory", "class_ogre_1_1_exception_factory.html", null ],
-    [ "Ogre::FactoryObj< T >", "class_ogre_1_1_factory_obj.html", [
-      [ "Ogre::BillboardParticleRendererFactory", "class_ogre_1_1_billboard_particle_renderer_factory.html", null ]
-    ] ],
+    [ "Ogre::FactoryObj< T >", "class_ogre_1_1_factory_obj.html", null ],
     [ "Ogre::FactoryObj< Archive >", "class_ogre_1_1_factory_obj.html", [
       [ "Ogre::ArchiveFactory", "class_ogre_1_1_archive_factory.html", null ]
     ] ],
+    [ "Ogre::FactoryObj< ParticleSystemRenderer >", "class_ogre_1_1_factory_obj.html", [
+      [ "Ogre::BillboardParticleRendererFactory", "class_ogre_1_1_billboard_particle_renderer_factory.html", null ]
+    ] ],
     [ "Ogre::FileInfo", "struct_ogre_1_1_file_info.html", null ],
     [ "Ogre::FrameEvent", "struct_ogre_1_1_frame_event.html", null ],
     [ "Ogre::FrameListener", "class_ogre_1_1_frame_listener.html", [
@@ -389,10 +391,79 @@ var hierarchy =
     [ "Ogre::isPodLike< unsigned short >", "struct_ogre_1_1is_pod_like_3_01unsigned_01short_01_4.html", null ],
     [ "Ogre::IteratorWrapper< T, IteratorType, ValType >", "class_ogre_1_1_iterator_wrapper.html", null ],
     [ "Ogre::IteratorWrapper< T, IteratorType, T::mapped_type >", "class_ogre_1_1_iterator_wrapper.html", [
-      [ "Ogre::MapIteratorWrapper< T, IteratorType >", "class_ogre_1_1_map_iterator_wrapper.html", null ]
+      [ "Ogre::MapIteratorWrapper< T, IteratorType >", "class_ogre_1_1_map_iterator_wrapper.html", [
+        [ "Ogre::ConstMapIterator< NodeTrackList >", "class_ogre_1_1_const_map_iterator.html", null ],
+        [ "Ogre::ConstMapIterator< NumericTrackList >", "class_ogre_1_1_const_map_iterator.html", null ],
+        [ "Ogre::ConstMapIterator< VertexTrackList >", "class_ogre_1_1_const_map_iterator.html", null ],
+        [ "Ogre::ConstMapIterator< AnimationStateMap >", "class_ogre_1_1_const_map_iterator.html", null ],
+        [ "Ogre::ConstMapIterator< GpuConstantDefinitionMap >", "class_ogre_1_1_const_map_iterator.html", null ],
+        [ "Ogre::ConstMapIterator< InstanceBatchMap >", "class_ogre_1_1_const_map_iterator.html", null ],
+        [ "Ogre::ConstMapIterator< VertexOffsetMap >", "class_ogre_1_1_const_map_iterator.html", null ],
+        [ "Ogre::ConstMapIterator< NormalsMap >", "class_ogre_1_1_const_map_iterator.html", null ],
+        [ "Ogre::ConstMapIterator< PriorityMap >", "class_ogre_1_1_const_map_iterator.html", null ],
+        [ "Ogre::ConstMapIterator< MovableObjectFactoryMap >", "class_ogre_1_1_const_map_iterator.html", null ],
+        [ "Ogre::ConstMapIterator< TerrainSlotMap >", "class_ogre_1_1_const_map_iterator.html", null ],
+        [ "Ogre::MapIterator< AnimationStateMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< ArchiveMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< SettingsMultiMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< SettingsBySection >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< VertexBoneAssignmentList >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< ParticleAffectorFactoryMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< ParticleEmitterFactoryMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< ParticleSystemRendererFactoryMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< ParticleTemplateMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< VertexOffsetMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< NormalsMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< PriorityMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< ResourceManagerMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< ResourceHandleMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< CameraList >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< AnimationList >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< MovableObjectMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< MaterialBucketMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< RegionMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< ChildMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< ChildContainerMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< OverlayMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< TerrainSlotMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< PCZoneFactoryMap >", "class_ogre_1_1_map_iterator.html", null ],
+        [ "Ogre::MapIterator< ZoneMap >", "class_ogre_1_1_map_iterator.html", null ]
+      ] ]
     ] ],
     [ "Ogre::IteratorWrapper< T, IteratorType, T::value_type >", "class_ogre_1_1_iterator_wrapper.html", [
-      [ "Ogre::VectorIteratorWrapper< T, IteratorType >", "class_ogre_1_1_vector_iterator_wrapper.html", null ]
+      [ "Ogre::VectorIteratorWrapper< T, IteratorType >", "class_ogre_1_1_vector_iterator_wrapper.html", [
+        [ "Ogre::ConstVectorIterator< EnabledAnimationStateList >", "class_ogre_1_1_const_vector_iterator.html", null ],
+        [ "Ogre::ConstVectorIterator< InstanceBatchVec >", "class_ogre_1_1_const_vector_iterator.html", null ],
+        [ "Ogre::ConstVectorIterator< PoseRefList >", "class_ogre_1_1_const_vector_iterator.html", null ],
+        [ "Ogre::ConstVectorIterator< LodValueList >", "class_ogre_1_1_const_vector_iterator.html", null ],
+        [ "Ogre::ConstVectorIterator< PoseList >", "class_ogre_1_1_const_vector_iterator.html", null ],
+        [ "Ogre::ConstVectorIterator< ChildNodeMap >", "class_ogre_1_1_const_vector_iterator.html", null ],
+        [ "Ogre::ConstVectorIterator< TextureUnitStates >", "class_ogre_1_1_const_vector_iterator.html", null ],
+        [ "Ogre::ConstVectorIterator< NodeList >", "class_ogre_1_1_const_vector_iterator.html", null ],
+        [ "Ogre::ConstVectorIterator< ShadowTextureConfigList >", "class_ogre_1_1_const_vector_iterator.html", null ],
+        [ "Ogre::ConstVectorIterator< ObjectMap >", "class_ogre_1_1_const_vector_iterator.html", null ],
+        [ "Ogre::ConstVectorIterator< LinkedSkeletonAnimSourceList >", "class_ogre_1_1_const_vector_iterator.html", null ],
+        [ "Ogre::ConstVectorIterator< GPUVendorRuleList >", "class_ogre_1_1_const_vector_iterator.html", null ],
+        [ "Ogre::ConstVectorIterator< GPUDeviceNameRuleList >", "class_ogre_1_1_const_vector_iterator.html", null ],
+        [ "Ogre::VectorIterator< Passes >", "class_ogre_1_1_vector_iterator.html", null ],
+        [ "Ogre::VectorIterator< TargetPasses >", "class_ogre_1_1_vector_iterator.html", null ],
+        [ "Ogre::VectorIterator< TextureDefinitions >", "class_ogre_1_1_vector_iterator.html", null ],
+        [ "Ogre::VectorIterator< Techniques >", "class_ogre_1_1_vector_iterator.html", null ],
+        [ "Ogre::VectorIterator< Instances >", "class_ogre_1_1_vector_iterator.html", null ],
+        [ "Ogre::VectorIterator< TextureList >", "class_ogre_1_1_vector_iterator.html", null ],
+        [ "Ogre::VectorIterator< ChildObjectList >", "class_ogre_1_1_vector_iterator.html", null ],
+        [ "Ogre::VectorIterator< PoseRefList >", "class_ogre_1_1_vector_iterator.html", null ],
+        [ "Ogre::VectorIterator< SubMeshList >", "class_ogre_1_1_vector_iterator.html", null ],
+        [ "Ogre::VectorIterator< PoseList >", "class_ogre_1_1_vector_iterator.html", null ],
+        [ "Ogre::VectorIterator< ChildNodeMap >", "class_ogre_1_1_vector_iterator.html", null ],
+        [ "Ogre::VectorIterator< TextureUnitStates >", "class_ogre_1_1_vector_iterator.html", null ],
+        [ "Ogre::VectorIterator< ObjectMap >", "class_ogre_1_1_vector_iterator.html", null ],
+        [ "Ogre::VectorIterator< ShadowRenderableList >", "class_ogre_1_1_vector_iterator.html", null ],
+        [ "Ogre::VectorIterator< BoneList >", "class_ogre_1_1_vector_iterator.html", null ],
+        [ "Ogre::VectorIterator< GeometryBucketList >", "class_ogre_1_1_vector_iterator.html", null ],
+        [ "Ogre::VectorIterator< LODBucketList >", "class_ogre_1_1_vector_iterator.html", null ],
+        [ "Ogre::VectorIterator< IlluminationPassList >", "class_ogre_1_1_vector_iterator.html", null ]
+      ] ]
     ] ],
     [ "Ogre::IteratorWrapper< T, T::const_iterator, T::mapped_type >", "class_ogre_1_1_iterator_wrapper.html", [
       [ "Ogre::MapIteratorWrapper< T, T::const_iterator >", "class_ogre_1_1_map_iterator_wrapper.html", [
@@ -470,6 +541,7 @@ var hierarchy =
     [ "Ogre::Page", "class_ogre_1_1_page.html", null ],
     [ "Ogre::PageProvider", "class_ogre_1_1_page_provider.html", null ],
     [ "Ogre::ParamCommand", null, [
+      [ "Ogre::SimpleParamCommand< _Class, const String &, getter, setter >", "class_ogre_1_1_simple_param_command_3_01___class_00_01const_01_string_01_6_00_01getter_00_01setter_01_4.html", null ],
       [ "Ogre::AreaEmitter::CmdDepth", "class_ogre_1_1_area_emitter_1_1_cmd_depth.html", null ],
       [ "Ogre::AreaEmitter::CmdHeight", "class_ogre_1_1_area_emitter_1_1_cmd_height.html", null ],
       [ "Ogre::AreaEmitter::CmdWidth", "class_ogre_1_1_area_emitter_1_1_cmd_width.html", null ],
@@ -794,43 +866,24 @@ var hierarchy =
       [ "Ogre::TextureManager", "class_ogre_1_1_texture_manager.html", null ]
     ] ],
     [ "Ogre::SmallVectorBase", "class_ogre_1_1_small_vector_base.html", [
-      [ "Ogre::SmallVectorTemplateCommon< Edge >", "class_ogre_1_1_small_vector_template_common.html", [
-        [ "Ogre::SmallVectorTemplateBase< Edge, isPodLike< Edge >::value >", "class_ogre_1_1_small_vector_template_base.html", [
-          [ "Ogre::SmallVectorImpl< Edge >", "class_ogre_1_1_small_vector_impl.html", [
-            [ "Ogre::SmallVector< Edge, S >", "class_ogre_1_1_small_vector.html", [
-              [ "Ogre::VectorSet< Edge, 8 >", "struct_ogre_1_1_vector_set.html", null ]
-            ] ]
-          ] ]
-        ] ]
-      ] ],
-      [ "Ogre::SmallVectorTemplateCommon< Line * >", "class_ogre_1_1_small_vector_template_common.html", [
-        [ "Ogre::SmallVectorTemplateBase< Line *, isPodLike< Line * >::value >", "class_ogre_1_1_small_vector_template_base.html", [
-          [ "Ogre::SmallVectorImpl< Line * >", "class_ogre_1_1_small_vector_impl.html", [
-            [ "Ogre::SmallVector< Line *, S >", "class_ogre_1_1_small_vector.html", [
-              [ "Ogre::VectorSet< Line *, 7 >", "struct_ogre_1_1_vector_set.html", null ]
-            ] ]
-          ] ]
-        ] ]
-      ] ],
-      [ "Ogre::SmallVectorTemplateCommon< Triangle * >", "class_ogre_1_1_small_vector_template_common.html", [
-        [ "Ogre::SmallVectorTemplateBase< Triangle *, isPodLike< Triangle * >::value >", "class_ogre_1_1_small_vector_template_base.html", [
-          [ "Ogre::SmallVectorImpl< Triangle * >", "class_ogre_1_1_small_vector_impl.html", [
-            [ "Ogre::SmallVector< Triangle *, S >", "class_ogre_1_1_small_vector.html", [
-              [ "Ogre::VectorSet< Triangle *, 7 >", "struct_ogre_1_1_vector_set.html", null ]
-            ] ]
-          ] ]
-        ] ]
-      ] ],
       [ "Ogre::SmallVectorTemplateCommon< T >", "class_ogre_1_1_small_vector_template_common.html", [
         [ "Ogre::SmallVectorTemplateBase< T, isPodLike< T >::value >", "class_ogre_1_1_small_vector_template_base.html", [
+          [ "Ogre::U< T >", "class_ogre_1_1_small_vector_impl.html", null ],
           [ "Ogre::SmallVectorImpl< T >", "class_ogre_1_1_small_vector_impl.html", [
+            [ "Ogre::iterator< T, S >", "class_ogre_1_1_small_vector.html", null ],
             [ "Ogre::SmallVector< T, S >", "class_ogre_1_1_small_vector.html", [
               [ "Ogre::VectorSet< T, S >", "struct_ogre_1_1_vector_set.html", null ]
             ] ],
-            [ "Ogre::SmallVector< T, N >", "class_ogre_1_1_small_vector.html", null ],
+            [ "Ogre::SmallVector< T, 0 >", "class_ogre_1_1_small_vector_3_01_t_00_010_01_4.html", null ],
+            [ "Ogre::SmallVector< T, N >", "class_ogre_1_1_small_vector.html", [
+              [ "Ogre::VectorSet< Edge, 8 >", "struct_ogre_1_1_vector_set.html", null ],
+              [ "Ogre::VectorSet< Line *, 7 >", "struct_ogre_1_1_vector_set.html", null ],
+              [ "Ogre::VectorSet< Triangle *, 7 >", "struct_ogre_1_1_vector_set.html", null ]
+            ] ],
             [ "Ogre::SmallVector< T, 0 >", "class_ogre_1_1_small_vector_3_01_t_00_010_01_4.html", null ]
           ] ]
         ] ],
+        [ "Ogre::SmallVectorTemplateBase< T, true >", "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html", null ],
         [ "Ogre::SmallVectorTemplateBase< T, isPodLike >", "class_ogre_1_1_small_vector_template_base.html", null ],
         [ "Ogre::SmallVectorTemplateBase< T, true >", "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html", null ]
       ] ]
@@ -839,7 +892,6 @@ var hierarchy =
     [ "Ogre::SPFMNone", "struct_ogre_1_1_s_p_f_m_none.html", null ],
     [ "Ogre::Sphere", "class_ogre_1_1_sphere.html", null ],
     [ "Ogre::StaticCache< cacheSize >", "class_ogre_1_1_static_cache.html", null ],
-    [ "Ogre::StaticCache< 16 *OGRE_STREAM_TEMP_SIZE >", "class_ogre_1_1_static_cache.html", null ],
     [ "Ogre::StaticFaceGroup", "struct_ogre_1_1_static_face_group.html", null ],
     [ "Ogre::StaticGeometry::SubMeshLodGeometryLink", "struct_ogre_1_1_static_geometry_1_1_sub_mesh_lod_geometry_link.html", null ],
     [ "Ogre::StencilState", "struct_ogre_1_1_stencil_state.html", null ],
@@ -896,29 +948,23 @@ var hierarchy =
       ] ]
     ] ],
     [ "Ogre::TRect< T >", "struct_ogre_1_1_t_rect.html", null ],
-    [ "Ogre::TRect< float >", "struct_ogre_1_1_t_rect.html", null ],
-    [ "Ogre::TRect< int32 >", "struct_ogre_1_1_t_rect.html", null ],
-    [ "Ogre::TRect< Real >", "struct_ogre_1_1_t_rect.html", null ],
     [ "Ogre::vector< T >", "struct_ogre_1_1vector.html", null ],
     [ "Ogre::VectorBase< dims, T >", "struct_ogre_1_1_vector_base.html", [
+      [ "Ogre::Vector< 2, Real >", "class_ogre_1_1_vector.html", null ],
+      [ "Ogre::Vector< 2, float >", "class_ogre_1_1_vector.html", null ],
+      [ "Ogre::Vector< 2, int >", "class_ogre_1_1_vector.html", null ],
+      [ "Ogre::Vector< 3, Real >", "class_ogre_1_1_vector.html", null ],
+      [ "Ogre::Vector< 3, float >", "class_ogre_1_1_vector.html", null ],
+      [ "Ogre::Vector< 3, int >", "class_ogre_1_1_vector.html", null ],
+      [ "Ogre::Vector< 4, Real >", "class_ogre_1_1_vector.html", null ],
+      [ "Ogre::Vector< 4, float >", "class_ogre_1_1_vector.html", null ],
+      [ "Ogre::Vector< 3, uchar >", "class_ogre_1_1_vector.html", null ],
+      [ "Ogre::Vector< 4, uchar >", "class_ogre_1_1_vector.html", null ],
       [ "Ogre::Vector< dims, T >", "class_ogre_1_1_vector.html", null ]
     ] ],
     [ "Ogre::VectorBase< 2, Real >", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html", null ],
     [ "Ogre::VectorBase< 3, Real >", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html", null ],
     [ "Ogre::VectorBase< 4, Real >", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html", null ],
-    [ "Ogre::VectorBase< dims, float >", "struct_ogre_1_1_vector_base.html", [
-      [ "Ogre::Vector< 4, float >", "class_ogre_1_1_vector.html", null ],
-      [ "Ogre::Vector< 3, float >", "class_ogre_1_1_vector.html", null ],
-      [ "Ogre::Vector< 2, float >", "class_ogre_1_1_vector.html", null ]
-    ] ],
-    [ "Ogre::VectorBase< dims, int >", "struct_ogre_1_1_vector_base.html", [
-      [ "Ogre::Vector< 3, int >", "class_ogre_1_1_vector.html", null ]
-    ] ],
-    [ "Ogre::VectorBase< dims, Real >", "struct_ogre_1_1_vector_base.html", [
-      [ "Ogre::Vector< 3, Real >", "class_ogre_1_1_vector.html", null ],
-      [ "Ogre::Vector< 4, Real >", "class_ogre_1_1_vector.html", null ],
-      [ "Ogre::Vector< 2, Real >", "class_ogre_1_1_vector.html", null ]
-    ] ],
     [ "Ogre::VertexBoneAssignment", "struct_ogre_1_1_vertex_bone_assignment.html", null ],
     [ "Ogre::VertexData::HardwareAnimationData", "struct_ogre_1_1_vertex_data_1_1_hardware_animation_data.html", null ],
     [ "Ogre::VertexPoseKeyFrame::PoseRef", "struct_ogre_1_1_vertex_pose_key_frame_1_1_pose_ref.html", null ],
@@ -1196,7 +1242,46 @@ var hierarchy =
       ] ],
       [ "Ogre::ShadowRenderable", "class_ogre_1_1_shadow_renderable.html", null ]
     ] ],
+    [ "shared_ptr", null, [
+      [ "Ogre::SharedPtr< FileInfoList >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< ControllerValue< float > >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< ControllerFunction< float > >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< AnimableValue >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< Compositor >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< DataStream >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< GpuProgram >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< GpuNamedConstants >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< GpuLogicalBufferStruct >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< GpuSharedParameters >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< GpuProgramParameters >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< HardwareBuffer >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< HardwareIndexBuffer >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< HardwarePixelBuffer >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< HardwareVertexBuffer >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< Material >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< MemoryDataStream >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< Mesh >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< PatchMesh >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< RenderToVertexBuffer >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< Resource >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< ShadowCameraSetup >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< Skeleton >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< Texture >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< ConcreteNode >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< ConcreteNodeList >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< AbstractNode >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< AbstractNodeList >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< StringVector >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< Font >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< SubRenderStateAccessor >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< TerrainMaterialGenerator >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< BspLevel >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< Ogre::ControllerValue< T > >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< Ogre::ControllerFunction< T > >", "class_ogre_1_1_shared_ptr.html", null ],
+      [ "Ogre::SharedPtr< T >", "class_ogre_1_1_shared_ptr.html", null ]
+    ] ],
     [ "std::allocator", null, [
+      [ "Ogre::AlignedAllocator< Other, Alignment >", "struct_ogre_1_1_aligned_allocator.html", null ],
       [ "Ogre::AlignedAllocator< T, Alignment >", "struct_ogre_1_1_aligned_allocator.html", null ]
     ] ],
     [ "std::exception", null, [
@@ -1279,32 +1364,5 @@ var hierarchy =
     ] ],
     [ "ViewportAlloc", null, [
       [ "Ogre::Viewport", "class_ogre_1_1_viewport.html", null ]
-    ] ],
-    [ "shared_ptr", null, [
-      [ "Ogre::SharedPtr< Skeleton >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< Texture >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< Material >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< BspLevel >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< Ogre::ControllerValue< T > >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< Ogre::ControllerFunction< T > >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< ControllerValue< float > >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< ControllerFunction< float > >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< DataStream >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< Mesh >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< HardwareVertexBuffer >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< GpuLogicalBufferStruct >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< GpuNamedConstants >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< GpuProgram >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< HardwareBuffer >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< GpuSharedParameters >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< ShadowCameraSetup >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< AnimableValue >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< MemoryDataStream >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< SubRenderStateAccessor >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< GpuProgramParameters >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< AbstractNodeList >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< TerrainMaterialGenerator >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< Font >", "class_ogre_1_1_shared_ptr.html", null ],
-      [ "Ogre::SharedPtr< T >", "class_ogre_1_1_shared_ptr.html", null ]
     ] ]
 ];
\ No newline at end of file
