@@ -1,126 +1,5 @@
 var NAVTREEINDEX12 =
 {
-"class_ogre_1_1_d3_d9_render_system.html#ac150cea205fda65dacbccaee1d5d652fa0e39e4e40a49121c32929470d9829f38":[5,3,1,0,0,2],
-"class_ogre_1_1_d3_d9_render_system.html#ac150cea205fda65dacbccaee1d5d652fa25921c72928c345bce879cdeb59ea4de":[5,3,1,0,0,0],
-"class_ogre_1_1_d3_d9_render_system.html#ac150cea205fda65dacbccaee1d5d652faf9d4681736aed408d4446783840b775f":[5,3,1,0,0,1],
-"class_ogre_1_1_d3_d9_render_system.html#ac27c2134455ce86c7886c8450a0393ae":[5,3,1,0,67],
-"class_ogre_1_1_d3_d9_render_system.html#ac5910601e68f4c7c08370e2b74066d9b":[5,3,1,0,78],
-"class_ogre_1_1_d3_d9_render_system.html#ac674dcd0e1b47a07723fe341f06eef6d":[5,3,1,0,6],
-"class_ogre_1_1_d3_d9_render_system.html#ac95209c361f6d09fb6e0af0f6d4b4107":[5,3,1,0,52],
-"class_ogre_1_1_d3_d9_render_system.html#acc8659aa8149972ca8c1175199110d7d":[5,3,1,0,30],
-"class_ogre_1_1_d3_d9_render_system.html#acd1971d83f7000b83eb371d6877d89d2":[5,3,1,0,4],
-"class_ogre_1_1_d3_d9_render_system.html#acdd1a102566c67c2ce3426f06179cdae":[5,3,1,0,48],
-"class_ogre_1_1_d3_d9_render_system.html#ace53b06d3e61511f9b2dc6156e31c9a9":[5,3,1,0,81],
-"class_ogre_1_1_d3_d9_render_system.html#aceacaef86b50bc57a0eed5793ee26e74":[5,3,1,0,60],
-"class_ogre_1_1_d3_d9_render_system.html#acfaf7c8ec448362a48a5ab1a026909dd":[5,3,1,0,32],
-"class_ogre_1_1_d3_d9_render_system.html#ad0ce107404650d8b2ba8fcfba1448b60":[5,3,1,0,34],
-"class_ogre_1_1_d3_d9_render_system.html#ad177ce11d6941a706429db4a973faad4":[5,3,1,0,71],
-"class_ogre_1_1_d3_d9_render_system.html#ad80a6a285980da1c47bebb4946596039":[5,3,1,0,55],
-"class_ogre_1_1_d3_d9_render_system.html#ad8469f0aa267bf80682e08cdd0a41aaf":[5,3,1,0,8],
-"class_ogre_1_1_d3_d9_render_system.html#adeae40b2bceb2c09b225fec8a80cdfeb":[5,3,1,0,22],
-"class_ogre_1_1_d3_d9_render_system.html#ae849367c0ad6d28ecc8db5d95b3e56d7":[5,3,1,0,79],
-"class_ogre_1_1_d3_d9_render_system.html#aebb369ceba620861ccd3ff8a1cead931":[5,3,1,0,59],
-"class_ogre_1_1_d3_d9_render_system.html#aec34535d0f59c1eb5a2414a210b0a7c3":[5,3,1,0,21],
-"class_ogre_1_1_d3_d9_render_system.html#aec42c90e719c2c1d2581a906e5120ff7":[5,3,1,0,25],
-"class_ogre_1_1_d3_d9_render_system.html#aec82c6ec0be39f7ecb3e0d165125a540":[5,3,1,0,87],
-"class_ogre_1_1_d3_d9_render_system.html#af14f1a6b539a896178cebfd8a6282fa7":[5,3,1,0,19],
-"class_ogre_1_1_d3_d9_render_system.html#af25d5322ec044e06b143cc04a0f37bcb":[5,3,1,0,74],
-"class_ogre_1_1_d3_d9_render_system.html#af9b728ddf675afcecfafd0d4d335c63c":[5,3,1,0,70],
-"class_ogre_1_1_d3_d9_render_system.html#afaf9cf2f1d9cd94d8be47d9047533544":[5,3,1,0,68],
-"class_ogre_1_1_d3_d9_render_system.html#aff3564dce1811300a2d4e7a65e4e9c66":[5,3,1,0,39],
-"class_ogre_1_1_d3_d9_render_system.html#affaba55ebbb835d47398ba424d2191cf":[5,3,1,0,12],
-"class_ogre_1_1_d3_d9_resource_manager.html":[6,0,1,93],
-"class_ogre_1_1_d3_d9_resource_manager.html":[7,0,0,93],
-"class_ogre_1_1_d3_d9_resource_manager.html#a184caf162ee33abbfb146e82dcf92cf3":[6,0,1,93,7],
-"class_ogre_1_1_d3_d9_resource_manager.html#a184caf162ee33abbfb146e82dcf92cf3":[7,0,0,93,7],
-"class_ogre_1_1_d3_d9_resource_manager.html#a26706090b10f684168297c3515f5351a":[6,0,1,93,4],
-"class_ogre_1_1_d3_d9_resource_manager.html#a26706090b10f684168297c3515f5351a":[7,0,0,93,4],
-"class_ogre_1_1_d3_d9_resource_manager.html#a2e5c4329b1c7abf2af86ca8e7040f218":[6,0,1,93,0],
-"class_ogre_1_1_d3_d9_resource_manager.html#a2e5c4329b1c7abf2af86ca8e7040f218":[7,0,0,93,0],
-"class_ogre_1_1_d3_d9_resource_manager.html#a3b1885e4e9612f799ac4cacc72bd8df1":[6,0,1,93,8],
-"class_ogre_1_1_d3_d9_resource_manager.html#a3b1885e4e9612f799ac4cacc72bd8df1":[7,0,0,93,8],
-"class_ogre_1_1_d3_d9_resource_manager.html#a6217a2bec646ee530dcc0ae3959c3376":[6,0,1,93,1],
-"class_ogre_1_1_d3_d9_resource_manager.html#a6217a2bec646ee530dcc0ae3959c3376":[7,0,0,93,1],
-"class_ogre_1_1_d3_d9_resource_manager.html#a6892530d485dfb4f9ecedf035b02636e":[6,0,1,93,9],
-"class_ogre_1_1_d3_d9_resource_manager.html#a6892530d485dfb4f9ecedf035b02636e":[7,0,0,93,9],
-"class_ogre_1_1_d3_d9_resource_manager.html#a950f06f9f5d606cdd239cb0f91caec5a":[6,0,1,93,5],
-"class_ogre_1_1_d3_d9_resource_manager.html#a950f06f9f5d606cdd239cb0f91caec5a":[7,0,0,93,5],
-"class_ogre_1_1_d3_d9_resource_manager.html#a9774eeae04c96fe13a03cc506994ac41":[6,0,1,93,3],
-"class_ogre_1_1_d3_d9_resource_manager.html#a9774eeae04c96fe13a03cc506994ac41":[7,0,0,93,3],
-"class_ogre_1_1_d3_d9_resource_manager.html#abf59ec939708ee86f69c49d8794e79f9":[6,0,1,93,6],
-"class_ogre_1_1_d3_d9_resource_manager.html#abf59ec939708ee86f69c49d8794e79f9":[7,0,0,93,6],
-"class_ogre_1_1_d3_d9_resource_manager.html#aca7e782d7860488f1888191a0b92e9cc":[6,0,1,93,2],
-"class_ogre_1_1_d3_d9_resource_manager.html#aca7e782d7860488f1888191a0b92e9cc":[7,0,0,93,2],
-"class_ogre_1_1_d3_d9_resource_manager.html#ae4ca441097e4ad0ec1ff504041285152":[6,0,1,93,10],
-"class_ogre_1_1_d3_d9_resource_manager.html#ae4ca441097e4ad0ec1ff504041285152":[7,0,0,93,10],
-"class_ogre_1_1_data_stream.html":[5,0,8,4],
-"class_ogre_1_1_data_stream.html#a022f49c9313deffc5da4383d59d1f32d":[5,0,8,4,13],
-"class_ogre_1_1_data_stream.html#a11596eff968e2eaebc90f7ac88371bd4":[5,0,8,4,8],
-"class_ogre_1_1_data_stream.html#a2d9100f4e9167116fe280a7e7a1b6219":[5,0,8,4,17],
-"class_ogre_1_1_data_stream.html#a32966ad5a814f8c72fe0affbefcc6f55":[5,0,8,4,14],
-"class_ogre_1_1_data_stream.html#a3a99b8b9b4ce6cce64322ba89ea45e43":[5,0,8,4,6],
-"class_ogre_1_1_data_stream.html#a560b07ced4d47d31315d8d7f51638a8f":[5,0,8,4,5],
-"class_ogre_1_1_data_stream.html#a5d201db4c98570f9402f76caef5c5b2c":[5,0,8,4,4],
-"class_ogre_1_1_data_stream.html#a679e39a3ef590e1dc232800c37cfeb8b":[5,0,8,4,2],
-"class_ogre_1_1_data_stream.html#a68cde598ee9c2694e16931134fe5c136":[5,0,8,4,10],
-"class_ogre_1_1_data_stream.html#a776630c409195fdf118a6737571d3d07":[5,0,8,4,15],
-"class_ogre_1_1_data_stream.html#a81856582e643b4a560e6c3d3ad05e08c":[5,0,8,4,0],
-"class_ogre_1_1_data_stream.html#a81856582e643b4a560e6c3d3ad05e08ca8e221ca82d405d21d275997fbd3eb900":[5,0,8,4,0,1],
-"class_ogre_1_1_data_stream.html#a81856582e643b4a560e6c3d3ad05e08cac5f9d1587e9cc7dd1577af114dcba50e":[5,0,8,4,0,0],
-"class_ogre_1_1_data_stream.html#a81d740638618913333324663b2edb519":[5,0,8,4,18],
-"class_ogre_1_1_data_stream.html#a86d2ff5dff63ce4b689dd1d486d3243f":[5,0,8,4,12],
-"class_ogre_1_1_data_stream.html#a87d6018d4486304f004782c536a72de5":[5,0,8,4,1],
-"class_ogre_1_1_data_stream.html#a9501eeeb1aefc59f4dad05ec0cbdc14e":[5,0,8,4,3],
-"class_ogre_1_1_data_stream.html#a9d5b5224e17b9fc9d9756d8156a77a5c":[5,0,8,4,19],
-"class_ogre_1_1_data_stream.html#ace95bf415101e195a0c79838fdcb7e7d":[5,0,8,4,20],
-"class_ogre_1_1_data_stream.html#adc4002e013c279625553ccc3f50ddae1":[5,0,8,4,16],
-"class_ogre_1_1_data_stream.html#aebedb14c79369be5b8750d834b128b9b":[5,0,8,4,9],
-"class_ogre_1_1_data_stream.html#aedc53a8cff5334563283a4557d423b25":[5,0,8,4,11],
-"class_ogre_1_1_data_stream.html#aff0243c8ad8f5de00bf8e0887d0f034f":[5,0,8,4,7],
-"class_ogre_1_1_debug_drawer.html":[5,0,9,3],
-"class_ogre_1_1_debug_drawer.html#a380465eb6a3c7d6d9b09a5d87a4052d5":[5,0,9,3,2],
-"class_ogre_1_1_debug_drawer.html#a3a8c8a8a1c97f368a29caaac2af4d856":[5,0,9,3,0],
-"class_ogre_1_1_debug_drawer.html#ab71c073ac0e168579fb3975283c5e3eb":[5,0,9,3,1],
-"class_ogre_1_1_debug_drawer.html#abb957ee5e8dd6e7062700d11ce7615b7":[5,0,9,3,3],
-"class_ogre_1_1_default_axis_aligned_box_scene_query.html":[5,0,9,4],
-"class_ogre_1_1_default_axis_aligned_box_scene_query.html#a07057f940234ad7c0201decbecdba194":[5,0,9,4,0],
-"class_ogre_1_1_default_axis_aligned_box_scene_query.html#afa2144da4197b40dada039fd1084641c":[5,0,9,4,2],
-"class_ogre_1_1_default_axis_aligned_box_scene_query.html#aff51cd713a6dcfa195ce6d97701f752c":[5,0,9,4,1],
-"class_ogre_1_1_default_debug_drawer.html":[6,0,1,97],
-"class_ogre_1_1_default_debug_drawer.html":[7,0,0,97],
-"class_ogre_1_1_default_debug_drawer.html#a17230e3fe665e2e810843e340ba4e06b":[6,0,1,97,8],
-"class_ogre_1_1_default_debug_drawer.html#a17230e3fe665e2e810843e340ba4e06b":[7,0,0,97,8],
-"class_ogre_1_1_default_debug_drawer.html#a284fbdec1a311bb00f0074750dda5d6c":[6,0,1,97,6],
-"class_ogre_1_1_default_debug_drawer.html#a284fbdec1a311bb00f0074750dda5d6c":[7,0,0,97,6],
-"class_ogre_1_1_default_debug_drawer.html#a5a40b6836258edf02bd4d4be5b11c09c":[6,0,1,97,7],
-"class_ogre_1_1_default_debug_drawer.html#a5a40b6836258edf02bd4d4be5b11c09c":[7,0,0,97,7],
-"class_ogre_1_1_default_debug_drawer.html#a71da6aec84c0daa8617d642236e91908":[6,0,1,97,0],
-"class_ogre_1_1_default_debug_drawer.html#a71da6aec84c0daa8617d642236e91908":[7,0,0,97,0],
-"class_ogre_1_1_default_debug_drawer.html#a71da6aec84c0daa8617d642236e91908a8db337e1eb78cd6bfc5a8df84ff94b19":[6,0,1,97,0,1],
-"class_ogre_1_1_default_debug_drawer.html#a71da6aec84c0daa8617d642236e91908a8db337e1eb78cd6bfc5a8df84ff94b19":[7,0,0,97,0,1],
-"class_ogre_1_1_default_debug_drawer.html#a71da6aec84c0daa8617d642236e91908ab9d8292120ac28cd04f77cd276afa634":[6,0,1,97,0,0],
-"class_ogre_1_1_default_debug_drawer.html#a71da6aec84c0daa8617d642236e91908ab9d8292120ac28cd04f77cd276afa634":[7,0,0,97,0,0],
-"class_ogre_1_1_default_debug_drawer.html#a96bec68667abef108812e67af9992a47":[6,0,1,97,4],
-"class_ogre_1_1_default_debug_drawer.html#a96bec68667abef108812e67af9992a47":[7,0,0,97,4],
-"class_ogre_1_1_default_debug_drawer.html#abd9aa227f93cc19a3203e442343ebe37":[6,0,1,97,5],
-"class_ogre_1_1_default_debug_drawer.html#abd9aa227f93cc19a3203e442343ebe37":[7,0,0,97,5],
-"class_ogre_1_1_default_debug_drawer.html#ad291150ad2a0cbcddd5d803914b5b4ba":[6,0,1,97,2],
-"class_ogre_1_1_default_debug_drawer.html#ad291150ad2a0cbcddd5d803914b5b4ba":[7,0,0,97,2],
-"class_ogre_1_1_default_debug_drawer.html#ad583dda40c55a78057864e8718beb52a":[6,0,1,97,3],
-"class_ogre_1_1_default_debug_drawer.html#ad583dda40c55a78057864e8718beb52a":[7,0,0,97,3],
-"class_ogre_1_1_default_debug_drawer.html#aeb637f7326367d271fdcd0c4412cea08":[6,0,1,97,1],
-"class_ogre_1_1_default_debug_drawer.html#aeb637f7326367d271fdcd0c4412cea08":[7,0,0,97,1],
-"class_ogre_1_1_default_hardware_buffer.html":[5,0,7,1],
-"class_ogre_1_1_default_hardware_buffer.html#a050c9b25ac465441a52837bb75ebc60f":[5,0,7,1,3],
-"class_ogre_1_1_default_hardware_buffer.html#a3b7d53524bb4efc2aa1b9ebf608dcea2":[5,0,7,1,2],
-"class_ogre_1_1_default_hardware_buffer.html#aa2e1f53f6c37b0bb57bc38e4fe4d8fef":[5,0,7,1,4],
-"class_ogre_1_1_default_hardware_buffer.html#abf4158a560d35033133680dfb29e99f7":[5,0,7,1,1],
-"class_ogre_1_1_default_hardware_buffer.html#af5bf169a8912f614a2e301993e66abee":[5,0,7,1,0],
-"class_ogre_1_1_default_hardware_buffer_manager.html":[5,0,7,2],
-"class_ogre_1_1_default_hardware_buffer_manager.html#a222290dca734e3cb879691b334776e34":[5,0,7,2,1],
-"class_ogre_1_1_default_hardware_buffer_manager.html#a4705dd8822b0d33c17e1941572bd820d":[5,0,7,2,2],
-"class_ogre_1_1_default_hardware_buffer_manager.html#a4cd035da8caa2867d327ea9490f91c4d":[5,0,7,2,0],
-"class_ogre_1_1_default_hardware_buffer_manager.html#ad52b27601f52d5028d5f56e074e27d06":[5,0,7,2,4],
 "class_ogre_1_1_default_hardware_buffer_manager.html#af224a816c521f8d7da2aa5c1e312f25b":[5,0,7,2,5],
 "class_ogre_1_1_default_hardware_buffer_manager.html#afcf18a21b65c0375d28c5686307a3eee":[5,0,7,2,3],
 "class_ogre_1_1_default_hardware_buffer_manager_base.html":[5,0,7,3],
@@ -249,5 +128,126 @@ var NAVTREEINDEX12 =
 "class_ogre_1_1_deflate_stream.html#a2ef0f2e0bf0395ace3e29a059401d2cf":[7,0,0,111,7],
 "class_ogre_1_1_deflate_stream.html#a3bf53c73a9933c5e6e1ae215cba72845":[6,0,1,111,1],
 "class_ogre_1_1_deflate_stream.html#a3bf53c73a9933c5e6e1ae215cba72845":[7,0,0,111,1],
-"class_ogre_1_1_deflate_stream.html#a5ba171261e6c5d8c2f2880e99ca5c141":[6,0,1,111,5]
+"class_ogre_1_1_deflate_stream.html#a5ba171261e6c5d8c2f2880e99ca5c141":[6,0,1,111,5],
+"class_ogre_1_1_deflate_stream.html#a5ba171261e6c5d8c2f2880e99ca5c141":[7,0,0,111,5],
+"class_ogre_1_1_deflate_stream.html#a5e29bee00d7357fd2597c20ab0d371f7":[6,0,1,111,6],
+"class_ogre_1_1_deflate_stream.html#a5e29bee00d7357fd2597c20ab0d371f7":[7,0,0,111,6],
+"class_ogre_1_1_deflate_stream.html#a7ab66addcbf428322b1caea1d9c88cea":[6,0,1,111,4],
+"class_ogre_1_1_deflate_stream.html#a7ab66addcbf428322b1caea1d9c88cea":[7,0,0,111,4],
+"class_ogre_1_1_deflate_stream.html#a7cb0344e3c96a247f78863e62ea8b945":[6,0,1,111,9],
+"class_ogre_1_1_deflate_stream.html#a7cb0344e3c96a247f78863e62ea8b945":[7,0,0,111,9],
+"class_ogre_1_1_deflate_stream.html#a85818eb09d100f45a6141d36213fb3af":[6,0,1,111,12],
+"class_ogre_1_1_deflate_stream.html#a85818eb09d100f45a6141d36213fb3af":[7,0,0,111,12],
+"class_ogre_1_1_deflate_stream.html#a90494a018545804a60686ad179555822":[6,0,1,111,3],
+"class_ogre_1_1_deflate_stream.html#a90494a018545804a60686ad179555822":[7,0,0,111,3],
+"class_ogre_1_1_deflate_stream.html#a917342711b195ccbad40c65ad82e440c":[6,0,1,111,2],
+"class_ogre_1_1_deflate_stream.html#a917342711b195ccbad40c65ad82e440c":[7,0,0,111,2],
+"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908c":[6,0,1,111,0],
+"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908c":[7,0,0,111,0],
+"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908ca6d7007604fcbeb05fd8f27baac7eed9b":[6,0,1,111,0,3],
+"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908ca6d7007604fcbeb05fd8f27baac7eed9b":[7,0,0,111,0,3],
+"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908ca855b85480a0c741d3cb3e10c83a35838":[6,0,1,111,0,0],
+"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908ca855b85480a0c741d3cb3e10c83a35838":[7,0,0,111,0,0],
+"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908caab547cd040a3b61b6df82af4cf202692":[6,0,1,111,0,2],
+"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908caab547cd040a3b61b6df82af4cf202692":[7,0,0,111,0,2],
+"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908cad3be223c328c7637519421e4ce552ef1":[6,0,1,111,0,1],
+"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908cad3be223c328c7637519421e4ce552ef1":[7,0,0,111,0,1],
+"class_ogre_1_1_deflate_stream.html#aed7d30c52ce428ca353cde56b1b686df":[6,0,1,111,10],
+"class_ogre_1_1_deflate_stream.html#aed7d30c52ce428ca353cde56b1b686df":[7,0,0,111,10],
+"class_ogre_1_1_deflector_plane_affector.html":[5,2,10,5],
+"class_ogre_1_1_deflector_plane_affector.html#a1270e11fac75d4a23c844663435880f4":[5,2,10,5,11],
+"class_ogre_1_1_deflector_plane_affector.html#a27f5a61343d867f092b952e7e7e2bd84":[5,2,10,5,6],
+"class_ogre_1_1_deflector_plane_affector.html#a2b792c697baec1f9261441a8c3d8e411":[5,2,10,5,13],
+"class_ogre_1_1_deflector_plane_affector.html#a40134140f7160a036d788c3566046023":[5,2,10,5,9],
+"class_ogre_1_1_deflector_plane_affector.html#a8279e4c01b50cd1af7998066e302d4f1":[5,2,10,5,4],
+"class_ogre_1_1_deflector_plane_affector.html#a93370ae652e024c098b5e9fb9331b3c4":[5,2,10,5,8],
+"class_ogre_1_1_deflector_plane_affector.html#a9a9f808a17f812d4fbdeccf25253de0f":[5,2,10,5,3],
+"class_ogre_1_1_deflector_plane_affector.html#ab94db6d30ca0174ad693d14dd2d97da0":[5,2,10,5,12],
+"class_ogre_1_1_deflector_plane_affector.html#ad6a78b0183d6ca01b0d874072f516216":[5,2,10,5,7],
+"class_ogre_1_1_deflector_plane_affector.html#ae754ec84b841704659536de3fc80f96f":[5,2,10,5,5],
+"class_ogre_1_1_deflector_plane_affector.html#af833ea96855c512f01911dba5446f2b8":[5,2,10,5,10],
+"class_ogre_1_1_deflector_plane_affector_1_1_cmd_bounce.html":[5,2,10,5,0],
+"class_ogre_1_1_deflector_plane_affector_1_1_cmd_bounce.html#a8ce456c71a82ffb6811fb93235722f23":[5,2,10,5,0,1],
+"class_ogre_1_1_deflector_plane_affector_1_1_cmd_bounce.html#a92df5fb614719df9fbeabae0b83934f5":[5,2,10,5,0,0],
+"class_ogre_1_1_deflector_plane_affector_1_1_cmd_plane_normal.html":[5,2,10,5,1],
+"class_ogre_1_1_deflector_plane_affector_1_1_cmd_plane_normal.html#a2c124ef31b3b6cdac670cc438e045033":[5,2,10,5,1,0],
+"class_ogre_1_1_deflector_plane_affector_1_1_cmd_plane_normal.html#a84a3752f9f7bc2502108e30513a9aa37":[5,2,10,5,1,1],
+"class_ogre_1_1_deflector_plane_affector_1_1_cmd_plane_point.html":[5,2,10,5,2],
+"class_ogre_1_1_deflector_plane_affector_1_1_cmd_plane_point.html#a17ac02d9cf28a66758eeca88092c90ec":[5,2,10,5,2,0],
+"class_ogre_1_1_deflector_plane_affector_1_1_cmd_plane_point.html#a3c2284edb3fbc3097d446366ce7234fe":[5,2,10,5,2,1],
+"class_ogre_1_1_degree.html":[5,0,6,5],
+"class_ogre_1_1_degree.html#a0934993b96599628b37a28082aa35189":[5,0,6,5,23],
+"class_ogre_1_1_degree.html#a1b21b5dd134a959f2ff0b4fc36bf2519":[5,0,6,5,24],
+"class_ogre_1_1_degree.html#a2b55c39e79732312bef15ce6a217d206":[5,0,6,5,12],
+"class_ogre_1_1_degree.html#a361f3a162b7b0a234cceecef045c6a30":[5,0,6,5,0],
+"class_ogre_1_1_degree.html#a38f343d7b34d2239c9c5ec7270639b86":[5,0,6,5,1],
+"class_ogre_1_1_degree.html#a3948efcffa54a0ebd12753acd96c1594":[5,0,6,5,14],
+"class_ogre_1_1_degree.html#a3985fcbd2b8eb22a9d369a6b6ebe5763":[5,0,6,5,27],
+"class_ogre_1_1_degree.html#a501f79ce69c3a73d5c07c945c3251097":[5,0,6,5,29],
+"class_ogre_1_1_degree.html#a5db30a075125ac5f9742dac1de7e83e4":[5,0,6,5,21],
+"class_ogre_1_1_degree.html#a6fe71d74f931c1d5525a676ce4defecb":[5,0,6,5,4],
+"class_ogre_1_1_degree.html#a720ae822fce72eb4de3a6c6b59e27f4d":[5,0,6,5,3],
+"class_ogre_1_1_degree.html#a77fbb11439e3b9f3ce56af331737484d":[5,0,6,5,11],
+"class_ogre_1_1_degree.html#a7bc078c3f3df2ec10ac2d058d29e6e7d":[5,0,6,5,26],
+"class_ogre_1_1_degree.html#a7f2eded374257421684267738fb476a4":[5,0,6,5,13],
+"class_ogre_1_1_degree.html#a830559610ea7662565d6ea1107952e51":[5,0,6,5,16],
+"class_ogre_1_1_degree.html#a8aed655684943ae384e45378b65da36a":[5,0,6,5,10],
+"class_ogre_1_1_degree.html#a8ccdef2435d0a205feb54763d8be5fc9":[5,0,6,5,20],
+"class_ogre_1_1_degree.html#a8cf6e7cea4ceba86260f0a00e10843a7":[5,0,6,5,5],
+"class_ogre_1_1_degree.html#aa4de11c233003ffb99fc51951a207889":[5,0,6,5,2],
+"class_ogre_1_1_degree.html#aae5eef4a46d40d762e159610a9905c9f":[5,0,6,5,28],
+"class_ogre_1_1_degree.html#ab96e1c8373070e5a990e523f4e0069f0":[5,0,6,5,9],
+"class_ogre_1_1_degree.html#ac84420f8ca8ca97730058c16af2bff88":[5,0,6,5,19],
+"class_ogre_1_1_degree.html#accdd399875d49f167ecfcd3c815d75b5":[5,0,6,5,17],
+"class_ogre_1_1_degree.html#acd0fcb50083c8ee7ef0c4bc936aa0bbd":[5,0,6,5,22],
+"class_ogre_1_1_degree.html#acd2201c018ae74f013542664c2086be0":[5,0,6,5,18],
+"class_ogre_1_1_degree.html#ace8f3be58aeb1dcb44fe9d9865fb47c6":[5,0,6,5,25],
+"class_ogre_1_1_degree.html#adc93f437d32694bc6e63d0381c641031":[5,0,6,5,30],
+"class_ogre_1_1_degree.html#ae7ec7b667395a6e9fb79a92c55a9c5ec":[5,0,6,5,6],
+"class_ogre_1_1_degree.html#af2441af959738661a1a2251eb16e54bb":[5,0,6,5,15],
+"class_ogre_1_1_depth_buffer.html":[5,0,7,4],
+"class_ogre_1_1_direction_randomiser_affector.html":[5,2,10,6],
+"class_ogre_1_1_direction_randomiser_affector_1_1_cmd_keep_velocity.html":[5,2,10,7],
+"class_ogre_1_1_direction_randomiser_affector_1_1_cmd_randomness.html":[5,2,10,8],
+"class_ogre_1_1_direction_randomiser_affector_1_1_cmd_scope.html":[5,2,10,9],
+"class_ogre_1_1_distance_lod_box_strategy.html":[5,0,4,1],
+"class_ogre_1_1_distance_lod_box_strategy.html#a13819182818575ae473286449f563706":[5,0,4,1,2],
+"class_ogre_1_1_distance_lod_box_strategy.html#a3a10186da1f694019bd56738d523f990":[5,0,4,1,1],
+"class_ogre_1_1_distance_lod_box_strategy.html#a7de1d4d48cc9cef13375bebf3bf5d91b":[5,0,4,1,3],
+"class_ogre_1_1_distance_lod_box_strategy.html#aefc779936e9fe54a627715bbc0a7f3d9":[5,0,4,1,0],
+"class_ogre_1_1_distance_lod_sphere_strategy.html":[5,0,4,2],
+"class_ogre_1_1_distance_lod_sphere_strategy.html#a1836339ae099ab2dcebc31cfcc4a9475":[5,0,4,2,1],
+"class_ogre_1_1_distance_lod_sphere_strategy.html#a86bd0de82734a68148126e872eb92874":[5,0,4,2,2],
+"class_ogre_1_1_distance_lod_sphere_strategy.html#a99b5ef240e4230111c22e2e131474f3f":[5,0,4,2,0],
+"class_ogre_1_1_distance_lod_sphere_strategy.html#ae478d8c56d2ec46b79af762d32494127":[5,0,4,2,3],
+"class_ogre_1_1_distance_lod_strategy_base.html":[5,0,4,3],
+"class_ogre_1_1_distance_lod_strategy_base.html#a0de7722e986cdcca067bc1773feb6065":[5,0,4,3,10],
+"class_ogre_1_1_distance_lod_strategy_base.html#a15f1fe0235a041c18abd9644dbed5d87":[5,0,4,3,0],
+"class_ogre_1_1_distance_lod_strategy_base.html#a3ef487ffc2e8223fbceea0df0bb98e73":[5,0,4,3,7],
+"class_ogre_1_1_distance_lod_strategy_base.html#a4f8f711a88a7ad7308bfb58e525503ab":[5,0,4,3,8],
+"class_ogre_1_1_distance_lod_strategy_base.html#a5b60368988f8c388b97d6af77b7c08c9":[5,0,4,3,11],
+"class_ogre_1_1_distance_lod_strategy_base.html#a65d9d54235e62d66e1f25355926d7a63":[5,0,4,3,6],
+"class_ogre_1_1_distance_lod_strategy_base.html#a8a2e6192e83057b8973b5247a8ff7abe":[5,0,4,3,1],
+"class_ogre_1_1_distance_lod_strategy_base.html#ab26e68a2e700746489699bc1c70e8e18":[5,0,4,3,3],
+"class_ogre_1_1_distance_lod_strategy_base.html#acb473d444fc5b8b836b172d3baaa6a75":[5,0,4,3,4],
+"class_ogre_1_1_distance_lod_strategy_base.html#ae0eb79032a169437c7ecdad4d20e8a81":[5,0,4,3,5],
+"class_ogre_1_1_distance_lod_strategy_base.html#ae8568a566aac276fcf9f1ab7c5f19a38":[5,0,4,3,2],
+"class_ogre_1_1_distance_lod_strategy_base.html#aed77c6dfbdc0fbf75bf9deaf4f2b8bfc":[5,0,4,3,9],
+"class_ogre_1_1_dot_scene_loader.html":[5,2,3,0],
+"class_ogre_1_1_dot_scene_loader.html#a4d3297139bca45e1130443d79b7b2e70":[5,2,3,0,0],
+"class_ogre_1_1_dot_scene_loader.html#a6a2e576a1adac9e7dd9c59548c02df47":[5,2,3,0,1],
+"class_ogre_1_1_dot_scene_loader.html#a6e5298ed5aed9df4bc08a9e76db432a0":[5,2,3,0,2],
+"class_ogre_1_1_dot_scene_loader.html#ab47d1392af6c3f5679f45d79fd31261b":[5,2,3,0,4],
+"class_ogre_1_1_dot_scene_loader.html#ae35c9465e0d77b51589dabefa2cdeb6d":[5,2,3,0,3],
+"class_ogre_1_1_dot_scene_plugin.html":[5,2,3,1],
+"class_ogre_1_1_dual_quaternion.html":[5,0,6,6],
+"class_ogre_1_1_dual_quaternion.html#a024daf85de3ed5b28ac41d490012dd2f":[5,0,6,6,7],
+"class_ogre_1_1_dual_quaternion.html#a0eb3f8e285a3aaddb6867f24486dbf21":[5,0,6,6,8],
+"class_ogre_1_1_dual_quaternion.html#a10574bf89fef9fc12fac5ed4e8085f71":[5,0,6,6,3],
+"class_ogre_1_1_dual_quaternion.html#a123fbf0958bccd9f5381d6f124d0586e":[5,0,6,6,25],
+"class_ogre_1_1_dual_quaternion.html#a16fefc12aaa35460748c8dfc253d39f1":[5,0,6,6,17],
+"class_ogre_1_1_dual_quaternion.html#a1afbb66b83f2085f452bb663ceafc9dc":[5,0,6,6,20],
+"class_ogre_1_1_dual_quaternion.html#a303afd76b65bd34a28accdb6eb0c024c":[5,0,6,6,4],
+"class_ogre_1_1_dual_quaternion.html#a43375b322ae7a0b7f5d03318bfa33f17":[5,0,6,6,21],
+"class_ogre_1_1_dual_quaternion.html#a488ce81a7866d481169647cff04dc17c":[5,0,6,6,24]
 };
