@@ -1,125 +1,5 @@
 var NAVTREEINDEX29 =
 {
-"class_ogre_1_1_pass.html#a763b8993d64d234349ffa11932b912e0":[5,0,5,18,144],
-"class_ogre_1_1_pass.html#a76e0c135dbcacf5d12cc78a15452c7dc":[5,0,5,18,14],
-"class_ogre_1_1_pass.html#a77551778f0d1989cdf7541cd0a71faf8":[5,0,5,18,210],
-"class_ogre_1_1_pass.html#a788b633913442314683050c34b2c3c9b":[5,0,5,18,40],
-"class_ogre_1_1_pass.html#a7a1d67d993a4b3fdd0eb3719704947bb":[5,0,5,18,146],
-"class_ogre_1_1_pass.html#a7a9dc9ff2c18d8a5953d7578d2b2c438":[5,0,5,18,58],
-"class_ogre_1_1_pass.html#a7f36f2c48b62fd29b2abdee4425d6a2c":[5,0,5,18,6],
-"class_ogre_1_1_pass.html#a80c357f88e45737a1c5aa368d278b4f7":[5,0,5,18,31],
-"class_ogre_1_1_pass.html#a823dd0856cf4d8bfa08abc3591c47c02":[5,0,5,18,20],
-"class_ogre_1_1_pass.html#a8336a42895b9429c0bbae528fcaa5a43":[5,0,5,18,120],
-"class_ogre_1_1_pass.html#a85a67b777d757d158c6cbc2b4f7ec76e":[5,0,5,18,87],
-"class_ogre_1_1_pass.html#a85bffe16db4ccd90a26a257ded6e57c4":[5,0,5,18,143],
-"class_ogre_1_1_pass.html#a86de1842654eb89c6f48785d02f07688":[5,0,5,18,65],
-"class_ogre_1_1_pass.html#a879780ade78dc1dce173c51ed5c6b3f2":[5,0,5,18,184],
-"class_ogre_1_1_pass.html#a889ed9697e2a990143cb41f953878dd3":[5,0,5,18,180],
-"class_ogre_1_1_pass.html#a8942abf3ede0f3cb43584c85c4071734":[5,0,5,18,99],
-"class_ogre_1_1_pass.html#a8ac6972d87fade69312d80d8c7049d59":[5,0,5,18,3],
-"class_ogre_1_1_pass.html#a8b816cdd2b5b5fcc5cbe6744b6bb2dbd":[5,0,5,18,129],
-"class_ogre_1_1_pass.html#a8d799c8e3324a37e70d50f8fd1e5daac":[5,0,5,18,52],
-"class_ogre_1_1_pass.html#a8db1ef396830a458b80e26cb64967a90":[5,0,5,18,197],
-"class_ogre_1_1_pass.html#a8e61c233c08848aa736bcfa7bdb58158":[5,0,5,18,76],
-"class_ogre_1_1_pass.html#a8f69f7e13e3665ba295ce9b4671fdc4c":[5,0,5,18,67],
-"class_ogre_1_1_pass.html#a8f7068c8fb5556c150126866373343ac":[5,0,5,18,132],
-"class_ogre_1_1_pass.html#a8ff736f5d1d0eb3e3caa23b1d7c79997":[5,0,5,18,202],
-"class_ogre_1_1_pass.html#a90202dc859f6b1399334563203d3e381":[5,0,5,18,56],
-"class_ogre_1_1_pass.html#a928061c8f56d923808add7e8ba9cdee8":[5,0,5,18,188],
-"class_ogre_1_1_pass.html#a939fc6e2a02a7d753c84ec11219e97da":[5,0,5,18,8],
-"class_ogre_1_1_pass.html#a93c36ae948d9e0357c11adb0ce6d5859":[5,0,5,18,25],
-"class_ogre_1_1_pass.html#a948a03f973f5d8cd0c4ac8592db80593":[5,0,5,18,154],
-"class_ogre_1_1_pass.html#a95a7a4006f26528ef4f6ce42ae56b09b":[5,0,5,18,127],
-"class_ogre_1_1_pass.html#a9683c2f40ed7c96b708eb2db5e02c842":[5,0,5,18,43],
-"class_ogre_1_1_pass.html#a9729c4faa36b1a38ce0a8c14a3627dbe":[5,0,5,18,126],
-"class_ogre_1_1_pass.html#a97deab966da4653d248875782b45a3f1":[5,0,5,18,163],
-"class_ogre_1_1_pass.html#a97e5a74847664d60fb741eca605d9960":[5,0,5,18,1],
-"class_ogre_1_1_pass.html#a989043a45609fd8f82235c3d1c402a23":[5,0,5,18,200],
-"class_ogre_1_1_pass.html#a9a397a3383ca34ff91e67fe4126ca1a5":[5,0,5,18,2],
-"class_ogre_1_1_pass.html#a9ae2570082185c2b6e237a2d46f9bb60":[5,0,5,18,79],
-"class_ogre_1_1_pass.html#a9f14ed26740158970994057e48e562e9":[5,0,5,18,131],
-"class_ogre_1_1_pass.html#a9fe6fc3f542eade6b37d49cd0eadddde":[5,0,5,18,116],
-"class_ogre_1_1_pass.html#aa35a3242a45176f8605bd8c866198b67":[5,0,5,18,94],
-"class_ogre_1_1_pass.html#aa4bba51e9a0cba1b9708bab99496c1a8":[5,0,5,18,73],
-"class_ogre_1_1_pass.html#aa89b9de8338da5bb1944b16145ee2f62":[5,0,5,18,78],
-"class_ogre_1_1_pass.html#aa9bd26e7a9e62db9ab52c1b4af859f72":[5,0,5,18,115],
-"class_ogre_1_1_pass.html#aabd2c9a9313c0e3ba809d4cb063eac12":[5,0,5,18,139],
-"class_ogre_1_1_pass.html#aad3e6c7c7b59e2c303c348b4850b1a3a":[5,0,5,18,90],
-"class_ogre_1_1_pass.html#aad5e478599ef9431650288df1e515756":[5,0,5,18,167],
-"class_ogre_1_1_pass.html#ab25733e77cd0b2f558d62e5a7ab7592e":[5,0,5,18,10],
-"class_ogre_1_1_pass.html#ab2d6e2e30826d01e5ec19bef7446f447":[5,0,5,18,91],
-"class_ogre_1_1_pass.html#ab3af180b9759ea13e557003abc84e594":[5,0,5,18,12],
-"class_ogre_1_1_pass.html#ab3c8f1edbb0aa6c0e0f488a8d4ca6d1f":[5,0,5,18,185],
-"class_ogre_1_1_pass.html#ab63508d99fef116d0df14c080e0e1129":[5,0,5,18,39],
-"class_ogre_1_1_pass.html#ab7e5da37e9081506bb5647222d16bb5a":[5,0,5,18,17],
-"class_ogre_1_1_pass.html#ab85cf60f49c52c53671d5bb5105231e8":[5,0,5,18,187],
-"class_ogre_1_1_pass.html#aba0003996c1c200db9fb6466a2253a54":[5,0,5,18,162],
-"class_ogre_1_1_pass.html#aba057d0d19159c21b9a79485512b6f9d":[5,0,5,18,18],
-"class_ogre_1_1_pass.html#abc6714cbd40710f4c908556b644814a8":[5,0,5,18,34],
-"class_ogre_1_1_pass.html#abce35807758f26b84d29313cf70593cd":[5,0,5,18,38],
-"class_ogre_1_1_pass.html#abd67db27426bb99e6e58e7299424c4bc":[5,0,5,18,128],
-"class_ogre_1_1_pass.html#abdcffe5cb7cee6c8c5a5fd4c2f75164d":[5,0,5,18,19],
-"class_ogre_1_1_pass.html#abe6e32bc6812ed954daaa2c5518a2ac3":[5,0,5,18,182],
-"class_ogre_1_1_pass.html#abee48df0d246eb685780d16b32b7f8f4":[5,0,5,18,157],
-"class_ogre_1_1_pass.html#ac0d16617c07bcfdc4f17e9ffed2f8591":[5,0,5,18,179],
-"class_ogre_1_1_pass.html#ac1513f6d3e1acb9037225d826ec99856":[5,0,5,18,61],
-"class_ogre_1_1_pass.html#ac1e07d3bccdb7f6c437c107c92e4ae46":[5,0,5,18,189],
-"class_ogre_1_1_pass.html#ac3c602911c2c1511ab551db4cef59c37":[5,0,5,18,148],
-"class_ogre_1_1_pass.html#ac490e2cef75de42128f43bd1dd394538":[5,0,5,18,151],
-"class_ogre_1_1_pass.html#ac5f4c80e53eb3776483b3414893c4235":[5,0,5,18,198],
-"class_ogre_1_1_pass.html#ac95db75cb036fe01bc7e9a37934c6ff8":[5,0,5,18,4],
-"class_ogre_1_1_pass.html#aca1044a438121427b138b1391d37854f":[5,0,5,18,66],
-"class_ogre_1_1_pass.html#aca462cd8e0708d90c3131ddd39e95674":[5,0,5,18,97],
-"class_ogre_1_1_pass.html#acb5a5d646e84a1d6c0be32f1132419f8":[5,0,5,18,108],
-"class_ogre_1_1_pass.html#acd99aaea7eec3026699bfccdd09310b0":[5,0,5,18,102],
-"class_ogre_1_1_pass.html#ace4313056341502f87ada68638cae334":[5,0,5,18,80],
-"class_ogre_1_1_pass.html#ad107a9233c0220b96000cb6778fea9bf":[5,0,5,18,150],
-"class_ogre_1_1_pass.html#ad17196c5383815e1af157fc9617c474b":[5,0,5,18,196],
-"class_ogre_1_1_pass.html#ad1d50f9c7cd1b11646ec88f463f0a27f":[5,0,5,18,147],
-"class_ogre_1_1_pass.html#ad2469a288587756a1bc7d85fecc5038c":[5,0,5,18,166],
-"class_ogre_1_1_pass.html#ad2816a80c67ba785b78d7d386c17d726":[5,0,5,18,169],
-"class_ogre_1_1_pass.html#ad51f3602ae69b8d0f219582aa6b16d48":[5,0,5,18,204],
-"class_ogre_1_1_pass.html#ad58bed2ac47d40e65750c61c0ca36af3":[5,0,5,18,177],
-"class_ogre_1_1_pass.html#ad681df78f0e0c61e1bc166e3ec85170f":[5,0,5,18,107],
-"class_ogre_1_1_pass.html#ad7582011f85937446047a843896c8382":[5,0,5,18,122],
-"class_ogre_1_1_pass.html#ad7d25e05b830745ecfc6cbd09624ee17":[5,0,5,18,49],
-"class_ogre_1_1_pass.html#ad9e4cda5e74ef06a6dda30e57e4b5d44":[5,0,5,18,32],
-"class_ogre_1_1_pass.html#ada65b65c257df31f481b54ac08ad6436":[5,0,5,18,213],
-"class_ogre_1_1_pass.html#adc75fe5011be72c0597535cb37d75d57":[5,0,5,18,125],
-"class_ogre_1_1_pass.html#adcb78aa549dc85cb36bd3dbc8abeee24":[5,0,5,18,98],
-"class_ogre_1_1_pass.html#ade6c00297cd5d46bb365d981cd1764a6":[5,0,5,18,103],
-"class_ogre_1_1_pass.html#ae0a98973675e2cf71b286ceb9e73ecd3":[5,0,5,18,121],
-"class_ogre_1_1_pass.html#ae1b0920d6ba670d5e2e85bf2282bd2ef":[5,0,5,18,119],
-"class_ogre_1_1_pass.html#ae21d6f29c89eeff54ab6de5562818c02":[5,0,5,18,70],
-"class_ogre_1_1_pass.html#ae3ad6543e0c24eb7f12b00f46e7124d8":[5,0,5,18,27],
-"class_ogre_1_1_pass.html#ae454faee87f8cb0b8540810e48118788":[5,0,5,18,88],
-"class_ogre_1_1_pass.html#ae4f6e70258ca9a870e3b0867792000e6":[5,0,5,18,176],
-"class_ogre_1_1_pass.html#ae5653eb7430051fc4a81aa577c031186":[5,0,5,18,28],
-"class_ogre_1_1_pass.html#ae6756a522ba2aae4601c8153f38594d4":[5,0,5,18,153],
-"class_ogre_1_1_pass.html#ae8c6cd9d16220e8ef358f8b3e072d261":[5,0,5,18,173],
-"class_ogre_1_1_pass.html#ae8c85bd4eff471ca7b3c710d20dbf274":[5,0,5,18,85],
-"class_ogre_1_1_pass.html#aeaf906d8abba9a4b4dde83f87daa0f4e":[5,0,5,18,54],
-"class_ogre_1_1_pass.html#aeb16b94de537bda3140df7095090cc10":[5,0,5,18,201],
-"class_ogre_1_1_pass.html#aec14031d3e7e69c7ec4f734dc40f612d":[5,0,5,18,75],
-"class_ogre_1_1_pass.html#aec3f262fe893114ab6428644c256dda1":[5,0,5,18,112],
-"class_ogre_1_1_pass.html#aec98c9346a22a4a98acdaf5b8849a5c1":[5,0,5,18,133],
-"class_ogre_1_1_pass.html#aed6912e985c09f72d8f8012494f1068a":[5,0,5,18,93],
-"class_ogre_1_1_pass.html#aedb647950fbc40f52ae139eb166d602d":[5,0,5,18,100],
-"class_ogre_1_1_pass.html#aef6c591b069aa6f7c65afc1419d47de6":[5,0,5,18,92],
-"class_ogre_1_1_pass.html#aefbd80d762d78838df626482df1ac81b":[5,0,5,18,71],
-"class_ogre_1_1_pass.html#af0977cabd2a7fb79f9ee03078f79011a":[5,0,5,18,24],
-"class_ogre_1_1_pass.html#af1992ef39ef97e0b48e878c9aaa2badd":[5,0,5,18,199],
-"class_ogre_1_1_pass.html#af23f6b1ae56f9acdcb05f8cbcf0e9153":[5,0,5,18,11],
-"class_ogre_1_1_pass.html#af2643f7594c827d2f1b8785029de280f":[5,0,5,18,145],
-"class_ogre_1_1_pass.html#af27332810328f3be996516ccfd105ac2":[5,0,5,18,48],
-"class_ogre_1_1_pass.html#af54b3be2df752a5afd31ef8c3c4da055":[5,0,5,18,113],
-"class_ogre_1_1_pass.html#af5e358a5fd8a944c9845f8aee4ba54a6":[5,0,5,18,46],
-"class_ogre_1_1_pass.html#af6b2aab96fb146a8e92043c7dc771de4":[5,0,5,18,159],
-"class_ogre_1_1_pass.html#af70ccd332a1df548058917c31021f7df":[5,0,5,18,44],
-"class_ogre_1_1_pass.html#af86935304f781d608cd883901e9e1190":[5,0,5,18,214],
-"class_ogre_1_1_pass.html#af9d27cc0af581bc67a8edca9bc876dee":[5,0,5,18,164],
-"class_ogre_1_1_pass.html#afaa52a3826a08569b8263834f043a83f":[5,0,5,18,186],
-"class_ogre_1_1_pass.html#afb3b4e8c3d0058a43cd2b855fc22199c":[5,0,5,18,15],
 "class_ogre_1_1_pass.html#afc41cb1fe9251448002a2405405b8bd9":[5,0,5,18,172],
 "class_ogre_1_1_pass.html#afd45b897ebc29d3ee40a2ee307682f35":[5,0,5,18,174],
 "class_ogre_1_1_pass.html#aff774d55b700af010f57e2330101a610":[5,0,5,18,212],
@@ -243,11 +123,131 @@ var NAVTREEINDEX29 =
 "class_ogre_1_1_plane_bounded_volume.html#a2381ee685a1657cb601f1859ed8bc9b0":[5,0,6,14,4],
 "class_ogre_1_1_plane_bounded_volume.html#a477b753b9fda0c99ccce3e5195b2d7a8":[5,0,6,14,5],
 "class_ogre_1_1_plane_bounded_volume.html#a4d323aac2569fdb268dd6dda2801896e":[5,0,6,14,7],
-"class_ogre_1_1_plane_bounded_volume.html#a52f7c389144c1c587d7fea9e2b8d2a12":[5,0,6,14,0],
 "class_ogre_1_1_plane_bounded_volume.html#a9f3907950c9fd279e01ac1d4a03d9871":[5,0,6,14,1],
 "class_ogre_1_1_plane_bounded_volume.html#ac92a3d627da4cadbc9ebe7331b368e6e":[5,0,6,14,3],
+"class_ogre_1_1_plane_bounded_volume.html#adffb808d81baf5b8342fc8959e8123bf":[5,0,6,14,0],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html":[5,0,9,30],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a37f0a7cdf7bdb53bfa98c9e3c8541c41":[5,0,9,30,1],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ac7f81d455b20245603c5d51f4b00ea90":[5,0,9,30,0],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#af82e119f79b5e4e91e599c27623977df":[5,0,9,30,2]
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#af82e119f79b5e4e91e599c27623977df":[5,0,9,30,2],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#af9f6f42dc4cd2b5368e380ff4297fdbf":[5,0,9,30,3],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html":[5,0,9,31],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a0fdd507e53ed2fecb42080c9c9fe85ec":[5,0,9,31,1],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a9c531d5dfdafb8b7f5927625c7f013ba":[5,0,9,31,0],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#aaab9fdf433d40a446a78c67828291812":[5,0,9,31,2],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#ab3bbcf2daee8b0f476e6618c988fcef8":[5,0,9,31,3],
+"class_ogre_1_1_platform_information.html":[5,0,2,29],
+"class_ogre_1_1_platform_information.html#a1b64c69682054e5e3d1563067fa19f68":[5,0,2,29,1],
+"class_ogre_1_1_platform_information.html#aae9beb453c6df1f32ad9949536a3f40f":[5,0,2,29,2],
+"class_ogre_1_1_platform_information.html#ab397833e2f858920d32be590c714336a":[5,0,2,29,3],
+"class_ogre_1_1_platform_information.html#ae04f524bd9f4e399eeb5307a39ab1f56":[5,0,2,29,4],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807":[5,0,2,29,0],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807a05a46e35faa66d778ed42a73233f3d59":[5,0,2,29,0,4],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807a15cd1f4c0b74a9fa9f9e5b9a74ab1616":[5,0,2,29,0,6],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807a15d04db9f54c246d2f71d8c7d2ee2a75":[5,0,2,29,0,11],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807a171794d6739d25f3bcf5f5f1ddffdfb1":[5,0,2,29,0,8],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807a1ae4263f68c419342c129ca694878307":[5,0,2,29,0,0],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807a1bea16c1677fe68834a2d76b968562d7":[5,0,2,29,0,15],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807a5fc4873770d764423e744f0c38205f9a":[5,0,2,29,0,12],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807a8b9a9e995ae9886ef33500254536cc6e":[5,0,2,29,0,1],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807a926da4b4266e9394a740a5b5d737abf2":[5,0,2,29,0,14],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807aa607177ead91f654dbc5c2444c5999b9":[5,0,2,29,0,2],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807ab02aebd522397209dc00ab5e580e1cd6":[5,0,2,29,0,7],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807ab8dc79e9c3f35aa7befa143234048020":[5,0,2,29,0,10],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807ac13691e4b73cb7643a41163944a9a5a5":[5,0,2,29,0,9],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807adb21fcf38fa8c6da129b284fe6098138":[5,0,2,29,0,13],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807af1d5c5e48b069e9cdfb96167836f5f8f":[5,0,2,29,0,5],
+"class_ogre_1_1_platform_information.html#af7f9306631264031789d89af0642a807af8fc92fa7cbc79a0c63ee8df4426f877":[5,0,2,29,0,3],
+"class_ogre_1_1_plugin.html":[5,0,2,30],
+"class_ogre_1_1_plugin.html#a02890fc726dd3163721bdbec1c60339a":[5,0,2,30,0],
+"class_ogre_1_1_plugin.html#a0e0115ae4937a5df6548758c9f1ef4b5":[5,0,2,30,2],
+"class_ogre_1_1_plugin.html#a17fe6741c49a0fb9153797c70bdb884b":[5,0,2,30,5],
+"class_ogre_1_1_plugin.html#a47748105a90ce86b7e0f99a6910bd31d":[5,0,2,30,6],
+"class_ogre_1_1_plugin.html#a556fd0c6a5a05cce82dc7df998c99c0f":[5,0,2,30,3],
+"class_ogre_1_1_plugin.html#a890da15775afd75c14e81bc6207de81f":[5,0,2,30,4],
+"class_ogre_1_1_plugin.html#a8f531cb7678768d34140e1aa15335f57":[5,0,2,30,1],
+"class_ogre_1_1_point_emitter.html":[5,2,10,13],
+"class_ogre_1_1_point_emitter.html#a29def4fec887d31359afefe60440c5ce":[5,2,10,13,1],
+"class_ogre_1_1_point_emitter.html#ab692eaa67eb9fbede0139434c74b4b45":[5,2,10,13,0],
+"class_ogre_1_1_polygon.html":[5,0,6,15],
+"class_ogre_1_1_polygon.html#a0d19a9876f714cde041e3b7c4598e3b4":[5,0,6,15,9],
+"class_ogre_1_1_polygon.html#a1530c1d4761371c423916f4b497d612e":[5,0,6,15,3],
+"class_ogre_1_1_polygon.html#a2326d35755fe008fb437c208c6b007d6":[5,0,6,15,13],
+"class_ogre_1_1_polygon.html#a268cd4fc6b3eab7805436795dc36d146":[5,0,6,15,17],
+"class_ogre_1_1_polygon.html#a54477f45af2ab161d65160461985cacc":[5,0,6,15,8],
+"class_ogre_1_1_polygon.html#a5dfaeaa196e2005a3a6acad151141d9a":[5,0,6,15,12],
+"class_ogre_1_1_polygon.html#a5fd6676a7f72ed2cb4b96262e7e0b448":[5,0,6,15,14],
+"class_ogre_1_1_polygon.html#a642f59093f01be26321a884468a29e54":[5,0,6,15,20],
+"class_ogre_1_1_polygon.html#a6c6bde3911911e1bdf7ff2ed93209eda":[5,0,6,15,15],
+"class_ogre_1_1_polygon.html#a72d1c26d937a8a3f8caad158c7d71745":[5,0,6,15,0],
+"class_ogre_1_1_polygon.html#a75ad4cca62e4f65b7f6007ee29c42644":[5,0,6,15,1],
+"class_ogre_1_1_polygon.html#a777fe4198b330b2df854b68128299f5c":[5,0,6,15,10],
+"class_ogre_1_1_polygon.html#a7ce008c85c18f7c28776a7e6b5fb60f3":[5,0,6,15,4],
+"class_ogre_1_1_polygon.html#a86fb38e409c2792034bb6754ff373dc0":[5,0,6,15,5],
+"class_ogre_1_1_polygon.html#a8853087632d98ac16fa4e1c04e537353":[5,0,6,15,6],
+"class_ogre_1_1_polygon.html#a88ae238bdf4e4074d76bffa45b587e37":[5,0,6,15,18],
+"class_ogre_1_1_polygon.html#a9d80e759f5c77ba5a308d298c8b498c2":[5,0,6,15,11],
+"class_ogre_1_1_polygon.html#a9db9518c3381e7a840610bf181d65b73":[5,0,6,15,16],
+"class_ogre_1_1_polygon.html#aa5ffcde9852d1d04d51751f7d3b6b794":[5,0,6,15,19],
+"class_ogre_1_1_polygon.html#ac32b2d0a6e7c0cee21471fdaf6da13c4":[5,0,6,15,7],
+"class_ogre_1_1_polygon.html#ae6e7019c9a29ef5eb95e6c063d355830":[5,0,6,15,2],
+"class_ogre_1_1_pool.html":[6,0,1,366],
+"class_ogre_1_1_pool.html":[7,0,0,366],
+"class_ogre_1_1_pool.html#a31c74c47be2a3c8e5abe93a8ac061bc7":[6,0,1,366,2],
+"class_ogre_1_1_pool.html#a31c74c47be2a3c8e5abe93a8ac061bc7":[7,0,0,366,2],
+"class_ogre_1_1_pool.html#a4fb09f4b25feb32de79b6f578359aab1":[6,0,1,366,1],
+"class_ogre_1_1_pool.html#a4fb09f4b25feb32de79b6f578359aab1":[7,0,0,366,1],
+"class_ogre_1_1_pool.html#a7bd667e735a8fdaf2e7017d436ba75a6":[6,0,1,366,0],
+"class_ogre_1_1_pool.html#a7bd667e735a8fdaf2e7017d436ba75a6":[7,0,0,366,0],
+"class_ogre_1_1_pool.html#abafd7c72963d86ef829c0373fe50aa7f":[6,0,1,366,3],
+"class_ogre_1_1_pool.html#abafd7c72963d86ef829c0373fe50aa7f":[7,0,0,366,3],
+"class_ogre_1_1_pool.html#af399adb462aa706c25e1e961cdfb5a1e":[6,0,1,366,4],
+"class_ogre_1_1_pool.html#af399adb462aa706c25e1e961cdfb5a1e":[7,0,0,366,4],
+"class_ogre_1_1_portal.html":[6,0,1,367],
+"class_ogre_1_1_portal.html":[7,0,0,367],
+"class_ogre_1_1_portal.html#a0782b90dedb9f30a0c908262af9bd184":[6,0,1,367,1],
+"class_ogre_1_1_portal.html#a0782b90dedb9f30a0c908262af9bd184":[7,0,0,367,1],
+"class_ogre_1_1_portal.html#a25d7a31a53171da1b75e35b0b5907292":[6,0,1,367,3],
+"class_ogre_1_1_portal.html#a25d7a31a53171da1b75e35b0b5907292":[7,0,0,367,3],
+"class_ogre_1_1_portal.html#a2ac4a2ed94658aecb3d99ad6540ccf82":[6,0,1,367,0],
+"class_ogre_1_1_portal.html#a2ac4a2ed94658aecb3d99ad6540ccf82":[7,0,0,367,0],
+"class_ogre_1_1_portal.html#a727e088f147250e0a12f39a68b22e33e":[6,0,1,367,2],
+"class_ogre_1_1_portal.html#a727e088f147250e0a12f39a68b22e33e":[7,0,0,367,2],
+"class_ogre_1_1_portal.html#a917bb783c4a52b0fde2cef512c12a096":[6,0,1,367,6],
+"class_ogre_1_1_portal.html#a917bb783c4a52b0fde2cef512c12a096":[7,0,0,367,6],
+"class_ogre_1_1_portal.html#ad311b50599405981fdcbc55e4c4d5797":[6,0,1,367,4],
+"class_ogre_1_1_portal.html#ad311b50599405981fdcbc55e4c4d5797":[7,0,0,367,4],
+"class_ogre_1_1_portal.html#af5e87bad80832d026f6f79c7edd1569e":[6,0,1,367,5],
+"class_ogre_1_1_portal.html#af5e87bad80832d026f6f79c7edd1569e":[7,0,0,367,5],
+"class_ogre_1_1_portal_base.html":[6,0,1,368],
+"class_ogre_1_1_portal_base.html":[7,0,0,368],
+"class_ogre_1_1_portal_base.html#a015feef401ddf609ac00f495956b7ddd":[6,0,1,368,12],
+"class_ogre_1_1_portal_base.html#a015feef401ddf609ac00f495956b7ddd":[7,0,0,368,12],
+"class_ogre_1_1_portal_base.html#a02110b4b9d0ddb498d384cf6f3ec8951":[6,0,1,368,9],
+"class_ogre_1_1_portal_base.html#a02110b4b9d0ddb498d384cf6f3ec8951":[7,0,0,368,9],
+"class_ogre_1_1_portal_base.html#a040f340da1d8cead46d8543b73811df5":[6,0,1,368,34],
+"class_ogre_1_1_portal_base.html#a040f340da1d8cead46d8543b73811df5":[7,0,0,368,34],
+"class_ogre_1_1_portal_base.html#a05c4b91cbe5f80f315b6820c209e4404":[6,0,1,368,6],
+"class_ogre_1_1_portal_base.html#a05c4b91cbe5f80f315b6820c209e4404":[7,0,0,368,6],
+"class_ogre_1_1_portal_base.html#a0ae708437e8708798abebb19d2e0a5cc":[6,0,1,368,25],
+"class_ogre_1_1_portal_base.html#a0ae708437e8708798abebb19d2e0a5cc":[7,0,0,368,25],
+"class_ogre_1_1_portal_base.html#a113fc83791e8c50ca6c57f5c7a39a4d1":[6,0,1,368,29],
+"class_ogre_1_1_portal_base.html#a113fc83791e8c50ca6c57f5c7a39a4d1":[7,0,0,368,29],
+"class_ogre_1_1_portal_base.html#a227c3139d54a67d74d26cc69aae9faf8":[6,0,1,368,42],
+"class_ogre_1_1_portal_base.html#a227c3139d54a67d74d26cc69aae9faf8":[7,0,0,368,42],
+"class_ogre_1_1_portal_base.html#a34a188f0db37e579b37a83a59f7087fa":[6,0,1,368,36],
+"class_ogre_1_1_portal_base.html#a34a188f0db37e579b37a83a59f7087fa":[7,0,0,368,36],
+"class_ogre_1_1_portal_base.html#a420b2efcf0a35aed9c4d59a7ea4e3e79":[6,0,1,368,41],
+"class_ogre_1_1_portal_base.html#a420b2efcf0a35aed9c4d59a7ea4e3e79":[7,0,0,368,41],
+"class_ogre_1_1_portal_base.html#a468e1886f099a140f750aca9a437a670":[6,0,1,368,18],
+"class_ogre_1_1_portal_base.html#a468e1886f099a140f750aca9a437a670":[7,0,0,368,18],
+"class_ogre_1_1_portal_base.html#a47bd5bd57cb5fa2076a1f7848bf9b65f":[6,0,1,368,11],
+"class_ogre_1_1_portal_base.html#a47bd5bd57cb5fa2076a1f7848bf9b65f":[7,0,0,368,11],
+"class_ogre_1_1_portal_base.html#a490a19e184b64cad03fe2013b371bcf3":[6,0,1,368,5],
+"class_ogre_1_1_portal_base.html#a490a19e184b64cad03fe2013b371bcf3":[7,0,0,368,5],
+"class_ogre_1_1_portal_base.html#a4b8f189a0c307e8ce05e2c62a486115f":[6,0,1,368,19],
+"class_ogre_1_1_portal_base.html#a4b8f189a0c307e8ce05e2c62a486115f":[7,0,0,368,19],
+"class_ogre_1_1_portal_base.html#a5cb47323a95b9298f1e706a52213fae1":[6,0,1,368,35],
+"class_ogre_1_1_portal_base.html#a5cb47323a95b9298f1e706a52213fae1":[7,0,0,368,35],
+"class_ogre_1_1_portal_base.html#a5cf356caed0ca1812cf442df2a27302d":[6,0,1,368,33]
 };
