@@ -1,125 +1,5 @@
 var NAVTREEINDEX36 =
 {
-"class_ogre_1_1_render_window.html#a756b752e30cad1f8f71b69c86bc2f6f2":[5,0,7,35,6],
-"class_ogre_1_1_render_window.html#a7bd367fcadf2aba85f08cf9c5fd27e22":[5,0,7,35,2],
-"class_ogre_1_1_render_window.html#a7e174d7113a1f466faa5dc92a0496c57":[5,0,7,35,17],
-"class_ogre_1_1_render_window.html#a91ac294d89632996384d89bb9e8f6d78":[5,0,7,35,12],
-"class_ogre_1_1_render_window.html#a96ec12856ec5384456c9d0a86bd76568":[5,0,7,35,23],
-"class_ogre_1_1_render_window.html#aac75d5f9db876e365ce7ad1fe731dd2f":[5,0,7,35,21],
-"class_ogre_1_1_render_window.html#aaf42ce91cddbebe097c168dba749159b":[5,0,7,35,13],
-"class_ogre_1_1_render_window.html#ab35ae246281e7a6ee3cd820e01e4910b":[5,0,7,35,18],
-"class_ogre_1_1_render_window.html#abac0a19f1940b7cfbae21686aeccab51":[5,0,7,35,16],
-"class_ogre_1_1_render_window.html#ac1231f0ddcc0a526baf6e2e27fe50a5c":[5,0,7,35,20],
-"class_ogre_1_1_render_window.html#ac2b77b29188e2dd5e85ad0d9e1a4ad79":[5,0,7,35,8],
-"class_ogre_1_1_render_window.html#ad5231af00c0091449dc14ed627189d0c":[5,0,7,35,3],
-"class_ogre_1_1_render_window.html#ada43e7327c5df4905069694fb707885e":[5,0,7,35,10],
-"class_ogre_1_1_render_window.html#ada987a799db45db2a6305ca16d8664e8":[5,0,7,35,5],
-"class_ogre_1_1_render_window.html#ada9c46d189e9dd3e4a06744c359a762a":[5,0,7,35,15],
-"class_ogre_1_1_render_window.html#aef01aef07c52dd58fe07e68e602931a1":[5,0,7,35,19],
-"class_ogre_1_1_render_window.html#af8615122f9bc57a80ffc8c73a75d2852":[5,0,7,35,14],
-"class_ogre_1_1_render_window.html#af9153ad94900ca36534f25537b35a9cd":[5,0,7,35,9],
-"class_ogre_1_1_renderable.html":[5,0,9,38],
-"class_ogre_1_1_renderable.html#a09508b487562891913cf565650bf569c":[5,0,9,38,16],
-"class_ogre_1_1_renderable.html#a0c726a0326e8a7d9e80d030541b6bddf":[5,0,9,38,19],
-"class_ogre_1_1_renderable.html#a13f1bbc23e57df9084bed76acb3b5500":[5,0,9,38,27],
-"class_ogre_1_1_renderable.html#a196b591da8b57799ef3c960c60552876":[5,0,9,38,26],
-"class_ogre_1_1_renderable.html#a26fe85d5b382966c77a9b104695b0a7c":[5,0,9,38,10],
-"class_ogre_1_1_renderable.html#a2f770d6ba9b3d97bdc63ecf0e3888aab":[5,0,9,38,23],
-"class_ogre_1_1_renderable.html#a32353addc2f1d02512314b5d1a53c5c1":[5,0,9,38,15],
-"class_ogre_1_1_renderable.html#a3621cee2a019e59d3671c1a204caf4c7":[5,0,9,38,5],
-"class_ogre_1_1_renderable.html#a3d5e8933145d36977b8c2b64e307bc59":[5,0,9,38,17],
-"class_ogre_1_1_renderable.html#a4136ce4b9d3add5203339327015d872d":[5,0,9,38,11],
-"class_ogre_1_1_renderable.html#a529f5e35e023d837787658590e27ede0":[5,0,9,38,6],
-"class_ogre_1_1_renderable.html#a6d06a2cec2b2a25fd4cc92d615d3d875":[5,0,9,38,18],
-"class_ogre_1_1_renderable.html#a742052f8185975e8b92103c924b005d3":[5,0,9,38,22],
-"class_ogre_1_1_renderable.html#a77230eea8136b7c296cc0a5db1dba9ee":[5,0,9,38,8],
-"class_ogre_1_1_renderable.html#a812d3b0f5df694b92084a98387d8f215":[5,0,9,38,20],
-"class_ogre_1_1_renderable.html#a869e7226c48fbff5dafef92b2b929b5e":[5,0,9,38,14],
-"class_ogre_1_1_renderable.html#a897d64f73a5e6ccc45d52a88e86392e1":[5,0,9,38,9],
-"class_ogre_1_1_renderable.html#aba213eec48158dd61bdb546c67e3cba9":[5,0,9,38,4],
-"class_ogre_1_1_renderable.html#abd85c7ae6f5de865b8037f37e426886e":[5,0,9,38,25],
-"class_ogre_1_1_renderable.html#ad59d950e62159594350bffc87dc094ba":[5,0,9,38,21],
-"class_ogre_1_1_renderable.html#ae53cff42a16304f582ef83ad3017d614":[5,0,9,38,13],
-"class_ogre_1_1_renderable.html#ae5a6101851f1e45229f7b4bc20a69815":[5,0,9,38,2],
-"class_ogre_1_1_renderable.html#ae944917873dd68126c129f05e51622d3":[5,0,9,38,24],
-"class_ogre_1_1_renderable.html#aed186856b59bf967f3188bfa70546957":[5,0,9,38,1],
-"class_ogre_1_1_renderable.html#af2c110b7d0ce7f3508dd6066a84a5e71":[5,0,9,38,3],
-"class_ogre_1_1_renderable.html#af630e6230261ecca2ecbfcf0b0ee9ce9":[5,0,9,38,12],
-"class_ogre_1_1_renderable.html#af85238872bb197dea36acf21a578ecec":[5,0,9,38,28],
-"class_ogre_1_1_renderable.html#afcbf4cb36d5911a9d40a40c57e94f23b":[5,0,9,38,7],
-"class_ogre_1_1_renderable_1_1_visitor.html":[5,0,9,38,0],
-"class_ogre_1_1_renderable_1_1_visitor.html#a67b2d4e6dc274102523fde6b20d79ff5":[5,0,9,38,0,0],
-"class_ogre_1_1_renderable_1_1_visitor.html#acc21c51c774281b1030860b8c72c315e":[5,0,9,38,0,1],
-"class_ogre_1_1_rendering_a_p_i_exception.html":[5,0,2,37],
-"class_ogre_1_1_rendering_a_p_i_exception.html#aa3f950b457a33a114a74f9b8993a885d":[5,0,2,37,0],
-"class_ogre_1_1_resource.html":[5,0,8,22],
-"class_ogre_1_1_resource.html#a0373e75f7dbe77968a39f490ad0d3327":[5,0,8,22,11],
-"class_ogre_1_1_resource.html#a03c52d5285092f0a5d21ad83a0643814":[5,0,8,22,3],
-"class_ogre_1_1_resource.html#a07e619aa09d3bc6789a6667cb4fc572c":[5,0,8,22,1],
-"class_ogre_1_1_resource.html#a07e619aa09d3bc6789a6667cb4fc572ca133a073b86c346096237063f99870fc1":[5,0,8,22,1,4],
-"class_ogre_1_1_resource.html#a07e619aa09d3bc6789a6667cb4fc572ca28d463296cacdfc115dbc3fb02d00e94":[5,0,8,22,1,0],
-"class_ogre_1_1_resource.html#a07e619aa09d3bc6789a6667cb4fc572ca4228d390b3a9ed614001db177d1f441e":[5,0,8,22,1,3],
-"class_ogre_1_1_resource.html#a07e619aa09d3bc6789a6667cb4fc572caa38cbef7605fc4bff6da2f34599ace8f":[5,0,8,22,1,2],
-"class_ogre_1_1_resource.html#a07e619aa09d3bc6789a6667cb4fc572cab43c913411f4a96722902f17b88f10fb":[5,0,8,22,1,5],
-"class_ogre_1_1_resource.html#a07e619aa09d3bc6789a6667cb4fc572caf138fc9087e0dc755bff08a83720cbb5":[5,0,8,22,1,1],
-"class_ogre_1_1_resource.html#a089562812828920fe1d1a371acf393e7":[5,0,8,22,4],
-"class_ogre_1_1_resource.html#a126372a71844bda74011ccd5088f706c":[5,0,8,22,20],
-"class_ogre_1_1_resource.html#a1aa750a4b994f2b1066220936cdfdb94":[5,0,8,22,2],
-"class_ogre_1_1_resource.html#a1aa750a4b994f2b1066220936cdfdb94a6ee542226e1cf18df28ab88426be6809":[5,0,8,22,2,1],
-"class_ogre_1_1_resource.html#a1aa750a4b994f2b1066220936cdfdb94a70589e0b87b09b0a4fd98ce490dc9782":[5,0,8,22,2,2],
-"class_ogre_1_1_resource.html#a1aa750a4b994f2b1066220936cdfdb94ab49695ac949df3a7d2e2f9a03267097c":[5,0,8,22,2,0],
-"class_ogre_1_1_resource.html#a1aa750a4b994f2b1066220936cdfdb94ad83abf165de5cfa1a4c8e0cd5471ad2c":[5,0,8,22,2,4],
-"class_ogre_1_1_resource.html#a1aa750a4b994f2b1066220936cdfdb94ae5f2eca654bd810da4c774570a5b4b77":[5,0,8,22,2,3],
-"class_ogre_1_1_resource.html#a350b287fa3e83a389221274f68760008":[5,0,8,22,5],
-"class_ogre_1_1_resource.html#a367f6fe60bb211cb4c32e3825ca67e4c":[5,0,8,22,21],
-"class_ogre_1_1_resource.html#a3c49142f739ba8fb56d6e7b3db235fb7":[5,0,8,22,23],
-"class_ogre_1_1_resource.html#a3f0f5f3e9b31dc550c08c64e500ce12a":[5,0,8,22,8],
-"class_ogre_1_1_resource.html#a4bb074a87acae93d982052a7c963627c":[5,0,8,22,27],
-"class_ogre_1_1_resource.html#a5016aec1762b026997ddd346775879ef":[5,0,8,22,7],
-"class_ogre_1_1_resource.html#a5513ffce404b14cff72846318b018d32":[5,0,8,22,22],
-"class_ogre_1_1_resource.html#a56125b3075687bb7b9f8777af1ae2533":[5,0,8,22,16],
-"class_ogre_1_1_resource.html#a5ed6d6e514e60e22651aaf2eb6a1bead":[5,0,8,22,31],
-"class_ogre_1_1_resource.html#a61e4debda04414e03f01fff1f67dcae0":[5,0,8,22,24],
-"class_ogre_1_1_resource.html#a665ef26b34f83f69feac0a7486da131e":[5,0,8,22,18],
-"class_ogre_1_1_resource.html#a699d1c851f494a8d5d23d23b695ceb47":[5,0,8,22,6],
-"class_ogre_1_1_resource.html#a6fb19a3770f7614bc5d0f05f25aaf8f5":[5,0,8,22,32],
-"class_ogre_1_1_resource.html#a7e248a1cca0662418d4ab3f63c2e7cf6":[5,0,8,22,28],
-"class_ogre_1_1_resource.html#a89665eeed8820b2aacfab028a9ad0a3b":[5,0,8,22,26],
-"class_ogre_1_1_resource.html#aa31bef1bfaa87731622e56f11b548e27":[5,0,8,22,10],
-"class_ogre_1_1_resource.html#aa5d6f3f7e73b77b233fc62b11f270e4d":[5,0,8,22,25],
-"class_ogre_1_1_resource.html#aaf3746937cd11864f53bc1c3b4437541":[5,0,8,22,33],
-"class_ogre_1_1_resource.html#aaf9a9f934a2de09611c503c8f24f45df":[5,0,8,22,15],
-"class_ogre_1_1_resource.html#ad1d41a6867f71d6dd445db5b1f44ca27":[5,0,8,22,17],
-"class_ogre_1_1_resource.html#ada1a90494dce289acbfe4124d9314384":[5,0,8,22,19],
-"class_ogre_1_1_resource.html#ade85e4d5579519e4117a84789c0ae8fd":[5,0,8,22,29],
-"class_ogre_1_1_resource.html#ae229b1f58092109adef55bfc6f864d79":[5,0,8,22,12],
-"class_ogre_1_1_resource.html#aea002983a30ce4db78ab523e6ad08046":[5,0,8,22,14],
-"class_ogre_1_1_resource.html#af80ca873097a3a595011167ec3cb8189":[5,0,8,22,13],
-"class_ogre_1_1_resource.html#af94ea11da8a78e6097a6646fa3d0115a":[5,0,8,22,9],
-"class_ogre_1_1_resource.html#afcb4a61b965600a67ca2c2f060821db9":[5,0,8,22,30],
-"class_ogre_1_1_resource_1_1_listener.html":[5,0,8,22,0],
-"class_ogre_1_1_resource_1_1_listener.html#a087cbfc9a4ad6490b09884d482932945":[5,0,8,22,0,0],
-"class_ogre_1_1_resource_1_1_listener.html#a7951abdcff85efd6cf58a49d94442f67":[5,0,8,22,0,2],
-"class_ogre_1_1_resource_1_1_listener.html#a9f8cdeb73a65a6a1c018e5ac783dfafe":[5,0,8,22,0,3],
-"class_ogre_1_1_resource_1_1_listener.html#ac8d962ac52ef53a2ad6ddbdc5b6c9655":[5,0,8,22,0,1],
-"class_ogre_1_1_resource_background_queue.html":[5,0,8,23],
-"class_ogre_1_1_resource_background_queue.html#a1197dd668ed663bc9d735a7e0944aecf":[5,0,8,23,11],
-"class_ogre_1_1_resource_background_queue.html#a3207a7700d3325a27579041820d02ec8":[5,0,8,23,10],
-"class_ogre_1_1_resource_background_queue.html#a407ce0c4668bdf5558e15f7f99c37fa8":[5,0,8,23,1],
-"class_ogre_1_1_resource_background_queue.html#a4afe3c604c94c70c5ef82230dbc74395":[5,0,8,23,5],
-"class_ogre_1_1_resource_background_queue.html#a4e986bf164fb24b7dbfb28b3c52b21c2":[5,0,8,23,7],
-"class_ogre_1_1_resource_background_queue.html#a5b904db390474e10b4c124f56f7f7deb":[5,0,8,23,8],
-"class_ogre_1_1_resource_background_queue.html#a65a4875e331a16b3e0635f636e8b8381":[5,0,8,23,3],
-"class_ogre_1_1_resource_background_queue.html#a66b7d9af907b30c46666dfad25100323":[5,0,8,23,2],
-"class_ogre_1_1_resource_background_queue.html#a74525d1f4e99a24afa3cc0800f0b6ce9":[5,0,8,23,0],
-"class_ogre_1_1_resource_background_queue.html#a7588e0bee5ed34b8f013fcf6360a84b5":[5,0,8,23,6],
-"class_ogre_1_1_resource_background_queue.html#ab9060bfd6e3aed6eeb269ca8e60cd162":[5,0,8,23,9],
-"class_ogre_1_1_resource_background_queue.html#abce105d63ee0e5efcd315f0d3a651b61":[5,0,8,23,4],
-"class_ogre_1_1_resource_group_listener.html":[5,0,8,24],
-"class_ogre_1_1_resource_group_listener.html#a2127468fe0a61339f4a9e0490d8d6073":[5,0,8,24,6],
-"class_ogre_1_1_resource_group_listener.html#a247dbd6b4dfd78d38470e011a875b3f3":[5,0,8,24,13],
-"class_ogre_1_1_resource_group_listener.html#a4e895decbc7404e15c9a1772384c277e":[5,0,8,24,15],
-"class_ogre_1_1_resource_group_listener.html#a6373c4d2c4be1754ba88075130090a4e":[5,0,8,24,5],
 "class_ogre_1_1_resource_group_listener.html#a89dcbff8ca3b29c666c2c3726d6e4aea":[5,0,8,24,1],
 "class_ogre_1_1_resource_group_listener.html#a9c13bf3dea8b29dfa4f59b8094b973bc":[5,0,8,24,10],
 "class_ogre_1_1_resource_group_listener.html#aabfd15f40381229c50551bd064a6b6e5":[5,0,8,24,12],
@@ -154,7 +34,7 @@ var NAVTREEINDEX36 =
 "class_ogre_1_1_resource_group_manager.html#a3562a410d5854514d3b662b5968bab33":[5,0,8,25,10],
 "class_ogre_1_1_resource_group_manager.html#a37bd72c78c5388ef046dec74f1e41e09":[5,0,8,25,70],
 "class_ogre_1_1_resource_group_manager.html#a3808397e9d3a0f53399b587b4db147d2":[5,0,8,25,60],
-"class_ogre_1_1_resource_group_manager.html#a3b5d91064860e4cabd8879bc9cab1ebf":[5,0,8,25,2],
+"class_ogre_1_1_resource_group_manager.html#a3961d693f8c5b8326b840f2ae1dd9f90":[5,0,8,25,5],
 "class_ogre_1_1_resource_group_manager.html#a3c7d7dc6bb59e43db49e77cd3d8a44c4":[5,0,8,25,71],
 "class_ogre_1_1_resource_group_manager.html#a3d95100bdec0d08a7e0df75fece470f0":[5,0,8,25,40],
 "class_ogre_1_1_resource_group_manager.html#a407415b99c1df3b275e2609e16e8b39f":[5,0,8,25,44],
@@ -180,24 +60,23 @@ var NAVTREEINDEX36 =
 "class_ogre_1_1_resource_group_manager.html#a791bfb9582a3ce16425371e66b899128":[5,0,8,25,50],
 "class_ogre_1_1_resource_group_manager.html#a7b09da95b6e1dcecdee14a9e37a6c555":[5,0,8,25,51],
 "class_ogre_1_1_resource_group_manager.html#a7e64ea1228280465675f0b1438d21e4a":[5,0,8,25,53],
-"class_ogre_1_1_resource_group_manager.html#a8aaadee4bb1dbfefd2cfa23772cba7e3":[5,0,8,25,5],
 "class_ogre_1_1_resource_group_manager.html#a8dd6791186bfa655584a2c91c3e18ee3":[5,0,8,25,29],
 "class_ogre_1_1_resource_group_manager.html#a8eaa9df18f04d69402f7369dca5a4cca":[5,0,8,25,21],
 "class_ogre_1_1_resource_group_manager.html#a8f8027c8d44d25f2d3b18d0a8caaa42d":[5,0,8,25,42],
 "class_ogre_1_1_resource_group_manager.html#a90bbba7b33448bb46a58f0759faa657a":[5,0,8,25,25],
-"class_ogre_1_1_resource_group_manager.html#a9106d334f973afba0e7c6259d0a71246":[5,0,8,25,3],
 "class_ogre_1_1_resource_group_manager.html#a9b4ec48c9f25a6e37fa7d4cb5eac5520":[5,0,8,25,55],
 "class_ogre_1_1_resource_group_manager.html#a9c1ba0f11d134d0b5614391ca836844c":[5,0,8,25,8],
 "class_ogre_1_1_resource_group_manager.html#a9e7c5dfc9905d1eee64289d9dc0fa6a5":[5,0,8,25,43],
 "class_ogre_1_1_resource_group_manager.html#aafd69be90e1774f2a4b34c4e6dcaa38a":[5,0,8,25,54],
 "class_ogre_1_1_resource_group_manager.html#ab05122c94423565cf5e83b1dc2afefa1":[5,0,8,25,48],
 "class_ogre_1_1_resource_group_manager.html#ab518acba863b43d7c920869e33b28c51":[5,0,8,25,32],
-"class_ogre_1_1_resource_group_manager.html#ab8c13d88ead5cb8b29bcf99d3e65b0e6":[5,0,8,25,4],
+"class_ogre_1_1_resource_group_manager.html#abb6fa5b78ff9f77f35b69cefd9d50283":[5,0,8,25,3],
 "class_ogre_1_1_resource_group_manager.html#acb9bf6a75143b0ce49a0af7d05b213fe":[5,0,8,25,49],
 "class_ogre_1_1_resource_group_manager.html#acd4fe53cc4f0ab2800d7675fc4cba9b2":[5,0,8,25,67],
 "class_ogre_1_1_resource_group_manager.html#ad843c3889b80ebd8e01aed9cf81b3769":[5,0,8,25,6],
 "class_ogre_1_1_resource_group_manager.html#aded812a215c5be14bca70132f2eedaec":[5,0,8,25,33],
 "class_ogre_1_1_resource_group_manager.html#ae01e1cd42ad060adbeeddd5c500ac8c8":[5,0,8,25,12],
+"class_ogre_1_1_resource_group_manager.html#ae26eacec6d13149f46c47d88c7110625":[5,0,8,25,2],
 "class_ogre_1_1_resource_group_manager.html#ae7d6c2af0066f761a7c7e9ab17fe6bae":[5,0,8,25,27],
 "class_ogre_1_1_resource_group_manager.html#ae8b0855faf84539b7979775c37efd590":[5,0,8,25,31],
 "class_ogre_1_1_resource_group_manager.html#ae91a1f693e5f2954e4b352886ddde669":[5,0,8,25,64],
@@ -205,6 +84,7 @@ var NAVTREEINDEX36 =
 "class_ogre_1_1_resource_group_manager.html#aebc185a7ef51b89887e941eed2cde64b":[5,0,8,25,22],
 "class_ogre_1_1_resource_group_manager.html#af5c901bfb116d7f70f4542bd828784f4":[5,0,8,25,9],
 "class_ogre_1_1_resource_group_manager.html#af83db8197424c1f2782fdbc163857b76":[5,0,8,25,11],
+"class_ogre_1_1_resource_group_manager.html#af875db11dc5aba6ab72ec40296af9a5c":[5,0,8,25,4],
 "class_ogre_1_1_resource_group_manager.html#af88e3d5af3a2f1234d5f0c57a63ff605":[5,0,8,25,24],
 "class_ogre_1_1_resource_group_manager.html#afdf17a57c9a47226e42625e8046f6b49":[5,0,8,25,65],
 "class_ogre_1_1_resource_loading_listener.html":[5,0,8,26],
@@ -220,34 +100,154 @@ var NAVTREEINDEX36 =
 "class_ogre_1_1_resource_manager.html#a257ae8a9ac7538581173b7ddcf7b3f19":[5,0,8,27,21],
 "class_ogre_1_1_resource_manager.html#a27fb21c71096b32c612945a54b008b1a":[5,0,8,27,35],
 "class_ogre_1_1_resource_manager.html#a2b2b134c38b4ead5ef13bd157fe2329a":[5,0,8,27,7],
+"class_ogre_1_1_resource_manager.html#a31a40854bf7ade620d6632550f2c474b":[5,0,8,27,3],
 "class_ogre_1_1_resource_manager.html#a379c3ff20c97fcd13db3bc7841b4b560":[5,0,8,27,34],
 "class_ogre_1_1_resource_manager.html#a40769092850d5b296e1d1a9190631700":[5,0,8,27,30],
 "class_ogre_1_1_resource_manager.html#a4350b30d83790f208a9fdd1197ce9c95":[5,0,8,27,33],
 "class_ogre_1_1_resource_manager.html#a4a0a809ceb7ddf690fc3d681bd56bc83":[5,0,8,27,28],
 "class_ogre_1_1_resource_manager.html#a4d3289d4636168230da11c1c9794db59":[5,0,8,27,45],
 "class_ogre_1_1_resource_manager.html#a4dda8323b265a00638dd29a4fa6510bc":[5,0,8,27,18],
+"class_ogre_1_1_resource_manager.html#a4f7da59507a5a8550ea97615ff9afff0":[5,0,8,27,5],
 "class_ogre_1_1_resource_manager.html#a532e96fbeac065b4a7866b4302a90618":[5,0,8,27,10],
 "class_ogre_1_1_resource_manager.html#a54d1843a43aebb13542312cd17134e6a":[5,0,8,27,32],
 "class_ogre_1_1_resource_manager.html#a57e22b305d763f9ede5bda93f31051ca":[5,0,8,27,38],
-"class_ogre_1_1_resource_manager.html#a5955c25987f910c790ac219f6fe82a44":[5,0,8,27,5],
 "class_ogre_1_1_resource_manager.html#a62ddf3760bd9871b25ca016732e149d1":[5,0,8,27,13],
 "class_ogre_1_1_resource_manager.html#a6871e913a62e1b419438e3169bc72bd3":[5,0,8,27,23],
-"class_ogre_1_1_resource_manager.html#a6cd7a309e70c01984ce1cacce40a81c9":[5,0,8,27,4],
 "class_ogre_1_1_resource_manager.html#a6ce966e769770ce9f90d77eddc2c30a3":[5,0,8,27,25],
+"class_ogre_1_1_resource_manager.html#a6d9424ed93bc679b5543ddc9fc9fe41b":[5,0,8,27,4],
 "class_ogre_1_1_resource_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[5,0,8,27,24],
 "class_ogre_1_1_resource_manager.html#a700088a63eabb0f6cb1fac96686db464":[5,0,8,27,8],
-"class_ogre_1_1_resource_manager.html#a7014a5df174738d8f93b1f046968f362":[5,0,8,27,3],
 "class_ogre_1_1_resource_manager.html#a7913c36c02ef03007ff1a1c76ddf7710":[5,0,8,27,44],
 "class_ogre_1_1_resource_manager.html#a81b8a65b13a613bf57656c6af0ab1ac6":[5,0,8,27,26],
 "class_ogre_1_1_resource_manager.html#a82b76280229c498b8d66f64b2a848447":[5,0,8,27,39],
+"class_ogre_1_1_resource_manager.html#a849d25862f43feec07252f0ae139c3e4":[5,0,8,27,2],
 "class_ogre_1_1_resource_manager.html#a84e25cc5ad09ff7567d1fed7429433a3":[5,0,8,27,20],
 "class_ogre_1_1_resource_manager.html#a8b925fa7454c0de2e57c2576435ebed3":[5,0,8,27,27],
 "class_ogre_1_1_resource_manager.html#a93b40c858020f2bbbcebcd4dc72a6321":[5,0,8,27,19],
 "class_ogre_1_1_resource_manager.html#aa8b761abb06d74347e9636550307ccd9":[5,0,8,27,42],
 "class_ogre_1_1_resource_manager.html#aa9608544a7beb1b0e43835877ab62788":[5,0,8,27,16],
-"class_ogre_1_1_resource_manager.html#aaf0404e63b54d9333ed0e4193d265a26":[5,0,8,27,1],
 "class_ogre_1_1_resource_manager.html#ab284e49ab87b8178a684ed87b454f59b":[5,0,8,27,36],
 "class_ogre_1_1_resource_manager.html#ab9676c551c591baf0c5ccbeefd5b8ae8":[5,0,8,27,29],
 "class_ogre_1_1_resource_manager.html#abd807a5a8f5754af45fc60db40b455d5":[5,0,8,27,11],
-"class_ogre_1_1_resource_manager.html#ac3f365e1d71fbe328637a681171d7acd":[5,0,8,27,9]
+"class_ogre_1_1_resource_manager.html#ac3f365e1d71fbe328637a681171d7acd":[5,0,8,27,9],
+"class_ogre_1_1_resource_manager.html#ac401b57afcc205728a3821065aef6238":[5,0,8,27,12],
+"class_ogre_1_1_resource_manager.html#ae071093e2681923ddf1d661087b44e4d":[5,0,8,27,40],
+"class_ogre_1_1_resource_manager.html#aea812804e59454cd29ee531ebab56b1b":[5,0,8,27,22],
+"class_ogre_1_1_resource_manager.html#aeaa1410333b7bcea14b00c360112a528":[5,0,8,27,17],
+"class_ogre_1_1_resource_manager.html#aef014a01154b840f2fe417dd09167782":[5,0,8,27,37],
+"class_ogre_1_1_resource_manager.html#aef35da7d45100ccdb828962b58e50adf":[5,0,8,27,6],
+"class_ogre_1_1_resource_manager.html#af1a871ac005af0be0b8c1857a4f8eea9":[5,0,8,27,31],
+"class_ogre_1_1_resource_manager.html#af484f2b60c8d9bc87f37fa8af8e630c5":[5,0,8,27,1],
+"class_ogre_1_1_resource_manager_1_1_resource_pool.html":[5,0,8,27,0],
+"class_ogre_1_1_resource_manager_1_1_resource_pool.html#a1992b6d48e0c64024954426b609a0bbe":[5,0,8,27,0,2],
+"class_ogre_1_1_resource_manager_1_1_resource_pool.html#a96f9becf6ab3f185f59780d3d267049b":[5,0,8,27,0,0],
+"class_ogre_1_1_resource_manager_1_1_resource_pool.html#aac2cb15bdfaa605297e31e85d452e278":[5,0,8,27,0,1],
+"class_ogre_1_1_resource_manager_1_1_resource_pool.html#ade7e78614948dfa5f01add6c82b1882e":[5,0,8,27,0,3],
+"class_ogre_1_1_ribbon_trail.html":[5,0,1,22],
+"class_ogre_1_1_ribbon_trail.html#a16c72a3ce2081cbbf3cc01bf907bfa67":[5,0,1,22,23],
+"class_ogre_1_1_ribbon_trail.html#a443d866366335cbf106fe4cc31c80c86":[5,0,1,22,22],
+"class_ogre_1_1_ribbon_trail.html#a4b9562a9764b7ce5d4db6fc9c59deff8":[5,0,1,22,12],
+"class_ogre_1_1_ribbon_trail.html#a58422667fcb7d29dfaca1f0a851ad628":[5,0,1,22,15],
+"class_ogre_1_1_ribbon_trail.html#a7871d546a48c127e6068ef7f408842d5":[5,0,1,22,5],
+"class_ogre_1_1_ribbon_trail.html#a7ef20f333691fe7fb5cce5bb1d7c8012":[5,0,1,22,2],
+"class_ogre_1_1_ribbon_trail.html#a7fd33999495bf1c773331a5db80b0cac":[5,0,1,22,19],
+"class_ogre_1_1_ribbon_trail.html#a8a166f5eebda9774c286a90963eb2a46":[5,0,1,22,3],
+"class_ogre_1_1_ribbon_trail.html#a8ac5a54349431efa4c210b7a74f60d91":[5,0,1,22,26],
+"class_ogre_1_1_ribbon_trail.html#a9e71b08aa64add5e1262e2de15b0becc":[5,0,1,22,17],
+"class_ogre_1_1_ribbon_trail.html#a9ef35b8521c1007645abc1eaa3098832":[5,0,1,22,20],
+"class_ogre_1_1_ribbon_trail.html#a9f1fb9b8c18a39375d65cac3441a2fb4":[5,0,1,22,7],
+"class_ogre_1_1_ribbon_trail.html#aa51b1f3a6fee616dfecb05965db78fe4":[5,0,1,22,6],
+"class_ogre_1_1_ribbon_trail.html#aa64743cce7cede32aadf23a0d6298958":[5,0,1,22,16],
+"class_ogre_1_1_ribbon_trail.html#aa7a7e14c85c2875f9c70982cdb5aab6b":[5,0,1,22,24],
+"class_ogre_1_1_ribbon_trail.html#aa87dbc42370145c7829bce54b0919e03":[5,0,1,22,1],
+"class_ogre_1_1_ribbon_trail.html#ab625b0ac07ebb001cf22e089e4ef05ec":[5,0,1,22,18],
+"class_ogre_1_1_ribbon_trail.html#ab67b6492b1c8e5687d9623f1518e86ac":[5,0,1,22,25],
+"class_ogre_1_1_ribbon_trail.html#abd091e77be6e22fdd018aada0961f5c8":[5,0,1,22,21],
+"class_ogre_1_1_ribbon_trail.html#abeddfc60ef032d61276e5b694cb883df":[5,0,1,22,4],
+"class_ogre_1_1_ribbon_trail.html#ac710cc931767fc3b2018b4fac708678b":[5,0,1,22,11],
+"class_ogre_1_1_ribbon_trail.html#ac98c4fa0f7c412751c4352eb8d0e39a1":[5,0,1,22,13],
+"class_ogre_1_1_ribbon_trail.html#acc5d84beeb6b521dad7407d8aa11777f":[5,0,1,22,10],
+"class_ogre_1_1_ribbon_trail.html#acc8002296a48321ac318f99a77c82ef4":[5,0,1,22,0],
+"class_ogre_1_1_ribbon_trail.html#ad554af1a54fb650197947467b2d88839":[5,0,1,22,14],
+"class_ogre_1_1_ribbon_trail.html#ae7deac4e95e9ae76650d9576f363fa4a":[5,0,1,22,8],
+"class_ogre_1_1_ribbon_trail.html#afcb2546e8ec7769f7111f03a6a2cc6d4":[5,0,1,22,9],
+"class_ogre_1_1_ring_emitter.html":[5,2,10,14],
+"class_ogre_1_1_ring_emitter.html#a0a869977ab0c0ce93ffa8f7b6b62a730":[5,2,10,14,8],
+"class_ogre_1_1_ring_emitter.html#a0c27fc47afc5857aecf9558ee88bbc0b":[5,2,10,14,6],
+"class_ogre_1_1_ring_emitter.html#a3219c4a6ba77ef006ca2c89e143b568a":[5,2,10,14,2],
+"class_ogre_1_1_ring_emitter.html#a6bec37d0215d00d7c21cf9cd3ecb7e74":[5,2,10,14,4],
+"class_ogre_1_1_ring_emitter.html#ab72f845f276736ad49f37644e12d9c5b":[5,2,10,14,5],
+"class_ogre_1_1_ring_emitter.html#ac55dd6a31d71aff429dd71df299ec95b":[5,2,10,14,3],
+"class_ogre_1_1_ring_emitter.html#ae7e311c98390c9987d5ce4f773b9b692":[5,2,10,14,7],
+"class_ogre_1_1_ring_emitter_1_1_cmd_inner_x.html":[5,2,10,14,0],
+"class_ogre_1_1_ring_emitter_1_1_cmd_inner_x.html#a65d7c19d618c5d1ce9b1135a72e98f28":[5,2,10,14,0,1],
+"class_ogre_1_1_ring_emitter_1_1_cmd_inner_x.html#af116870994510f32c27988a4509d948b":[5,2,10,14,0,0],
+"class_ogre_1_1_ring_emitter_1_1_cmd_inner_y.html":[5,2,10,14,1],
+"class_ogre_1_1_ring_emitter_1_1_cmd_inner_y.html#ab7b8ca734ea152e8a7e83665a4fe7e79":[5,2,10,14,1,1],
+"class_ogre_1_1_ring_emitter_1_1_cmd_inner_y.html#abfc4f4baa0f7dadda0ccca0ded9c0b81":[5,2,10,14,1,0],
+"class_ogre_1_1_root.html":[5,0,2,39],
+"class_ogre_1_1_root.html#a00dcf2dbc091ec793f521fd0e467bf27":[5,0,2,39,30],
+"class_ogre_1_1_root.html#a01d3244dcf290c2db36aea6b0c63616a":[5,0,2,39,58],
+"class_ogre_1_1_root.html#a06b786d8e0847dfe9cc15e1dea308fcd":[5,0,2,39,87],
+"class_ogre_1_1_root.html#a0a10213bc5e0af9946cc295e84331d37":[5,0,2,39,82],
+"class_ogre_1_1_root.html#a0c36540d9764ec4e41940423dd0ae88b":[5,0,2,39,16],
+"class_ogre_1_1_root.html#a12dc2722de43cb2aa8e93845ea641358":[5,0,2,39,15],
+"class_ogre_1_1_root.html#a15166e7cc1e879b71948665737e79ce6":[5,0,2,39,60],
+"class_ogre_1_1_root.html#a18d21240d53ca480b6c122d80185ac3b":[5,0,2,39,78],
+"class_ogre_1_1_root.html#a194d3177b24dae7d73255268773a54b3":[5,0,2,39,56],
+"class_ogre_1_1_root.html#a19a9920a0eb5466338524aa5a997bc6e":[5,0,2,39,49],
+"class_ogre_1_1_root.html#a1f045bf046a75d65e6ddc71f4ebe0b2c":[5,0,2,39,70],
+"class_ogre_1_1_root.html#a20657c9c8ac25dce6d66b11ed7a8fca4":[5,0,2,39,45],
+"class_ogre_1_1_root.html#a20b606897509da75ad2795a8c894f2c0":[5,0,2,39,11],
+"class_ogre_1_1_root.html#a23417d6cbe7aeeafcc6a1a146a5e7b95":[5,0,2,39,53],
+"class_ogre_1_1_root.html#a23fd83ef996349d5151cd93ca4908d36":[5,0,2,39,57],
+"class_ogre_1_1_root.html#a24559fa6a4f1772c7518fcb0911278f4":[5,0,2,39,65],
+"class_ogre_1_1_root.html#a261189545f730e6243418d93cebfb75b":[5,0,2,39,72],
+"class_ogre_1_1_root.html#a26e03cab07db4acf8debe0faa9aab876":[5,0,2,39,67],
+"class_ogre_1_1_root.html#a293d1580c95101d72f2155e3fe2237bf":[5,0,2,39,4],
+"class_ogre_1_1_root.html#a2afff4a877a26bff8b47d32f9dcc15a8":[5,0,2,39,69],
+"class_ogre_1_1_root.html#a2e24d306cf90066702f616ba3a0d5b15":[5,0,2,39,63],
+"class_ogre_1_1_root.html#a33f7c5af7a51aff1d28a8d7f16253d57":[5,0,2,39,1],
+"class_ogre_1_1_root.html#a38131d8140e54a4a6e772d547c96d780":[5,0,2,39,77],
+"class_ogre_1_1_root.html#a3829209d84d95bb51960f7c56a86fc70":[5,0,2,39,54],
+"class_ogre_1_1_root.html#a3840c316ccddef1ccadf51325ad72ee2":[5,0,2,39,76],
+"class_ogre_1_1_root.html#a3be7a9636d4d5357df4968dff6ea138a":[5,0,2,39,44],
+"class_ogre_1_1_root.html#a518176c6e941302f9b31192a594e04bb":[5,0,2,39,22],
+"class_ogre_1_1_root.html#a51ca396e6c35072572e2aa8cdf5043b5":[5,0,2,39,29],
+"class_ogre_1_1_root.html#a541c72ca9f592e7a754e751e2b55e934":[5,0,2,39,19],
+"class_ogre_1_1_root.html#a5520d8d9e91c82d3d7ed273f02461edd":[5,0,2,39,34],
+"class_ogre_1_1_root.html#a57ec49d0fd19402ea8a4336f53ab62b4":[5,0,2,39,61],
+"class_ogre_1_1_root.html#a5cb5bad3812289df48db18a93445d6bf":[5,0,2,39,10],
+"class_ogre_1_1_root.html#a5dcfb7ee8fb1473fdc973752bc9452b4":[5,0,2,39,73],
+"class_ogre_1_1_root.html#a5ea47cd9c094644e1abac7607e1922fd":[5,0,2,39,52],
+"class_ogre_1_1_root.html#a6461e7f5423d060704cc9548a1b52b7a":[5,0,2,39,39],
+"class_ogre_1_1_root.html#a724ee7dcbdb7b8052420df2fecd07c0d":[5,0,2,39,3],
+"class_ogre_1_1_root.html#a734be2fb6e01355f328fa5ccd2e737f6":[5,0,2,39,17],
+"class_ogre_1_1_root.html#a759fd6c0d609b590d0b27da17ba382a4":[5,0,2,39,24],
+"class_ogre_1_1_root.html#a7820badfeef2fb9994ea9de17facb218":[5,0,2,39,37],
+"class_ogre_1_1_root.html#a7ee696cf420c9fa73429b9aed250f6b4":[5,0,2,39,25],
+"class_ogre_1_1_root.html#a7ff564512e4873f5ea27c36adb3face1":[5,0,2,39,40],
+"class_ogre_1_1_root.html#a816c44429449ce436837f53cd4cb8e93":[5,0,2,39,7],
+"class_ogre_1_1_root.html#a8cdb9d22e78d95e7e6dae230608d43c4":[5,0,2,39,43],
+"class_ogre_1_1_root.html#a8ddde4d4b5c30072619f5afd91222492":[5,0,2,39,13],
+"class_ogre_1_1_root.html#a8eda253befda1255cbfd3b298f62449e":[5,0,2,39,35],
+"class_ogre_1_1_root.html#a90c3f8c5e515282b8aa0fe0352ddc934":[5,0,2,39,74],
+"class_ogre_1_1_root.html#a9bd411bb1456e55ca634a67ef003e691":[5,0,2,39,2],
+"class_ogre_1_1_root.html#a9c063121d67ba39f658295b3ccefb37a":[5,0,2,39,47],
+"class_ogre_1_1_root.html#a9c610fa759978755ffd9da222fe68b3e":[5,0,2,39,81],
+"class_ogre_1_1_root.html#a9e2492db70157da036a814c84e516500":[5,0,2,39,51],
+"class_ogre_1_1_root.html#aa0cf5300f2f1893c1eb8749ae7d074f0":[5,0,2,39,62],
+"class_ogre_1_1_root.html#aa44a0398484e6efc3d13c590f02b0783":[5,0,2,39,85],
+"class_ogre_1_1_root.html#aa63b41f580aca52c3f35279dd06234fc":[5,0,2,39,0],
+"class_ogre_1_1_root.html#ab1859f8f00a1460f962d641b854a3bd0":[5,0,2,39,26],
+"class_ogre_1_1_root.html#ab5b391ac4b40774d1d77a339140bc954":[5,0,2,39,84],
+"class_ogre_1_1_root.html#ab6d87c0af70d247b8809cf61e9482840":[5,0,2,39,86],
+"class_ogre_1_1_root.html#ab7360b80fdc4eeb6bc63ff594c04bd04":[5,0,2,39,83],
+"class_ogre_1_1_root.html#aba26bc9123d8725d971e458e48c2694f":[5,0,2,39,66],
+"class_ogre_1_1_root.html#aba900bb388dd68af993df311076a9205":[5,0,2,39,32],
+"class_ogre_1_1_root.html#abb459bff4221b304013e36508e60128d":[5,0,2,39,21],
+"class_ogre_1_1_root.html#abe00e99a9ee49d6f095f943c42ae512e":[5,0,2,39,71],
+"class_ogre_1_1_root.html#ac446fdd2ca501766a3e28f067ec13dc5":[5,0,2,39,64],
+"class_ogre_1_1_root.html#ac629671c7fd688ddf036c92ca84137cb":[5,0,2,39,28],
+"class_ogre_1_1_root.html#ac62dc40092cfe152bb85fa1245222d82":[5,0,2,39,14]
 };
