@@ -1,105 +1,5 @@
 var NAVTREEINDEX41 =
 {
-"class_ogre_1_1_small_vector_impl.html#af1a27d7b06c0ff4671a6f4617fbaa7ba":[6,0,1,475,9],
-"class_ogre_1_1_small_vector_impl.html#af1a27d7b06c0ff4671a6f4617fbaa7ba":[7,0,0,475,9],
-"class_ogre_1_1_small_vector_impl.html#af8af78d33f9c946183a925698f36c6ad":[6,0,1,475,2],
-"class_ogre_1_1_small_vector_impl.html#af8af78d33f9c946183a925698f36c6ad":[7,0,0,475,2],
-"class_ogre_1_1_small_vector_template_base.html":[6,0,1,476],
-"class_ogre_1_1_small_vector_template_base.html":[7,0,0,476],
-"class_ogre_1_1_small_vector_template_base.html#a08f0d82975d336032f922f602ac0f35f":[6,0,1,476,1],
-"class_ogre_1_1_small_vector_template_base.html#a08f0d82975d336032f922f602ac0f35f":[7,0,0,476,1],
-"class_ogre_1_1_small_vector_template_base.html#a0c2eb072dfec3dd4b21519915f6eea62":[6,0,1,476,2],
-"class_ogre_1_1_small_vector_template_base.html#a0c2eb072dfec3dd4b21519915f6eea62":[7,0,0,476,2],
-"class_ogre_1_1_small_vector_template_base.html#a1102e592ef56b3858af2d0322b64bb0b":[6,0,1,476,0],
-"class_ogre_1_1_small_vector_template_base.html#a1102e592ef56b3858af2d0322b64bb0b":[7,0,0,476,0],
-"class_ogre_1_1_small_vector_template_base.html#a4e98041c1a76abf808becf450f43e5c7":[6,0,1,476,3],
-"class_ogre_1_1_small_vector_template_base.html#a4e98041c1a76abf808becf450f43e5c7":[7,0,0,476,3],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html":[6,0,1,477],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html":[7,0,0,477],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#a15dd2d9102920d0bcb714d3afd6b463e":[6,0,1,477,2],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#a15dd2d9102920d0bcb714d3afd6b463e":[7,0,0,477,2],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#a4d15744dc601db69005758b6e4b5657f":[6,0,1,477,4],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#a4d15744dc601db69005758b6e4b5657f":[7,0,0,477,4],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#a56118d327a717e0e0aa8fb98a1eae62e":[6,0,1,477,0],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#a56118d327a717e0e0aa8fb98a1eae62e":[7,0,0,477,0],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#a75b4f9ab566096949d688f6cb63b6036":[6,0,1,477,3],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#a75b4f9ab566096949d688f6cb63b6036":[7,0,0,477,3],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#afe468a8a8329abbea1476e5acb20956d":[6,0,1,477,1],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#afe468a8a8329abbea1476e5acb20956d":[7,0,0,477,1],
-"class_ogre_1_1_small_vector_template_common.html":[6,0,1,478],
-"class_ogre_1_1_small_vector_template_common.html":[7,0,0,478],
-"class_ogre_1_1_small_vector_template_common.html#a011ba964cc3d1777f2a59214f82e529d":[6,0,1,478,10],
-"class_ogre_1_1_small_vector_template_common.html#a011ba964cc3d1777f2a59214f82e529d":[7,0,0,478,10],
-"class_ogre_1_1_small_vector_template_common.html#a031182e52c76c98b41e3e6e7bc084a7e":[6,0,1,478,24],
-"class_ogre_1_1_small_vector_template_common.html#a031182e52c76c98b41e3e6e7bc084a7e":[7,0,0,478,24],
-"class_ogre_1_1_small_vector_template_common.html#a2914029c53db3683e055e071cafa00c4":[6,0,1,478,11],
-"class_ogre_1_1_small_vector_template_common.html#a2914029c53db3683e055e071cafa00c4":[7,0,0,478,11],
-"class_ogre_1_1_small_vector_template_common.html#a29f4c0677b9a04a1f137adc07be5be3a":[6,0,1,478,23],
-"class_ogre_1_1_small_vector_template_common.html#a29f4c0677b9a04a1f137adc07be5be3a":[7,0,0,478,23],
-"class_ogre_1_1_small_vector_template_common.html#a3e4105820c0f20b850e06ce43eadb92f":[6,0,1,478,18],
-"class_ogre_1_1_small_vector_template_common.html#a3e4105820c0f20b850e06ce43eadb92f":[7,0,0,478,18],
-"class_ogre_1_1_small_vector_template_common.html#a3f9319371de3a93895d6bce769faad4c":[6,0,1,478,1],
-"class_ogre_1_1_small_vector_template_common.html#a3f9319371de3a93895d6bce769faad4c":[7,0,0,478,1],
-"class_ogre_1_1_small_vector_template_common.html#a44c80d4f7bcd71b7cc02038fd13356de":[6,0,1,478,17],
-"class_ogre_1_1_small_vector_template_common.html#a44c80d4f7bcd71b7cc02038fd13356de":[7,0,0,478,17],
-"class_ogre_1_1_small_vector_template_common.html#a6f3019eb35333a8ca4e10f14923298d4":[6,0,1,478,12],
-"class_ogre_1_1_small_vector_template_common.html#a6f3019eb35333a8ca4e10f14923298d4":[7,0,0,478,12],
-"class_ogre_1_1_small_vector_template_common.html#a726e02e5ed3fb393ddab4970b92e3906":[6,0,1,478,19],
-"class_ogre_1_1_small_vector_template_common.html#a726e02e5ed3fb393ddab4970b92e3906":[7,0,0,478,19],
-"class_ogre_1_1_small_vector_template_common.html#a7f6c13429c1adbcbcddbf33a5a8b3fe8":[6,0,1,478,28],
-"class_ogre_1_1_small_vector_template_common.html#a7f6c13429c1adbcbcddbf33a5a8b3fe8":[7,0,0,478,28],
-"class_ogre_1_1_small_vector_template_common.html#a842c16cca109fb09e637788e4f4be959":[6,0,1,478,3],
-"class_ogre_1_1_small_vector_template_common.html#a842c16cca109fb09e637788e4f4be959":[7,0,0,478,3],
-"class_ogre_1_1_small_vector_template_common.html#a87ee5ad0c88dbd163e58835d7990ef32":[6,0,1,478,15],
-"class_ogre_1_1_small_vector_template_common.html#a87ee5ad0c88dbd163e58835d7990ef32":[7,0,0,478,15],
-"class_ogre_1_1_small_vector_template_common.html#a8fd84d4c57b70b9b8111efa7d81c7d5b":[6,0,1,478,30],
-"class_ogre_1_1_small_vector_template_common.html#a8fd84d4c57b70b9b8111efa7d81c7d5b":[7,0,0,478,30],
-"class_ogre_1_1_small_vector_template_common.html#a922c12bc5de4cf0fee5c101919fecc94":[6,0,1,478,22],
-"class_ogre_1_1_small_vector_template_common.html#a922c12bc5de4cf0fee5c101919fecc94":[7,0,0,478,22],
-"class_ogre_1_1_small_vector_template_common.html#a9815c7884278cf8ae793f559d5da6d5f":[6,0,1,478,21],
-"class_ogre_1_1_small_vector_template_common.html#a9815c7884278cf8ae793f559d5da6d5f":[7,0,0,478,21],
-"class_ogre_1_1_small_vector_template_common.html#a99ff0ad333ed56a85fa907ef33ed7bc5":[6,0,1,478,4],
-"class_ogre_1_1_small_vector_template_common.html#a99ff0ad333ed56a85fa907ef33ed7bc5":[7,0,0,478,4],
-"class_ogre_1_1_small_vector_template_common.html#a9e765b3edf8b9303d380e6abb5fdaa7b":[6,0,1,478,13],
-"class_ogre_1_1_small_vector_template_common.html#a9e765b3edf8b9303d380e6abb5fdaa7b":[7,0,0,478,13],
-"class_ogre_1_1_small_vector_template_common.html#aa5c7ed10e04b28acc1fecd075879a3e3":[6,0,1,478,26],
-"class_ogre_1_1_small_vector_template_common.html#aa5c7ed10e04b28acc1fecd075879a3e3":[7,0,0,478,26],
-"class_ogre_1_1_small_vector_template_common.html#aabbc326f17698c1b404fcfed47099f19":[6,0,1,478,27],
-"class_ogre_1_1_small_vector_template_common.html#aabbc326f17698c1b404fcfed47099f19":[7,0,0,478,27],
-"class_ogre_1_1_small_vector_template_common.html#ab0dcd557ed3091ee1aa4408dfcc3c390":[6,0,1,478,6],
-"class_ogre_1_1_small_vector_template_common.html#ab0dcd557ed3091ee1aa4408dfcc3c390":[7,0,0,478,6],
-"class_ogre_1_1_small_vector_template_common.html#ab3bb5e3be2e6a4f8b68b61c1c16028e4":[6,0,1,478,25],
-"class_ogre_1_1_small_vector_template_common.html#ab3bb5e3be2e6a4f8b68b61c1c16028e4":[7,0,0,478,25],
-"class_ogre_1_1_small_vector_template_common.html#ad720fcb2b113ff3dd8e6d7a740a3caf2":[6,0,1,478,9],
-"class_ogre_1_1_small_vector_template_common.html#ad720fcb2b113ff3dd8e6d7a740a3caf2":[7,0,0,478,9],
-"class_ogre_1_1_small_vector_template_common.html#ad7f6f59724a6eeb0069fcbf3e9895d4e":[6,0,1,478,8],
-"class_ogre_1_1_small_vector_template_common.html#ad7f6f59724a6eeb0069fcbf3e9895d4e":[7,0,0,478,8],
-"class_ogre_1_1_small_vector_template_common.html#add1c1041f5e7ca89feccdf57e746558b":[6,0,1,478,14],
-"class_ogre_1_1_small_vector_template_common.html#add1c1041f5e7ca89feccdf57e746558b":[7,0,0,478,14],
-"class_ogre_1_1_small_vector_template_common.html#ade0b345b86115c971c4f459a62e4d8da":[6,0,1,478,2],
-"class_ogre_1_1_small_vector_template_common.html#ade0b345b86115c971c4f459a62e4d8da":[7,0,0,478,2],
-"class_ogre_1_1_small_vector_template_common.html#ade708dba3d6aa380726d9e10dfd6aac7":[6,0,1,478,29],
-"class_ogre_1_1_small_vector_template_common.html#ade708dba3d6aa380726d9e10dfd6aac7":[7,0,0,478,29],
-"class_ogre_1_1_small_vector_template_common.html#adf2eb6c75c5a21936b9d658de1a3e132":[6,0,1,478,16],
-"class_ogre_1_1_small_vector_template_common.html#adf2eb6c75c5a21936b9d658de1a3e132":[7,0,0,478,16],
-"class_ogre_1_1_small_vector_template_common.html#ae40a8630bf739e9fadd1162ea95bb412":[6,0,1,478,20],
-"class_ogre_1_1_small_vector_template_common.html#ae40a8630bf739e9fadd1162ea95bb412":[7,0,0,478,20],
-"class_ogre_1_1_small_vector_template_common.html#aea99144b94832adc8ef4709b70bf5d4d":[6,0,1,478,7],
-"class_ogre_1_1_small_vector_template_common.html#aea99144b94832adc8ef4709b70bf5d4d":[7,0,0,478,7],
-"class_ogre_1_1_small_vector_template_common.html#af87563ac928d682a200f37552928ebb0":[6,0,1,478,5],
-"class_ogre_1_1_small_vector_template_common.html#af87563ac928d682a200f37552928ebb0":[7,0,0,478,5],
-"class_ogre_1_1_small_vector_template_common.html#afa2a01aa38449534e1ccc9d6992e7182":[6,0,1,478,0],
-"class_ogre_1_1_small_vector_template_common.html#afa2a01aa38449534e1ccc9d6992e7182":[7,0,0,478,0],
-"class_ogre_1_1_sphere.html":[5,0,6,21],
-"class_ogre_1_1_sphere.html#a01e832a0542bde80df107ab6b26b56f9":[5,0,6,21,6],
-"class_ogre_1_1_sphere.html#a4a30ba4b71475bf2da82c91dcc13e97a":[5,0,6,21,9],
-"class_ogre_1_1_sphere.html#a6306310d834dc7844c73dd24ec7a318d":[5,0,6,21,2],
-"class_ogre_1_1_sphere.html#a774730a3d40a4375144128b13afc39ef":[5,0,6,21,8],
-"class_ogre_1_1_sphere.html#a77798ca00493f6b1f9da7f3eff782642":[5,0,6,21,7],
-"class_ogre_1_1_sphere.html#a93cb05f8025668db930ef81a34dca47b":[5,0,6,21,0],
-"class_ogre_1_1_sphere.html#a9e9104e8e57c2fa2d30920989c725d1a":[5,0,6,21,10],
-"class_ogre_1_1_sphere.html#aafe80cad31edd668b09981a6f836c8b1":[5,0,6,21,3],
-"class_ogre_1_1_sphere.html#abd0dc8dd45b400a07d71115652d2dc20":[5,0,6,21,1],
 "class_ogre_1_1_sphere.html#af2cd29ca81e68cdeb65b91a2667d6fbc":[5,0,6,21,5],
 "class_ogre_1_1_sphere.html#afc27f8572366e37a150a45963c4dc247":[5,0,6,21,4],
 "class_ogre_1_1_sphere_scene_query.html":[5,0,9,52],
@@ -127,37 +27,37 @@ var NAVTREEINDEX41 =
 "class_ogre_1_1_static_geometry.html#a01a3f53c1970d60f1908cac9d1cc3b1d":[5,0,9,54,34],
 "class_ogre_1_1_static_geometry.html#a03c94e8a32918dba0fa4321e49f7135f":[5,0,9,54,20],
 "class_ogre_1_1_static_geometry.html#a0487dd0323485acdda054ed41f4cc216":[5,0,9,54,15],
+"class_ogre_1_1_static_geometry.html#a0d1eafab98ba3f36b7ac8d39868bd158":[5,0,9,54,12],
+"class_ogre_1_1_static_geometry.html#a170301c4c8d1c95dcb322ed825007595":[5,0,9,54,11],
 "class_ogre_1_1_static_geometry.html#a1d58673b93c467f9e5e23af619d8806f":[5,0,9,54,37],
 "class_ogre_1_1_static_geometry.html#a24354033bca320e9777027dcfa8144e3":[5,0,9,54,33],
 "class_ogre_1_1_static_geometry.html#a275913c7bb86faf4acc86b6bd8e2a9ce":[5,0,9,54,23],
+"class_ogre_1_1_static_geometry.html#a2cf30b583c41eb0174b4cbeb5db4e75a":[5,0,9,54,8],
 "class_ogre_1_1_static_geometry.html#a2efcde5992970bde422ac7465107ee62":[5,0,9,54,29],
 "class_ogre_1_1_static_geometry.html#a2f1ab5e17bfa8bf9e4c389cfa8a5b1a3":[5,0,9,54,31],
 "class_ogre_1_1_static_geometry.html#a483ba1dbb7fcbe2be40c6168aaea5c2e":[5,0,9,54,40],
 "class_ogre_1_1_static_geometry.html#a54eeadead94735721ca7075b442dc6e9":[5,0,9,54,41],
-"class_ogre_1_1_static_geometry.html#a5fe6a376290b5e692b8ccb449d85713e":[5,0,9,54,10],
 "class_ogre_1_1_static_geometry.html#a6732442e32787ccd6c680e0ae9cc01fd":[5,0,9,54,35],
 "class_ogre_1_1_static_geometry.html#a684286488be58aba6f789314f08d52ee":[5,0,9,54,17],
 "class_ogre_1_1_static_geometry.html#a6d02bee2716715251c27dd9b4537c3d0":[5,0,9,54,16],
-"class_ogre_1_1_static_geometry.html#a7123ed08f80d3ff117938d27aa654bc9":[5,0,9,54,11],
 "class_ogre_1_1_static_geometry.html#a71907b64bca572d90168f28cb65f23cc":[5,0,9,54,28],
 "class_ogre_1_1_static_geometry.html#a798a7f52fee67ed148d5fca2f1eff3cc":[5,0,9,54,39],
-"class_ogre_1_1_static_geometry.html#a7da8e802dbecf66e37957d5b1becb315":[5,0,9,54,14],
 "class_ogre_1_1_static_geometry.html#a7e192ed9d7b41ae948b7ca0ed4cb5e0f":[5,0,9,54,32],
-"class_ogre_1_1_static_geometry.html#a7e26357f11e4efcecba8748981b7e112":[5,0,9,54,9],
+"class_ogre_1_1_static_geometry.html#a80c5f8105181b3e77468a87e5351825b":[5,0,9,54,10],
 "class_ogre_1_1_static_geometry.html#a83566155af8cfe9ebc83970b14978a37":[5,0,9,54,38],
 "class_ogre_1_1_static_geometry.html#a83743461ea0b73ddb35030804c2f3a6b":[5,0,9,54,22],
 "class_ogre_1_1_static_geometry.html#a8ce1fb9687b9023947683b881d72096b":[5,0,9,54,36],
 "class_ogre_1_1_static_geometry.html#a91b72934294a81bd107747a076fd8a69":[5,0,9,54,30],
 "class_ogre_1_1_static_geometry.html#a98c44ba2920c9e07d29548d5ee927b5e":[5,0,9,54,18],
+"class_ogre_1_1_static_geometry.html#a9a3a337c0d120c4c3bf65850c25b103a":[5,0,9,54,9],
 "class_ogre_1_1_static_geometry.html#aa077e3cb67caa3109a5664795644156a":[5,0,9,54,19],
 "class_ogre_1_1_static_geometry.html#ab0d5c294946e519c0dad95dc9802609a":[5,0,9,54,26],
 "class_ogre_1_1_static_geometry.html#abb2e76eabaaeff2abb47d8cfaa859435":[5,0,9,54,25],
-"class_ogre_1_1_static_geometry.html#acf84792f4755fe14ec7de7dad634c202":[5,0,9,54,8],
+"class_ogre_1_1_static_geometry.html#ac58b2faf8a71daf21406ed730215a13a":[5,0,9,54,14],
 "class_ogre_1_1_static_geometry.html#ad8b2c9adc4de73ab070a042f843c2efe":[5,0,9,54,21],
-"class_ogre_1_1_static_geometry.html#ae111c5afb3cdff90000a00dc9509ed35":[5,0,9,54,13],
 "class_ogre_1_1_static_geometry.html#ae31c57dc0ab9fdf05d3b068c4826ced0":[5,0,9,54,27],
 "class_ogre_1_1_static_geometry.html#ae86af04a730e6509245cf496ab0ee9a5":[5,0,9,54,24],
-"class_ogre_1_1_static_geometry.html#ae987ca3599a844051269afabc4c4c4ab":[5,0,9,54,12],
+"class_ogre_1_1_static_geometry.html#af697e3c0524a2e1976e691b38de9b8e1":[5,0,9,54,13],
 "class_ogre_1_1_static_geometry_1_1_geometry_bucket.html":[5,0,9,54,0],
 "class_ogre_1_1_static_geometry_1_1_geometry_bucket.html#a043a89755d05ca8ee6e4334376adae2c":[5,0,9,54,0,13],
 "class_ogre_1_1_static_geometry_1_1_geometry_bucket.html#a0c59c39704c44d0af35b311271c86ca7":[5,0,9,54,0,4],
@@ -181,26 +81,26 @@ var NAVTREEINDEX41 =
 "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a2a895595891f3a7332382d86939bd962":[5,0,9,54,1,14],
 "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a42a8380d57d91d8aea32e552d88cfa6a":[5,0,9,54,1,17],
 "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a491d98e5031fc4db2bcb77e9c6aa3460":[5,0,9,54,1,7],
+"class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a6240319f801ee4f58cacb9ceccd9496b":[5,0,9,54,1,1],
 "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a6244525eff9b19029642e262a1cee216":[5,0,9,54,1,9],
 "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a7372f3cfd5aa8cfaf2589ad16a776ef9":[5,0,9,54,1,5],
 "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a7b7d8789e819a72862a56918c17f94e1":[5,0,9,54,1,13],
-"class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a7e285ae7eefce3be51a64bdfcc62d697":[5,0,9,54,1,0],
 "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a9928b782916e2739a62accca185e6a48":[5,0,9,54,1,15],
 "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#aac2688d990e29f0ec6455cdf9af54ee0":[5,0,9,54,1,4],
 "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#ab686c556b75f53c03cd554bd90b632c2":[5,0,9,54,1,8],
 "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#ab772c6af3bb6cf79a5f6bb3bb3d84aaa":[5,0,9,54,1,11],
 "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#ab907eb21b0f40634427fee3e9e82adb5":[5,0,9,54,1,16],
 "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#abb4929bf76d5e7a3b70297cf74965aaf":[5,0,9,54,1,12],
+"class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#ac66c126a9e8cace5c45cf200d17221fe":[5,0,9,54,1,0],
 "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#acc3d9344b62bfedbc087c635e7678c95":[5,0,9,54,1,6],
-"class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#adbab94d8dbba62da8e63739fd5cc76a1":[5,0,9,54,1,1],
 "class_ogre_1_1_static_geometry_1_1_material_bucket.html":[5,0,9,54,2],
-"class_ogre_1_1_static_geometry_1_1_material_bucket.html#a13c849b3656f5cb6265445a7f1157ec9":[5,0,9,54,2,1],
 "class_ogre_1_1_static_geometry_1_1_material_bucket.html#a2d170c856439eb6c12938f7df305e479":[5,0,9,54,2,13],
-"class_ogre_1_1_static_geometry_1_1_material_bucket.html#a40ea58b7bb4cdae2e9dc5f8014c8d134":[5,0,9,54,2,0],
 "class_ogre_1_1_static_geometry_1_1_material_bucket.html#a45c99a1a8fd0b28bd0a72072355cf746":[5,0,9,54,2,2],
+"class_ogre_1_1_static_geometry_1_1_material_bucket.html#a59961706795c7ad082210c65748d0c83":[5,0,9,54,2,0],
 "class_ogre_1_1_static_geometry_1_1_material_bucket.html#a6c57eeba1ec38b4c20c9cca3430ac477":[5,0,9,54,2,5],
 "class_ogre_1_1_static_geometry_1_1_material_bucket.html#a73c3eb66a47f97224dcbeb48dc9bb6c5":[5,0,9,54,2,6],
 "class_ogre_1_1_static_geometry_1_1_material_bucket.html#aa3a817dab145e00ab3c07f1f62556f33":[5,0,9,54,2,7],
+"class_ogre_1_1_static_geometry_1_1_material_bucket.html#ab2f7c7785a86b2bf05998b96b73c5952":[5,0,9,54,2,1],
 "class_ogre_1_1_static_geometry_1_1_material_bucket.html#ab53df12637d620402fc10b1b755dbda8":[5,0,9,54,2,10],
 "class_ogre_1_1_static_geometry_1_1_material_bucket.html#ab56b7fd171bec6f46398bdf4baf7c338":[5,0,9,54,2,11],
 "class_ogre_1_1_static_geometry_1_1_material_bucket.html#abc4a538317300484ec970d2ff6482a7a":[5,0,9,54,2,14],
@@ -216,19 +116,19 @@ var NAVTREEINDEX41 =
 "class_ogre_1_1_static_geometry_1_1_optimised_sub_mesh_geometry.html#ad74c3d8bc57c3902ad3f1be62fc552fd":[5,0,9,54,3,0],
 "class_ogre_1_1_static_geometry_1_1_optimised_sub_mesh_geometry.html#afee0d52be974cc287c49c1988ca570aa":[5,0,9,54,3,3],
 "class_ogre_1_1_static_geometry_1_1_region.html":[5,0,9,54,6],
-"class_ogre_1_1_static_geometry_1_1_region.html#a1873bef85537e827ca2aa8cd69001f7e":[5,0,9,54,6,1],
 "class_ogre_1_1_static_geometry_1_1_region.html#a19c0bb2442a83b4f686c162653cd8ac0":[5,0,9,54,6,24],
 "class_ogre_1_1_static_geometry_1_1_region.html#a1ef54cc784f7a52df495e596d4d41de5":[5,0,9,54,6,23],
 "class_ogre_1_1_static_geometry_1_1_region.html#a24bc4f0c30f32bf1a1ee95f9ae349c3a":[5,0,9,54,6,11],
 "class_ogre_1_1_static_geometry_1_1_region.html#a4c5893c4de27195c17791a9b0902f5e1":[5,0,9,54,6,20],
+"class_ogre_1_1_static_geometry_1_1_region.html#a5249ca40ad17fae7ce97c26dd3bf3f00":[5,0,9,54,6,0],
 "class_ogre_1_1_static_geometry_1_1_region.html#a53abf43a3165c29b1f90261cb20e8e67":[5,0,9,54,6,25],
 "class_ogre_1_1_static_geometry_1_1_region.html#a543e5ff805c9d2e27d540f63dc79544f":[5,0,9,54,6,13],
 "class_ogre_1_1_static_geometry_1_1_region.html#a58f16eb868a355df9fe3f210f102c5b3":[5,0,9,54,6,22],
 "class_ogre_1_1_static_geometry_1_1_region.html#a5c5bcd0100aaeedc394506b60b5600b8":[5,0,9,54,6,17],
+"class_ogre_1_1_static_geometry_1_1_region.html#a75f120bb28afd724d9c6284d7c8f5a42":[5,0,9,54,6,1],
 "class_ogre_1_1_static_geometry_1_1_region.html#a847f2a29d7179f94f24f175d3ec13543":[5,0,9,54,6,10],
 "class_ogre_1_1_static_geometry_1_1_region.html#a855e777ea0d54fa5530ff5e7e8619581":[5,0,9,54,6,9],
 "class_ogre_1_1_static_geometry_1_1_region.html#a89cfb56a973320254f58595ac8615426":[5,0,9,54,6,19],
-"class_ogre_1_1_static_geometry_1_1_region.html#a9f092324bafe81d4716ea233c831503a":[5,0,9,54,6,0],
 "class_ogre_1_1_static_geometry_1_1_region.html#aa408a2de4cd4418590fa726ea3427190":[5,0,9,54,6,12],
 "class_ogre_1_1_static_geometry_1_1_region.html#aa51a200d2ca397e9b2a22aa2b6a6f46c":[5,0,9,54,6,16],
 "class_ogre_1_1_static_geometry_1_1_region.html#aab84defa5298d179b74a6dd6e92bad6c":[5,0,9,54,6,21],
@@ -249,5 +149,105 @@ var NAVTREEINDEX41 =
 "class_ogre_1_1_stream_serialiser.html#a072077ff56678e964608a7451db7c3f0afa17cf3b68b6464762f03423afc83d6e":[5,0,8,28,1,1],
 "class_ogre_1_1_stream_serialiser.html#a0d289d76cc669fd1ade3ef05fa48bd21":[5,0,8,28,32],
 "class_ogre_1_1_stream_serialiser.html#a0ffe90cc7b051f0f56faccc739988cea":[5,0,8,28,28],
-"class_ogre_1_1_stream_serialiser.html#a192b4339d7d5ba458824751e01575d92":[5,0,8,28,20]
+"class_ogre_1_1_stream_serialiser.html#a192b4339d7d5ba458824751e01575d92":[5,0,8,28,20],
+"class_ogre_1_1_stream_serialiser.html#a242f3491c47852b53b0b689edfc25e4c":[5,0,8,28,48],
+"class_ogre_1_1_stream_serialiser.html#a273eb21bd429c3a1dc4ac6981bea7c6b":[5,0,8,28,40],
+"class_ogre_1_1_stream_serialiser.html#a28eec6a458dd2f02a8849a51dc107dcf":[5,0,8,28,45],
+"class_ogre_1_1_stream_serialiser.html#a2aae82219abe1e37ea5f1c1adf8bdd1c":[5,0,8,28,21],
+"class_ogre_1_1_stream_serialiser.html#a2d9cd8abb22fbd17c795aa62765b4a59":[5,0,8,28,37],
+"class_ogre_1_1_stream_serialiser.html#a3173c30a36415d10b4daf6e130953e0e":[5,0,8,28,43],
+"class_ogre_1_1_stream_serialiser.html#a32788255718a172dd040cf6766e8e32a":[5,0,8,28,47],
+"class_ogre_1_1_stream_serialiser.html#a4397c12bc7f970bd559d0d24a0116b36":[5,0,8,28,36],
+"class_ogre_1_1_stream_serialiser.html#a456b335842b528abb03c953049cac7ad":[5,0,8,28,35],
+"class_ogre_1_1_stream_serialiser.html#a46bcb952e488697f41786e1156c00979":[5,0,8,28,39],
+"class_ogre_1_1_stream_serialiser.html#a49f031773228cdd832db5c52e7e0ea72":[5,0,8,28,18],
+"class_ogre_1_1_stream_serialiser.html#a517e99ed59380c90a1d29caf5d34df67":[5,0,8,28,8],
+"class_ogre_1_1_stream_serialiser.html#a53163836004961bea4bb7ab73819b322":[5,0,8,28,26],
+"class_ogre_1_1_stream_serialiser.html#a5435ad86ff5851f9012191d3b5179a55":[5,0,8,28,31],
+"class_ogre_1_1_stream_serialiser.html#a596a55c0496333afcfa6af3e51e36e64":[5,0,8,28,22],
+"class_ogre_1_1_stream_serialiser.html#a5e45523a0409077bbcab706ef0a58f64":[5,0,8,28,52],
+"class_ogre_1_1_stream_serialiser.html#a5f557c549a65a20e76e605f9bf9fe4c9":[5,0,8,28,41],
+"class_ogre_1_1_stream_serialiser.html#a60ac46edf43d39927816e34b1a0d983c":[5,0,8,28,23],
+"class_ogre_1_1_stream_serialiser.html#a6430b8559a0b559d3eefaebef786759e":[5,0,8,28,27],
+"class_ogre_1_1_stream_serialiser.html#a6469d16380285e935ad31ab9c1807f43":[5,0,8,28,4],
+"class_ogre_1_1_stream_serialiser.html#a6731deffcb48fa5b78422e4f955f5f93":[5,0,8,28,30],
+"class_ogre_1_1_stream_serialiser.html#a6cf4285399b89b088f2f297dda10fc91":[5,0,8,28,2],
+"class_ogre_1_1_stream_serialiser.html#a6cf4285399b89b088f2f297dda10fc91a2b594a33ac97bd7a0cc2d9047e2b1912":[5,0,8,28,2,1],
+"class_ogre_1_1_stream_serialiser.html#a6cf4285399b89b088f2f297dda10fc91ae3bcbc915c3187091bf95f1e7426a837":[5,0,8,28,2,0],
+"class_ogre_1_1_stream_serialiser.html#a6f33fe43504c631349b4a4c6244525b1":[5,0,8,28,3],
+"class_ogre_1_1_stream_serialiser.html#a72a8e8540b453b8428992c0c6c599995":[5,0,8,28,38],
+"class_ogre_1_1_stream_serialiser.html#a771fae398bd7b30a02ce9343d3de0792":[5,0,8,28,5],
+"class_ogre_1_1_stream_serialiser.html#a79d03ff4a8aedc9e28412dc25fa48027":[5,0,8,28,34],
+"class_ogre_1_1_stream_serialiser.html#a82759066f35c8cb08e24ce4357c747c7":[5,0,8,28,29],
+"class_ogre_1_1_stream_serialiser.html#a838c7aea842143bcf54d82d3fe085efe":[5,0,8,28,50],
+"class_ogre_1_1_stream_serialiser.html#a85a44458396fa2170fa8858a0328fa97":[5,0,8,28,49],
+"class_ogre_1_1_stream_serialiser.html#a880c33bffd02ac88cf7378a06ff4785b":[5,0,8,28,17],
+"class_ogre_1_1_stream_serialiser.html#a8da61d9cfea11fa94aef4b3ea1a81eae":[5,0,8,28,51],
+"class_ogre_1_1_stream_serialiser.html#a97b3a9ad5caea2da65b36a07816f968e":[5,0,8,28,14],
+"class_ogre_1_1_stream_serialiser.html#a994f2de1f0d13f674b6946b2490c225a":[5,0,8,28,25],
+"class_ogre_1_1_stream_serialiser.html#a9a3af44ad9ac9d841ec5e15d4c6856f3":[5,0,8,28,44],
+"class_ogre_1_1_stream_serialiser.html#aa0fa5f5b426eecb48246039f397befab":[5,0,8,28,16],
+"class_ogre_1_1_stream_serialiser.html#aa5e27e1fff17725bb9970d9ad81cfb39":[5,0,8,28,13],
+"class_ogre_1_1_stream_serialiser.html#aa63f3833de85040c420f1d9355b2bb52":[5,0,8,28,9],
+"class_ogre_1_1_stream_serialiser.html#aa930c1889b253433b459176426795627":[5,0,8,28,46],
+"class_ogre_1_1_stream_serialiser.html#aa9c4b6be63560e6f2ab0b647fe797175":[5,0,8,28,54],
+"class_ogre_1_1_stream_serialiser.html#aac94278ebfddb581f5e73838f573c9cd":[5,0,8,28,12],
+"class_ogre_1_1_stream_serialiser.html#ac16f0772431b3939250062d61957189d":[5,0,8,28,55],
+"class_ogre_1_1_stream_serialiser.html#ad1ba4ab9614504d8028c4d2754ca3315":[5,0,8,28,6],
+"class_ogre_1_1_stream_serialiser.html#ad453d94c2cc1ebd6a13d2571ee8d5456":[5,0,8,28,33],
+"class_ogre_1_1_stream_serialiser.html#ad7dbda6a8b282814f3eabcaed6f86abc":[5,0,8,28,19],
+"class_ogre_1_1_stream_serialiser.html#ad81be1455eacc97d5fcd1df06cbe1b93":[5,0,8,28,15],
+"class_ogre_1_1_stream_serialiser.html#ada08984a52a07febc6ddd531c60adbd6":[5,0,8,28,24],
+"class_ogre_1_1_stream_serialiser.html#ae287158dbf1c109012cb165bfc0cf1e8":[5,0,8,28,7],
+"class_ogre_1_1_stream_serialiser.html#ae955dfcf39b9a0d7407289e2073d45e0":[5,0,8,28,11],
+"class_ogre_1_1_stream_serialiser.html#aea616ff03daa17c34ac1e38682a501c2":[5,0,8,28,10],
+"class_ogre_1_1_stream_serialiser.html#aee0e00b95f550cc324cbb5fef1a3766b":[5,0,8,28,42],
+"class_ogre_1_1_stream_serialiser.html#af8fe1551fa5a1dc26317c9b57b8ef1f6":[5,0,8,28,53],
+"class_ogre_1_1_string_converter.html":[5,0,2,46],
+"class_ogre_1_1_string_converter.html#a041e06bfaeca7a8950bbd04176d1b826":[5,0,2,46,53],
+"class_ogre_1_1_string_converter.html#a0759107b842b8483abbce915a74dd5e1":[5,0,2,46,46],
+"class_ogre_1_1_string_converter.html#a0cdfb81eecf49efe65f33593f2251b39":[5,0,2,46,44],
+"class_ogre_1_1_string_converter.html#a0da7557e511082fe8e96dcb526c38d17":[5,0,2,46,12],
+"class_ogre_1_1_string_converter.html#a0e0ff0bb4ea783c8975755205a665bae":[5,0,2,46,30],
+"class_ogre_1_1_string_converter.html#a167f9319fa721f66e393d963de145c6c":[5,0,2,46,52],
+"class_ogre_1_1_string_converter.html#a1a53ab0f54bc753ae2748909696d0b32":[5,0,2,46,21],
+"class_ogre_1_1_string_converter.html#a1ca7f17dfe0a0d60cfd4aa4eae388a1a":[5,0,2,46,0],
+"class_ogre_1_1_string_converter.html#a2b13c57d6d50b02b4c49ee0f15047f86":[5,0,2,46,26],
+"class_ogre_1_1_string_converter.html#a3231bc671d186edf102ce3d66cb5c6b0":[5,0,2,46,1],
+"class_ogre_1_1_string_converter.html#a34ea0643ed34b39be5ae6e8991fc66f8":[5,0,2,46,28],
+"class_ogre_1_1_string_converter.html#a3fc58f308c0abf991206a2f30d6aa8b3":[5,0,2,46,31],
+"class_ogre_1_1_string_converter.html#a40baf295547f60d3d0efcf279268d8dc":[5,0,2,46,16],
+"class_ogre_1_1_string_converter.html#a41d15619e971971f2025052e1a6d7c5a":[5,0,2,46,17],
+"class_ogre_1_1_string_converter.html#a432bdb899c4f5c0408eee0587918279c":[5,0,2,46,27],
+"class_ogre_1_1_string_converter.html#a4591e8414fc653e18ac7c3b427c5f093":[5,0,2,46,49],
+"class_ogre_1_1_string_converter.html#a45fb498a2f798c82bbf88116a5a34c53":[5,0,2,46,5],
+"class_ogre_1_1_string_converter.html#a4d5e92a12b81e2c57d90762a305dc4d3":[5,0,2,46,42],
+"class_ogre_1_1_string_converter.html#a4de896cef79f4620355149a42c43dff6":[5,0,2,46,47],
+"class_ogre_1_1_string_converter.html#a4ed087545408d67c8ae78c61f17fe540":[5,0,2,46,25],
+"class_ogre_1_1_string_converter.html#a50dc18fbea93867cce178f015d866149":[5,0,2,46,36],
+"class_ogre_1_1_string_converter.html#a512f16395740a8e25107f91fe78a4f7f":[5,0,2,46,43],
+"class_ogre_1_1_string_converter.html#a54b489bc08f1542fe9dd0b9d57fbfbca":[5,0,2,46,15],
+"class_ogre_1_1_string_converter.html#a5660791892415b79c9a95342dad2840a":[5,0,2,46,2],
+"class_ogre_1_1_string_converter.html#a56ada01feac7a06801f82a9abfd0cd52":[5,0,2,46,35],
+"class_ogre_1_1_string_converter.html#a5d87f18dfdba37030bd8df0ba9317f43":[5,0,2,46,3],
+"class_ogre_1_1_string_converter.html#a6667bbf4ce4a97aab4f5224508e6847a":[5,0,2,46,55],
+"class_ogre_1_1_string_converter.html#a66b762033aad3b0464dd116f983c7685":[5,0,2,46,41],
+"class_ogre_1_1_string_converter.html#a78755a56a6f07c545bdc7a73c035a96d":[5,0,2,46,37],
+"class_ogre_1_1_string_converter.html#a7ba002d36e0af0d63ead860659c21625":[5,0,2,46,34],
+"class_ogre_1_1_string_converter.html#a7dd1a2f936cced85559abb1f948bdecb":[5,0,2,46,48],
+"class_ogre_1_1_string_converter.html#a8056b62654f3285bea74f61807b78c7d":[5,0,2,46,4],
+"class_ogre_1_1_string_converter.html#a8f1d0fab67ac94cb5466812aea13dae0":[5,0,2,46,45],
+"class_ogre_1_1_string_converter.html#a95d05930b54167f5353733ec36668f65":[5,0,2,46,54],
+"class_ogre_1_1_string_converter.html#a9633e8a5b340ca0c3b36aa51efb4cc5d":[5,0,2,46,38],
+"class_ogre_1_1_string_converter.html#a9ceacfd6e4f13f89c1ec03f5ef754b58":[5,0,2,46,50],
+"class_ogre_1_1_string_converter.html#aa05c075b14b73fbdc82f477d6da359f8":[5,0,2,46,20],
+"class_ogre_1_1_string_converter.html#aa0a2d5fb724610a66f1949511e1fb478":[5,0,2,46,19],
+"class_ogre_1_1_string_converter.html#aa0d9e22b2cfa07df243920cedfb68563":[5,0,2,46,40],
+"class_ogre_1_1_string_converter.html#aa331e97f9c49e38ac4951c6643f02fbf":[5,0,2,46,7],
+"class_ogre_1_1_string_converter.html#aa671980d27b86d09a0f568b451ba677d":[5,0,2,46,14],
+"class_ogre_1_1_string_converter.html#aac72f36d80009ebb30da7d270c08d591":[5,0,2,46,29],
+"class_ogre_1_1_string_converter.html#ab5b342933cd843bd5ce91b1b9f1d108a":[5,0,2,46,13],
+"class_ogre_1_1_string_converter.html#ab6f7c4fb9bf4be031282c8ccf5b38727":[5,0,2,46,22],
+"class_ogre_1_1_string_converter.html#abca988b16577c3feab1317c3646a180e":[5,0,2,46,6],
+"class_ogre_1_1_string_converter.html#abe797dbd9215f9f649c339a8f7044e50":[5,0,2,46,23]
 };
