@@ -1,120 +1,5 @@
 var NAVTREEINDEX60 =
 {
-"rtss.html#autotoc_md251":[1,4,0,6],
-"rtss.html#autotoc_md252":[1,4,0,7],
-"rtss.html#autotoc_md253":[1,4,0,8],
-"rtss.html#autotoc_md254":[1,4,0,9],
-"rtss.html#autotoc_md255":[1,4,0,11],
-"rtss.html#autotoc_md256":[1,4,1,1],
-"rtss.html#autotoc_md257":[1,4,1,2],
-"rtss.html#autotoc_md258":[1,4,3,1],
-"rtss.html#autotoc_md259":[1,4,4,1],
-"rtss.html#core-feats":[1,4,3,0],
-"rtss.html#creating-extensions":[1,4,4,5],
-"rtss.html#debugging":[1,4,4,6],
-"rtss.html#normal_map":[1,4,1,0],
-"rtss.html#rtssGenerate":[1,4,4,4],
-"rtss.html#rtssTech":[1,4,4,3],
-"rtss.html#rtss__components":[1,4,4,0],
-"rtss.html#rtss_custom_api":[1,4,4,2],
-"rtss.html#rtss_custom_mat":[1,4,0],
-"rtss.html#rtss_indepth":[1,4,4],
-"rtss.html#rtss_overview":[1,4,3],
-"rtss.html#rtss_tu_props":[1,4,1],
-"rtss.html#shadow_mapping":[1,4,0,10],
-"setup.html":[2,1],
-"setup.html#autotoc_md308":[2,1,2,0],
-"setup.html#autotoc_md309":[2,1,2,0,0],
-"setup.html#autotoc_md310":[2,1,2,0,1],
-"setup.html#autotoc_md311":[2,1,2,0,2],
-"setup.html#cmake":[2,1,0],
-"setup.html#setupRunning":[2,1,2],
-"setup.html#skeleton":[2,1,1],
-"struct_ogre_1_1_aligned_allocator.html":[5,0,2,0],
-"struct_ogre_1_1_aligned_allocator.html#a43862beb4c7cf42d4537d85f94bdf05c":[5,0,2,0,2],
-"struct_ogre_1_1_aligned_allocator.html#a6b5516246b4c0bf36bc88d78c1661c1a":[5,0,2,0,5],
-"struct_ogre_1_1_aligned_allocator.html#ada06dc753399c47df446191f70082841":[5,0,2,0,4],
-"struct_ogre_1_1_aligned_allocator.html#aeb6e5b03be1aaf4ca1ade5852a87e7e5":[5,0,2,0,3],
-"struct_ogre_1_1_aligned_allocator.html#aec0f4e93bb6df7da96d02e6a6aafadfd":[5,0,2,0,1],
-"struct_ogre_1_1_aligned_allocator_1_1rebind.html":[5,0,2,0,0],
-"struct_ogre_1_1_aligned_allocator_1_1rebind.html#ae2157f23d51da7c107f7a37e95dec785":[5,0,2,0,0,0],
-"struct_ogre_1_1_assimp_loader_1_1_options.html":[5,2,0,0,0],
-"struct_ogre_1_1_assimp_loader_1_1_options.html#a3654457ec5d49cbdc25879b2501a6fc0":[5,2,0,0,0,2],
-"struct_ogre_1_1_assimp_loader_1_1_options.html#a58414e94f4eb1adaecdbf1a6acd74d96":[5,2,0,0,0,3],
-"struct_ogre_1_1_assimp_loader_1_1_options.html#aca4f3631d2487ccf953f5a81c874add2":[5,2,0,0,0,5],
-"struct_ogre_1_1_assimp_loader_1_1_options.html#acc8cd921e5135f7f10d491fa62a599cb":[5,2,0,0,0,1],
-"struct_ogre_1_1_assimp_loader_1_1_options.html#aefa125d89ab9dd1848c040eede506639":[5,2,0,0,0,4],
-"struct_ogre_1_1_assimp_loader_1_1_options.html#af2b576ff086308c967bb17d5c17dc6ca":[5,2,0,0,0,0],
-"struct_ogre_1_1_box.html":[5,0,2,3],
-"struct_ogre_1_1_box.html#a14b2e385f1add85d4d896269ef3a3df9":[5,0,2,3,10],
-"struct_ogre_1_1_box.html#a19a7351210e086309a74461d8b4c5cb1":[5,0,2,3,16],
-"struct_ogre_1_1_box.html#a1d5ae3e6901d4a751a896ba7dbd380ea":[5,0,2,3,1],
-"struct_ogre_1_1_box.html#a299430570d30db49fa26940428891deb":[5,0,2,3,3],
-"struct_ogre_1_1_box.html#a31d35f1235b9652c39c1f30544fcf197":[5,0,2,3,9],
-"struct_ogre_1_1_box.html#a352d26dea0069f2e7f1414e8caa2328c":[5,0,2,3,7],
-"struct_ogre_1_1_box.html#a5499449ff454ff98aaa697f8854376fc":[5,0,2,3,6],
-"struct_ogre_1_1_box.html#a5a207f398c9bb5bd41537dbc11429226":[5,0,2,3,4],
-"struct_ogre_1_1_box.html#a5e545a9bd1bc4151a113267c6529d84f":[5,0,2,3,15],
-"struct_ogre_1_1_box.html#a7c317f774697dbd65dd77e49a0448d2d":[5,0,2,3,12],
-"struct_ogre_1_1_box.html#a7d1b60afde0486382a209908eae208f4":[5,0,2,3,2],
-"struct_ogre_1_1_box.html#a7d29d3b112980c25bd0250dc41cf6ed2":[5,0,2,3,5],
-"struct_ogre_1_1_box.html#a88fa61f841bc444d92075d8b6cb2b43b":[5,0,2,3,11],
-"struct_ogre_1_1_box.html#aaae3f6efb19b7607eef11e8e70fa46a2":[5,0,2,3,0],
-"struct_ogre_1_1_box.html#ac2c94e2d364dfabe7e4406ff8f41ab9e":[5,0,2,3,13],
-"struct_ogre_1_1_box.html#ae46fa4954b4d29f4d051f947fe45c142":[5,0,2,3,14],
-"struct_ogre_1_1_box.html#ae820fd38f7b51e2a907ef601642c898c":[5,0,2,3,8],
-"struct_ogre_1_1_bsp_node_1_1_brush.html":[5,2,1,2,0],
-"struct_ogre_1_1_bsp_node_1_1_brush.html#a1e6740b48713e3cc1fc3bdb62b9a6e64":[5,2,1,2,0,1],
-"struct_ogre_1_1_bsp_node_1_1_brush.html#a62726d014908dee79b47d4048184afaa":[5,2,1,2,0,0],
-"struct_ogre_1_1_bullet_1_1_collision_listener.html":[5,1,1,0],
-"struct_ogre_1_1_bullet_1_1_collision_listener.html#a15ed59bda733b6e63d9f28a58ef38b70":[5,1,1,0,0],
-"struct_ogre_1_1_bullet_1_1_collision_listener.html#a59d545c3645540c9cae1b3b945fd1903":[5,1,1,0,1],
-"struct_ogre_1_1_bullet_1_1_ray_result_callback.html":[5,1,1,4],
-"struct_ogre_1_1_bullet_1_1_ray_result_callback.html#a0f521584d3810e3339d886f6c26cae83":[5,1,1,4,1],
-"struct_ogre_1_1_bullet_1_1_ray_result_callback.html#a59e08ca9b439889c9d103d8bdc3e96c8":[5,1,1,4,0],
-"struct_ogre_1_1_colour_blend_state.html":[5,0,5,1],
-"struct_ogre_1_1_colour_blend_state.html#a137130fbfd568631e517597aeebf1c03":[5,0,5,1,11],
-"struct_ogre_1_1_colour_blend_state.html#a13e2c27dc6e21b80f1889d3b99682b16":[5,0,5,1,2],
-"struct_ogre_1_1_colour_blend_state.html#a1a8d5d6033ad996dfadaafdad151e25d":[5,0,5,1,10],
-"struct_ogre_1_1_colour_blend_state.html#a297efc16bd85050690f5de4c992a308b":[5,0,5,1,0],
-"struct_ogre_1_1_colour_blend_state.html#a2a86317b4a9efb0c6b4f3f8fe9ff0fbf":[5,0,5,1,7],
-"struct_ogre_1_1_colour_blend_state.html#a32b83f3be2641efbf6567b7d5aef22be":[5,0,5,1,3],
-"struct_ogre_1_1_colour_blend_state.html#a4c9669f21aa6a880dac5b5380310e6b0":[5,0,5,1,8],
-"struct_ogre_1_1_colour_blend_state.html#a6efce17376a11ea819d298d22580ea6b":[5,0,5,1,9],
-"struct_ogre_1_1_colour_blend_state.html#a782495abb2834f7a5c3585707392c7cb":[5,0,5,1,4],
-"struct_ogre_1_1_colour_blend_state.html#abcd09bd7450bb6acff82033ca357712e":[5,0,5,1,5],
-"struct_ogre_1_1_colour_blend_state.html#acd678d61988d495ed316cd33fbf272fb":[5,0,5,1,1],
-"struct_ogre_1_1_colour_blend_state.html#afcd73a71641f8bb2befcf147fd8bd982":[5,0,5,1,6],
-"struct_ogre_1_1_composition_pass_1_1_input_tex.html":[5,0,1,5,0],
-"struct_ogre_1_1_composition_pass_1_1_input_tex.html#a0c02e4a4e46c29f23af2e5cfdd4e01aa":[5,0,1,5,0,1],
-"struct_ogre_1_1_composition_pass_1_1_input_tex.html#a549645d3640226a6cbd2bdb3d4f29d59":[5,0,1,5,0,2],
-"struct_ogre_1_1_composition_pass_1_1_input_tex.html#a5f5c8dbdb4aabf1584453cefb997ae03":[5,0,1,5,0,0],
-"struct_ogre_1_1_composition_pass_1_1_input_tex.html#afb900befa1a297701c434ccc65d3d810":[5,0,1,5,0,3],
-"struct_ogre_1_1_concrete_node.html":[5,0,10,2],
-"struct_ogre_1_1_concrete_node.html#a444a4c821038a26b6b35aafdf28ca965":[5,0,10,2,2],
-"struct_ogre_1_1_concrete_node.html#a6b1a9325b60739ca145616a86e072e5e":[5,0,10,2,3],
-"struct_ogre_1_1_concrete_node.html#a918a98212eb518a991991c213c261a25":[5,0,10,2,4],
-"struct_ogre_1_1_concrete_node.html#a9b74cccba5209491c73512b95c9ffcc8":[5,0,10,2,0],
-"struct_ogre_1_1_concrete_node.html#aeba3be2d6fb8f7d390e57d38e846bbd7":[5,0,10,2,5],
-"struct_ogre_1_1_concrete_node.html#aec18817ab2fc66791cb2b18d01da9dd5":[5,0,10,2,1],
-"struct_ogre_1_1_config_option.html":[5,0,7,0],
-"struct_ogre_1_1_config_option.html#a0e082b7e9f4874eca45b5634d327e5e9":[5,0,7,0,1],
-"struct_ogre_1_1_config_option.html#a988907fd8dba26120cd9bed5dec0feb0":[5,0,7,0,2],
-"struct_ogre_1_1_config_option.html#aae2b962dbb9f9d21dc6d7d333637478f":[5,0,7,0,3],
-"struct_ogre_1_1_config_option.html#adb16975962ff003cda960713dec7c3bf":[5,0,7,0,0],
-"struct_ogre_1_1_driver_version.html":[5,0,7,5],
-"struct_ogre_1_1_driver_version.html#a25b4560ade1696aca231b4a6db4cbc0b":[5,0,7,5,0],
-"struct_ogre_1_1_driver_version.html#a2a220ab8ccde79520d30871b5453d31f":[5,0,7,5,3],
-"struct_ogre_1_1_driver_version.html#a32143ae51ec5ee29204ea2afe3e851c2":[5,0,7,5,2],
-"struct_ogre_1_1_driver_version.html#a81eb6896cc0c21829f6af65b6913f4cc":[5,0,7,5,4],
-"struct_ogre_1_1_driver_version.html#ac233befea948c74a75aaf937be7f78ec":[5,0,7,5,6],
-"struct_ogre_1_1_driver_version.html#ae3501d20cef0a84769ceacfbf3bae077":[5,0,7,5,1],
-"struct_ogre_1_1_driver_version.html#ae682f3bab912af152cb3f6e8497815f6":[5,0,7,5,5],
-"struct_ogre_1_1_edge_data_1_1_edge.html":[5,0,6,7,0],
-"struct_ogre_1_1_edge_data_1_1_edge.html#a6ba1f2209d1e9014c76c6acc8f626b96":[5,0,6,7,0,0],
-"struct_ogre_1_1_edge_data_1_1_edge.html#a83b46b6487ee08a92449c8698fc8fc11":[5,0,6,7,0,3],
-"struct_ogre_1_1_edge_data_1_1_edge.html#aa04881db8275f906b6209b67f77463ab":[5,0,6,7,0,1],
-"struct_ogre_1_1_edge_data_1_1_edge.html#af8e9e2d2507bd8781c1b34020b4e774a":[5,0,6,7,0,2],
 "struct_ogre_1_1_edge_data_1_1_edge_group.html":[5,0,6,7,1],
 "struct_ogre_1_1_edge_data_1_1_edge_group.html#a1564edb1edb8ee140fd14ee683cae134":[5,0,6,7,1,1],
 "struct_ogre_1_1_edge_data_1_1_edge_group.html#a30fb6c301c0f8cb5ffb940a31a6d6941":[5,0,6,7,1,2],
@@ -151,12 +36,12 @@ var NAVTREEINDEX60 =
 "struct_ogre_1_1_frame_event.html#adf69bb72418f50afcbf5b55ce0745b31":[5,0,2,15,1],
 "struct_ogre_1_1_glyph_info.html":[5,1,3,4],
 "struct_ogre_1_1_glyph_info.html#a0e4668bd868d64c871da6b3941b343d4":[5,1,3,4,6],
+"struct_ogre_1_1_glyph_info.html#a1cd2479f010df597c523081d2d265b0b":[5,1,3,4,1],
 "struct_ogre_1_1_glyph_info.html#a21118e6f23f439e16136ed6473235c7b":[5,1,3,4,4],
-"struct_ogre_1_1_glyph_info.html#a2710a15b88b3ca4037603f406dd489c6":[5,1,3,4,1],
 "struct_ogre_1_1_glyph_info.html#a379cd258ab2dafb4dd5c8f200975be58":[5,1,3,4,5],
 "struct_ogre_1_1_glyph_info.html#a44d4133e5bc5d9dbe59e062dea40daca":[5,1,3,4,2],
-"struct_ogre_1_1_glyph_info.html#a51b8a6953e2d0aa56cc81446fa81b71b":[5,1,3,4,0],
 "struct_ogre_1_1_glyph_info.html#a84b183865a26dd978207ade16075f075":[5,1,3,4,3],
+"struct_ogre_1_1_glyph_info.html#aad869b5e07f3135d09d5ff274e588560":[5,1,3,4,0],
 "struct_ogre_1_1_gpu_constant_definition.html":[5,0,5,4],
 "struct_ogre_1_1_gpu_constant_definition.html#a02052447cbbc9aa02e9ad34f45663f49":[5,0,5,4,20],
 "struct_ogre_1_1_gpu_constant_definition.html#a134c40a7f7baddf559a6a771c0cd9149":[5,0,5,4,5],
@@ -225,16 +110,16 @@ var NAVTREEINDEX60 =
 "struct_ogre_1_1_hardware_buffer_lock_guard.html#acf8b2f43970159df11e417defb4926f1":[5,0,7,8,4],
 "struct_ogre_1_1_hardware_buffer_lock_guard.html#af49d98668e31dad8d1633d7d3e1a4a3c":[5,0,7,8,10],
 "struct_ogre_1_1_i_shader.html":[5,3,6,0],
-"struct_ogre_1_1_i_shader.html#a0c1129f91cdeb70d642c07271861d470":[5,3,6,0,0],
+"struct_ogre_1_1_i_shader.html#a0b125fc17d46188a55e50c481b2138ea":[5,3,6,0,5],
 "struct_ogre_1_1_i_shader.html#a0d2f264bf7c9cb9f5a5084e3c130f9c0":[5,3,6,0,8],
-"struct_ogre_1_1_i_shader.html#a1172aa1a1ffd6c2063c4550bebbb8e21":[5,3,6,0,1],
-"struct_ogre_1_1_i_shader.html#a26bf4694e748958ecb71c258056c5fad":[5,3,6,0,5],
-"struct_ogre_1_1_i_shader.html#a48907afca8f999333b3930be016ad306":[5,3,6,0,3],
+"struct_ogre_1_1_i_shader.html#a584cfe2b463ef4efa26820d510a2bb59":[5,3,6,0,4],
 "struct_ogre_1_1_i_shader.html#a5eefe35cf4dc6d6aa43e5d0143ff4613":[5,3,6,0,7],
-"struct_ogre_1_1_i_shader.html#aaed8f1ebbb5ca0173651058ba6c9d68e":[5,3,6,0,2],
-"struct_ogre_1_1_i_shader.html#ab27d07924d9f6aaf2c68134bccee1fd7":[5,3,6,0,4],
-"struct_ogre_1_1_i_shader.html#ad1736d02f966e027d476403305c3612e":[5,3,6,0,6],
+"struct_ogre_1_1_i_shader.html#aad5e1e072f38959c0099ee102f845dd4":[5,3,6,0,2],
+"struct_ogre_1_1_i_shader.html#acc8b44c27c60167eeafcfec767aa778e":[5,3,6,0,6],
+"struct_ogre_1_1_i_shader.html#acdc190d97b554274d0b9bf401fb95dcd":[5,3,6,0,0],
 "struct_ogre_1_1_i_shader.html#ad74687f65d5b742089e9870c085877b4":[5,3,6,0,9],
+"struct_ogre_1_1_i_shader.html#ae047330cd61af5a36029f8bb74343b42":[5,3,6,0,1],
+"struct_ogre_1_1_i_shader.html#ae7e9c893f16272786ae85c3abdb9427d":[5,3,6,0,3],
 "struct_ogre_1_1_illumination_pass.html":[5,0,5,13],
 "struct_ogre_1_1_illumination_pass.html#a6931df999c8161fb6f91d121b0553577":[5,0,5,13,4],
 "struct_ogre_1_1_illumination_pass.html#ab5f7c941a2c79525fa9077eb358c628b":[5,0,5,13,2],
@@ -249,5 +134,120 @@ var NAVTREEINDEX60 =
 "struct_ogre_1_1_linked_skeleton_animation_source.html#a18367921f5c2e7eddaf14a54dacd3484":[5,0,0,18,2],
 "struct_ogre_1_1_linked_skeleton_animation_source.html#a35b55541c3e931ed3dd7d42ae58d01d2":[5,0,0,18,1],
 "struct_ogre_1_1_linked_skeleton_animation_source.html#a79bb4debcd21595087623b9a8d17d121":[5,0,0,18,4],
-"struct_ogre_1_1_linked_skeleton_animation_source.html#a7a01cb43456b193136f19dd60e9ec7f2":[5,0,0,18,0]
+"struct_ogre_1_1_linked_skeleton_animation_source.html#a7a01cb43456b193136f19dd60e9ec7f2":[5,0,0,18,0],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html":[6,0,1,235,0],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html":[7,0,0,235,0],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a320e05f6a3d088c4fcfee4d2f362acc2":[6,0,1,235,0,6],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a320e05f6a3d088c4fcfee4d2f362acc2":[7,0,0,235,0,6],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a433c84c8a42109d4f1e0987c063b0eee":[6,0,1,235,0,7],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a433c84c8a42109d4f1e0987c063b0eee":[7,0,0,235,0,7],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a5bbe0b22b07477f9c3c85386ddc92ea4":[6,0,1,235,0,3],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a5bbe0b22b07477f9c3c85386ddc92ea4":[7,0,0,235,0,3],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a8f6afddc2684f600eecf1b7e3b54cde2":[6,0,1,235,0,0],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a8f6afddc2684f600eecf1b7e3b54cde2":[7,0,0,235,0,0],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a9260f2150cfaf077b464264a0ed1ff3d":[6,0,1,235,0,5],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a9260f2150cfaf077b464264a0ed1ff3d":[7,0,0,235,0,5],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#acaec158cb30ee047996b3c28014354bf":[6,0,1,235,0,4],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#acaec158cb30ee047996b3c28014354bf":[7,0,0,235,0,4],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#ae5ec1345c756136361e8007598c838c1":[6,0,1,235,0,2],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#ae5ec1345c756136361e8007598c838c1":[7,0,0,235,0,2],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#aea6d9b276a12912bcde04f0d19337485":[6,0,1,235,0,1],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#aea6d9b276a12912bcde04f0d19337485":[7,0,0,235,0,1],
+"struct_ogre_1_1_lod_config.html":[5,1,2,2],
+"struct_ogre_1_1_lod_config.html#a0253402aeaebecece55a8ebf9aa977cd":[5,1,2,2,2],
+"struct_ogre_1_1_lod_config.html#a197e4bbdc17c5645e9775d0ea1863c4d":[5,1,2,2,5],
+"struct_ogre_1_1_lod_config.html#a57f8dbcdf687850f01f904973cab37a9":[5,1,2,2,9],
+"struct_ogre_1_1_lod_config.html#a5e92bc54de6971b64807d83f41532d21":[5,1,2,2,4],
+"struct_ogre_1_1_lod_config.html#a791dec38cc670f9bf9fa1e6ac5230a08":[5,1,2,2,6],
+"struct_ogre_1_1_lod_config.html#a7eecc87589b5a3eacfa363850c2fe4c0":[5,1,2,2,8],
+"struct_ogre_1_1_lod_config.html#a9634e8bfa3c423b7a2ad130f5db9ca61":[5,1,2,2,7],
+"struct_ogre_1_1_lod_config.html#aa70b6cf68e01fe84a5b01fe5af5839da":[5,1,2,2,1],
+"struct_ogre_1_1_lod_config.html#ae2ae0ac3ec6f97efcaeb586dcf3b4d89":[5,1,2,2,3],
+"struct_ogre_1_1_lod_config_1_1_advanced.html":[5,1,2,2,0],
+"struct_ogre_1_1_lod_config_1_1_advanced.html#a170e01ea28652c19ec4d610c0b491ab7":[5,1,2,2,0,2],
+"struct_ogre_1_1_lod_config_1_1_advanced.html#a8aae61afbddb7ac0e5f6666d953b973d":[5,1,2,2,0,8],
+"struct_ogre_1_1_lod_config_1_1_advanced.html#a8ae1db846ff3c2c997313b94f2d9fa65":[5,1,2,2,0,5],
+"struct_ogre_1_1_lod_config_1_1_advanced.html#a9ce3a02176658acb95c60bc98d9c189c":[5,1,2,2,0,7],
+"struct_ogre_1_1_lod_config_1_1_advanced.html#a9f051724cc2c50cb6fc84a749c3bd26f":[5,1,2,2,0,0],
+"struct_ogre_1_1_lod_config_1_1_advanced.html#aa510662a645fab3ef85ef4b1cde1a7a2":[5,1,2,2,0,3],
+"struct_ogre_1_1_lod_config_1_1_advanced.html#ac81a8e65cff66d461b2c884d35662f85":[5,1,2,2,0,6],
+"struct_ogre_1_1_lod_config_1_1_advanced.html#ae3a5b804c168f46fa914f229294a5677":[5,1,2,2,0,4],
+"struct_ogre_1_1_lod_config_1_1_advanced.html#af0b0ebeed034ed3d63ea1bfc3c36fab0":[5,1,2,2,0,1],
+"struct_ogre_1_1_lod_data.html":[5,1,2,3],
+"struct_ogre_1_1_lod_data.html#a038b915656b1f7c6608d018ea6f1b5a3":[5,1,2,3,8],
+"struct_ogre_1_1_lod_data.html#a0d3d22eb6fc67ccab340834fdeeb45d3":[5,1,2,3,11],
+"struct_ogre_1_1_lod_data.html#a0f4bf72e9fc1962cbc394affa672451a":[5,1,2,3,27],
+"struct_ogre_1_1_lod_data.html#a3041597a221fda483795a206a9c8d481":[5,1,2,3,10],
+"struct_ogre_1_1_lod_data.html#a3cb3b991e80bfd68dae64c445b9743ed":[5,1,2,3,22],
+"struct_ogre_1_1_lod_data.html#a41b7354e21e31fdffdbf57a3e2726936":[5,1,2,3,28],
+"struct_ogre_1_1_lod_data.html#a45d49919b94ad00023a4500cc9eaa241":[5,1,2,3,19],
+"struct_ogre_1_1_lod_data.html#a5653fe919222f908f0f66b395ef65f75":[5,1,2,3,14],
+"struct_ogre_1_1_lod_data.html#a5cee720aeb853541d042adb33892b1b8":[5,1,2,3,25],
+"struct_ogre_1_1_lod_data.html#a8e9cd1fac7686aa15718a1b4895dd3ba":[5,1,2,3,17],
+"struct_ogre_1_1_lod_data.html#a912bbcfec3ff16d136a2ccb87e722b39":[5,1,2,3,16],
+"struct_ogre_1_1_lod_data.html#a97a93af607bf6c7fe8729d7032a43ee7":[5,1,2,3,21],
+"struct_ogre_1_1_lod_data.html#a9d0a2e539c50b250ae2ed5e0ca0b5037":[5,1,2,3,24],
+"struct_ogre_1_1_lod_data.html#ad376dfff6935250740314efb5e99f2dd":[5,1,2,3,9],
+"struct_ogre_1_1_lod_data.html#ad3c424670454076e0ebf1d4adc87d104":[5,1,2,3,18],
+"struct_ogre_1_1_lod_data.html#ad442682ce19f3ac65702beb032a7a6df":[5,1,2,3,13],
+"struct_ogre_1_1_lod_data.html#aed7b2a441e826b40396db08b743f9131":[5,1,2,3,15],
+"struct_ogre_1_1_lod_data.html#af59854923d539c6b74be64d67aa05de8":[5,1,2,3,23],
+"struct_ogre_1_1_lod_data.html#af69d67f001e0a9417a9507c6b6fc5581":[5,1,2,3,12],
+"struct_ogre_1_1_lod_data.html#af95ac40c4f3bdd402aa2e0cc1e25fc9c":[5,1,2,3,20],
+"struct_ogre_1_1_lod_data.html#aff7b5cabe66e52756ffc1449b72672ac":[5,1,2,3,26],
+"struct_ogre_1_1_lod_data_1_1_edge.html":[5,1,2,3,0],
+"struct_ogre_1_1_lod_data_1_1_edge.html#a1f456b7ef93c6fdccab8c0ece50affc7":[5,1,2,3,0,3],
+"struct_ogre_1_1_lod_data_1_1_edge.html#a3ec40b83d91916a437b48d4e8d0c4bbb":[5,1,2,3,0,6],
+"struct_ogre_1_1_lod_data_1_1_edge.html#a6f27dffeccc65f1157b1e483bdfdfc05":[5,1,2,3,0,4],
+"struct_ogre_1_1_lod_data_1_1_edge.html#a6fc99de5e3b82dcba93ed93ce2ec9ec3":[5,1,2,3,0,5],
+"struct_ogre_1_1_lod_data_1_1_edge.html#a7107dc42d825d379eddfa1e972e22a0b":[5,1,2,3,0,1],
+"struct_ogre_1_1_lod_data_1_1_edge.html#a7e0e58962a7fe713743728f63a5b39db":[5,1,2,3,0,7],
+"struct_ogre_1_1_lod_data_1_1_edge.html#aef1383c820c467af702932fb8d4e08a9":[5,1,2,3,0,2],
+"struct_ogre_1_1_lod_data_1_1_edge.html#af59b284615ca330d7879fec720b15144":[5,1,2,3,0,0],
+"struct_ogre_1_1_lod_data_1_1_index_buffer_info.html":[5,1,2,3,1],
+"struct_ogre_1_1_lod_data_1_1_index_buffer_info.html#a26a533a653b8980db708a5931791d961":[5,1,2,3,1,4],
+"struct_ogre_1_1_lod_data_1_1_index_buffer_info.html#abf8765f39f6483c12cb4d25fbeefd01a":[5,1,2,3,1,0],
+"struct_ogre_1_1_lod_data_1_1_index_buffer_info.html#acdb48ad8eaf66458a090c37b805a22be":[5,1,2,3,1,2],
+"struct_ogre_1_1_lod_data_1_1_index_buffer_info.html#ace8f068f6f7d83cf1ae6dd0a92b26ee6":[5,1,2,3,1,1],
+"struct_ogre_1_1_lod_data_1_1_index_buffer_info.html#aef789e3ea55d0d890f1de9434d36a449":[5,1,2,3,1,3],
+"struct_ogre_1_1_lod_data_1_1_line.html":[5,1,2,3,3],
+"struct_ogre_1_1_lod_data_1_1_line.html#a6c8c2f0378dfce136a5b6e79e49f14cc":[5,1,2,3,3,5],
+"struct_ogre_1_1_lod_data_1_1_line.html#a9d5d9481ebf1384d3b1e7ee066a3768e":[5,1,2,3,3,3],
+"struct_ogre_1_1_lod_data_1_1_line.html#aa3e7051195f159e7a4ad8cfccb7e2f5b":[5,1,2,3,3,4],
+"struct_ogre_1_1_lod_data_1_1_line.html#aab02955a79f8ffb4676372031882fe79":[5,1,2,3,3,2],
+"struct_ogre_1_1_lod_data_1_1_line.html#abb571b93d022eacae313686662ac79d7":[5,1,2,3,3,1],
+"struct_ogre_1_1_lod_data_1_1_line.html#afff2de53d66875fc01c9815971dab96d":[5,1,2,3,3,6],
+"struct_ogre_1_1_lod_data_1_1_line.html#afff4d1507e0433c6cec166f00538e29c":[5,1,2,3,3,0],
+"struct_ogre_1_1_lod_data_1_1_triangle.html":[5,1,2,3,4],
+"struct_ogre_1_1_lod_data_1_1_triangle.html#a4eecf20b323ee21ea4c31a09abe54cd0":[5,1,2,3,4,7],
+"struct_ogre_1_1_lod_data_1_1_triangle.html#a4fbb1fc10853e3adc0116c3f5660487e":[5,1,2,3,4,0],
+"struct_ogre_1_1_lod_data_1_1_triangle.html#a5987bfe02a3d1aa1eb732a8a019558a9":[5,1,2,3,4,2],
+"struct_ogre_1_1_lod_data_1_1_triangle.html#a7f2b4a5ba3690ab520e445918935e525":[5,1,2,3,4,1],
+"struct_ogre_1_1_lod_data_1_1_triangle.html#ab43218cda5bc70a6c6e5f084a1a5ec7b":[5,1,2,3,4,3],
+"struct_ogre_1_1_lod_data_1_1_triangle.html#ac177a86ec820bd4bdf9ab1578132885e":[5,1,2,3,4,5],
+"struct_ogre_1_1_lod_data_1_1_triangle.html#ad3d2f1e41bdf70e19007938074b2cf0e":[5,1,2,3,4,6],
+"struct_ogre_1_1_lod_data_1_1_triangle.html#af4011d8be274ea62d50b8f8ef5eb89a6":[5,1,2,3,4,4],
+"struct_ogre_1_1_lod_data_1_1_triangle.html#aff1395c324d8808f43dcc76b8a5cdb3b":[5,1,2,3,4,8],
+"struct_ogre_1_1_lod_data_1_1_vertex.html":[5,1,2,3,5],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#a0f4e1115ab3949faaf58aff5b08b1cd9":[5,1,2,3,5,9],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#a2dd4f26fe6707cac4b003f727271ff5e":[5,1,2,3,5,8],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#a30e6002e8806af7c72eb4dc97d8806f2":[5,1,2,3,5,6],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#a4df65828c129283e5430d3c5df18d33d":[5,1,2,3,5,2],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#a54d42759d6ab25e25bd52d34a7e656c6":[5,1,2,3,5,5],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#a613e76486834495df006789d8824210b":[5,1,2,3,5,7],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#a6f356c0b5a1a3dcc5f999be8cc977fe0":[5,1,2,3,5,4],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#a94742e7f49c5ffdfb8fca2b1bff798bb":[5,1,2,3,5,0],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#aaa8e2eecfc5912d6958e65ecdf12d053":[5,1,2,3,5,1],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#ae45e43886c93e953d78cda1d84501ad5":[5,1,2,3,5,3],
+"struct_ogre_1_1_lod_data_1_1_vertex_equal.html":[5,1,2,3,6],
+"struct_ogre_1_1_lod_data_1_1_vertex_equal.html#a3cdf3e47024745b729a4801e1c5a924a":[5,1,2,3,6,0],
+"struct_ogre_1_1_lod_data_1_1_vertex_hash.html":[5,1,2,3,7],
+"struct_ogre_1_1_lod_data_1_1_vertex_hash.html#a2a0bae6ff8fab851d848fb8c225673b8":[5,1,2,3,7,0],
+"struct_ogre_1_1_lod_data_1_1_vertex_hash.html#a855695516ff2d3f0f8547150e0230e08":[5,1,2,3,7,2],
+"struct_ogre_1_1_lod_data_1_1_vertex_hash.html#aa103133087a79ad877cfe4a50f12af22":[5,1,2,3,7,1],
+"struct_ogre_1_1_lod_data_1_1_vertex_hash.html#aae427738b413ac6e1b2e040cc49760d6":[5,1,2,3,7,3],
+"struct_ogre_1_1_lod_level.html":[5,1,2,4],
+"struct_ogre_1_1_lod_level.html#a10d85c3d0d1f9a03019a9abc76cf70d1":[5,1,2,4,3],
+"struct_ogre_1_1_lod_level.html#a39e40bdcbeea13357ace7e38e53446e3":[5,1,2,4,0],
+"struct_ogre_1_1_lod_level.html#a39e40bdcbeea13357ace7e38e53446e3a484813e3eee23b35e7377eb8f225c9c4":[5,1,2,4,0,2]
 };
