@@ -3,6 +3,5 @@ var searchData=
   ['deferred_20shading_0',['Deferred Shading',['../deferred.html',1,'tutorials']]],
   ['definition_20scripts_1',['Font Definition Scripts',['../_font-_definition-_scripts.html',1,'Scripts']]],
   ['deprecated_20list_2',['Deprecated List',['../deprecated.html',1,'']]],
-  ['depth_3',['Reversed Depth',['../reversed-depth.html',1,'tutorials']]],
-  ['dotscene_20overview_4',['DotScene Overview',['../dotscene_overview.html',1,'tutorials']]]
+  ['depth_3',['Reversed Depth',['../reversed-depth.html',1,'tutorials']]]
 ];
