@@ -4,6 +4,5 @@ var searchData=
   ['ogre_1',['Guide to building OGRE',['../building-ogre.html',1,'tutorials']]],
   ['ogre_2',['Shadow Mapping in Ogre',['../_shadow_mapping_ogre.html',1,'tutorials']]],
   ['ogre_20project_3',['Setting up an OGRE project',['../setup.html',1,'tutorials']]],
-  ['overlay_20scripts_4',['Overlay Scripts',['../_overlay-_scripts.html',1,'Scripts']]],
-  ['overview_5',['DotScene Overview',['../dotscene_overview.html',1,'tutorials']]]
+  ['overlay_20scripts_4',['Overlay Scripts',['../_overlay-_scripts.html',1,'Scripts']]]
 ];
