@@ -1,33 +1,33 @@
 var tutorials =
 [
     [ "Guide to building OGRE", "building-ogre.html", [
-      [ "What is CMake?", "building-ogre.html#autotoc_md260", null ],
-      [ "Preparing the build environment", "building-ogre.html#autotoc_md261", null ],
-      [ "Getting dependencies", "building-ogre.html#autotoc_md262", [
-        [ "Linux", "building-ogre.html#autotoc_md263", null ],
-        [ "Recommended dependencies", "building-ogre.html#autotoc_md264", null ],
-        [ "Optional dependencies", "building-ogre.html#autotoc_md265", null ],
-        [ "Deprecated dependencies", "building-ogre.html#autotoc_md266", null ]
+      [ "What is CMake?", "building-ogre.html#autotoc_md259", null ],
+      [ "Preparing the build environment", "building-ogre.html#autotoc_md260", null ],
+      [ "Getting dependencies", "building-ogre.html#autotoc_md261", [
+        [ "Linux", "building-ogre.html#autotoc_md262", null ],
+        [ "Recommended dependencies", "building-ogre.html#autotoc_md263", null ],
+        [ "Optional dependencies", "building-ogre.html#autotoc_md264", null ],
+        [ "Deprecated dependencies", "building-ogre.html#autotoc_md265", null ]
       ] ],
       [ "Running CMake", "building-ogre.html#running-cmake", null ],
-      [ "Building", "building-ogre.html#autotoc_md267", null ],
+      [ "Building", "building-ogre.html#autotoc_md266", null ],
       [ "Installing", "building-ogre.html#installing-sdk", null ],
-      [ "Installing and building via vcpkg", "building-ogre.html#autotoc_md268", null ],
-      [ "Cross-Compiling", "building-ogre.html#autotoc_md269", [
-        [ "Android", "building-ogre.html#autotoc_md270", null ],
-        [ "WebAssembly / Emscripten", "building-ogre.html#autotoc_md271", null ],
-        [ "iOS OS", "building-ogre.html#autotoc_md272", null ],
-        [ "WinRT / UWP", "building-ogre.html#autotoc_md273", null ]
+      [ "Installing and building via vcpkg", "building-ogre.html#autotoc_md267", null ],
+      [ "Cross-Compiling", "building-ogre.html#autotoc_md268", [
+        [ "Android", "building-ogre.html#autotoc_md269", null ],
+        [ "WebAssembly / Emscripten", "building-ogre.html#autotoc_md270", null ],
+        [ "iOS OS", "building-ogre.html#autotoc_md271", null ],
+        [ "WinRT / UWP", "building-ogre.html#autotoc_md272", null ]
       ] ]
     ] ],
     [ "Setting up an OGRE project", "setup.html", [
       [ "CMake Configuration", "setup.html#cmake", null ],
       [ "Application skeleton", "setup.html#skeleton", null ],
       [ "Running your App", "setup.html#setupRunning", [
-        [ "Configuration Files", "setup.html#autotoc_md308", [
-          [ "plugins.cfg", "setup.html#autotoc_md309", null ],
-          [ "resources.cfg", "setup.html#autotoc_md310", null ],
-          [ "ogre.cfg", "setup.html#autotoc_md311", null ]
+        [ "Configuration Files", "setup.html#autotoc_md307", [
+          [ "plugins.cfg", "setup.html#autotoc_md308", null ],
+          [ "resources.cfg", "setup.html#autotoc_md309", null ],
+          [ "ogre.cfg", "setup.html#autotoc_md310", null ]
         ] ]
       ] ]
     ] ],
@@ -92,28 +92,28 @@ var tutorials =
     [ "Trays GUI System", "trays.html", [
       [ "Trays", "trays.html#trays-1", null ],
       [ "TrayManager", "trays.html#traymanager", [
-        [ "The Cursor", "trays.html#autotoc_md316", null ],
-        [ "The Backdrop", "trays.html#autotoc_md317", null ]
+        [ "The Cursor", "trays.html#autotoc_md315", null ],
+        [ "The Backdrop", "trays.html#autotoc_md316", null ]
       ] ],
       [ "Widgets", "trays.html#widgets", [
-        [ "Button", "trays.html#autotoc_md318", null ],
-        [ "TextBox", "trays.html#autotoc_md319", null ],
-        [ "SelectMenu", "trays.html#autotoc_md320", null ],
-        [ "Label", "trays.html#autotoc_md321", null ],
-        [ "Separator", "trays.html#autotoc_md322", null ],
-        [ "Slider", "trays.html#autotoc_md323", null ],
-        [ "ParamsPanel", "trays.html#autotoc_md324", null ],
-        [ "CheckBox", "trays.html#autotoc_md325", null ],
-        [ "DecorWidget", "trays.html#autotoc_md326", null ],
-        [ "ProgressBar", "trays.html#autotoc_md327", null ],
-        [ "The Null Tray", "trays.html#autotoc_md328", null ]
+        [ "Button", "trays.html#autotoc_md317", null ],
+        [ "TextBox", "trays.html#autotoc_md318", null ],
+        [ "SelectMenu", "trays.html#autotoc_md319", null ],
+        [ "Label", "trays.html#autotoc_md320", null ],
+        [ "Separator", "trays.html#autotoc_md321", null ],
+        [ "Slider", "trays.html#autotoc_md322", null ],
+        [ "ParamsPanel", "trays.html#autotoc_md323", null ],
+        [ "CheckBox", "trays.html#autotoc_md324", null ],
+        [ "DecorWidget", "trays.html#autotoc_md325", null ],
+        [ "ProgressBar", "trays.html#autotoc_md326", null ],
+        [ "The Null Tray", "trays.html#autotoc_md327", null ]
       ] ],
       [ "Special Widgets", "trays.html#special-widgets", [
-        [ "Frame Stats", "trays.html#autotoc_md329", null ],
-        [ "Logo", "trays.html#autotoc_md330", null ],
-        [ "Loading Bar", "trays.html#autotoc_md331", null ],
-        [ "Information Dialog", "trays.html#autotoc_md332", null ],
-        [ "Question Dialog", "trays.html#autotoc_md333", null ]
+        [ "Frame Stats", "trays.html#autotoc_md328", null ],
+        [ "Logo", "trays.html#autotoc_md329", null ],
+        [ "Loading Bar", "trays.html#autotoc_md330", null ],
+        [ "Information Dialog", "trays.html#autotoc_md331", null ],
+        [ "Question Dialog", "trays.html#autotoc_md332", null ]
       ] ],
       [ "TrayListener", "trays.html#tray-listener", null ],
       [ "Things to Try", "trays.html#things-to-try", null ]
@@ -129,38 +129,29 @@ var tutorials =
       [ "How to use it for non-programmers", "meshlod-generator.html#meshlod-nonprog", null ],
       [ "How to use it for programmers", "meshlod-generator.html#meshlod-prog", null ],
       [ "Extending MeshLodGenerator", "meshlod-generator.html#meshlod-extend", [
-        [ "Replacing a component", "meshlod-generator.html#autotoc_md302", null ]
-      ] ]
-    ] ],
-    [ "DotScene Overview", "dotscene_overview.html", [
-      [ "What is DotScene?", "dotscene_overview.html#autotoc_md9", null ],
-      [ "User Data", "dotscene_overview.html#autotoc_md10", null ],
-      [ "How to use DotScene", "dotscene_overview.html#autotoc_md11", null ],
-      [ "Instancing", "dotscene_overview.html#autotoc_md12", [
-        [ "Static Geometry", "dotscene_overview.html#autotoc_md13", null ],
-        [ "Instance Manager", "dotscene_overview.html#autotoc_md14", null ]
+        [ "Replacing a component", "meshlod-generator.html#autotoc_md301", null ]
       ] ]
     ] ],
     [ "Manual mesh creation", "manual-mesh-creation.html", [
-      [ "Using Manual Object", "manual-mesh-creation.html#autotoc_md299", [
-        [ "Example", "manual-mesh-creation.html#autotoc_md300", null ]
+      [ "Using Manual Object", "manual-mesh-creation.html#autotoc_md298", [
+        [ "Example", "manual-mesh-creation.html#autotoc_md299", null ]
       ] ],
-      [ "Using vertex and index buffers directly", "manual-mesh-creation.html#autotoc_md301", null ]
+      [ "Using vertex and index buffers directly", "manual-mesh-creation.html#autotoc_md300", null ]
     ] ],
     [ "Static Geometry", "tut__static_geom.html", [
-      [ "Blades of grass", "tut__static_geom.html#autotoc_md312", null ],
-      [ "A field of grass", "tut__static_geom.html#autotoc_md313", null ],
-      [ "Animating StaticGeometry", "tut__static_geom.html#autotoc_md314", null ],
-      [ "Advanced Object Batching", "tut__static_geom.html#autotoc_md315", null ]
+      [ "Blades of grass", "tut__static_geom.html#autotoc_md311", null ],
+      [ "A field of grass", "tut__static_geom.html#autotoc_md312", null ],
+      [ "Animating StaticGeometry", "tut__static_geom.html#autotoc_md313", null ],
+      [ "Advanced Object Batching", "tut__static_geom.html#autotoc_md314", null ]
     ] ],
     [ "Using the Profiler", "profiler.html", [
       [ "Reading the Display", "profiler.html#profRead", null ],
       [ "Features", "profiler.html#profFeatures", [
-        [ "Disabling the Profiler", "profiler.html#autotoc_md303", null ],
-        [ "Disabling Individual Profiles", "profiler.html#autotoc_md304", null ],
-        [ "Analyzing Application State", "profiler.html#autotoc_md305", null ],
-        [ "Logging Results", "profiler.html#autotoc_md306", null ],
-        [ "Changing the Frequency of Updating the Display", "profiler.html#autotoc_md307", null ]
+        [ "Disabling the Profiler", "profiler.html#autotoc_md302", null ],
+        [ "Disabling Individual Profiles", "profiler.html#autotoc_md303", null ],
+        [ "Analyzing Application State", "profiler.html#autotoc_md304", null ],
+        [ "Logging Results", "profiler.html#autotoc_md305", null ],
+        [ "Changing the Frequency of Updating the Display", "profiler.html#autotoc_md306", null ]
       ] ],
       [ "Performance and Accuracy", "profiler.html#profAccuracy", null ],
       [ "Remotery Backend", "profiler.html#profRemotery", null ],
@@ -168,11 +159,11 @@ var tutorials =
     ] ],
     [ "Reversed Depth", "reversed-depth.html", null ],
     [ "External Texture Sources", "_external-_texture-_sources.html", [
-      [ "What Is An External Texture Source?", "_external-_texture-_sources.html#autotoc_md294", null ],
-      [ "ExternalTextureSource Class", "_external-_texture-_sources.html#autotoc_md295", null ],
-      [ "ExternalTextureSourceManager Class", "_external-_texture-_sources.html#autotoc_md296", null ],
-      [ "Texture Source Material Script", "_external-_texture-_sources.html#autotoc_md297", null ],
-      [ "Simplified Diagram of Process", "_external-_texture-_sources.html#autotoc_md298", null ]
+      [ "What Is An External Texture Source?", "_external-_texture-_sources.html#autotoc_md293", null ],
+      [ "ExternalTextureSource Class", "_external-_texture-_sources.html#autotoc_md294", null ],
+      [ "ExternalTextureSourceManager Class", "_external-_texture-_sources.html#autotoc_md295", null ],
+      [ "Texture Source Material Script", "_external-_texture-_sources.html#autotoc_md296", null ],
+      [ "Simplified Diagram of Process", "_external-_texture-_sources.html#autotoc_md297", null ]
     ] ],
     [ "Background Resource Loading", "background-resource.html", null ],
     [ "Shadow Mapping in Ogre", "_shadow_mapping_ogre.html", [
@@ -200,48 +191,39 @@ var tutorials =
     ] ],
     [ "Deferred Shading", "deferred.html", [
       [ "What is Deferred Shading?", "deferred.html#what", [
-        [ "Deferred Shading Advantages", "deferred.html#autotoc_md274", null ],
-        [ "Deferred Shading Disadvantages", "deferred.html#autotoc_md275", null ]
+        [ "Deferred Shading Advantages", "deferred.html#autotoc_md273", null ],
+        [ "Deferred Shading Disadvantages", "deferred.html#autotoc_md274", null ]
       ] ],
       [ "Creating the G-Buffer", "deferred.html#creating", [
-        [ "Deciding on the GBuffer format", "deferred.html#autotoc_md276", null ],
-        [ "Preparing the objects for G-Buffer rendering", "deferred.html#autotoc_md277", [
-          [ "Inspect the classic technique", "deferred.html#autotoc_md278", null ],
-          [ "Generate the G-Buffer technique", "deferred.html#autotoc_md279", null ],
-          [ "Add the G-Buffer technique to the original material", "deferred.html#autotoc_md280", null ],
-          [ "Putting it all together", "deferred.html#autotoc_md281", null ]
+        [ "Deciding on the GBuffer format", "deferred.html#autotoc_md275", null ],
+        [ "Preparing the objects for G-Buffer rendering", "deferred.html#autotoc_md276", [
+          [ "Inspect the classic technique", "deferred.html#autotoc_md277", null ],
+          [ "Generate the G-Buffer technique", "deferred.html#autotoc_md278", null ],
+          [ "Add the G-Buffer technique to the original material", "deferred.html#autotoc_md279", null ],
+          [ "Putting it all together", "deferred.html#autotoc_md280", null ]
         ] ],
-        [ "Overriding the automatic process", "deferred.html#autotoc_md282", null ],
-        [ "Seeing it in action", "deferred.html#autotoc_md283", null ]
+        [ "Overriding the automatic process", "deferred.html#autotoc_md281", null ],
+        [ "Seeing it in action", "deferred.html#autotoc_md282", null ]
       ] ],
-      [ "Lighting the scene", "deferred.html#autotoc_md284", [
+      [ "Lighting the scene", "deferred.html#autotoc_md283", [
         [ "Rendering the light geometry", "deferred.html#lightgeom", [
-          [ "Prepare ambient colour and rebuild original depth buffer", "deferred.html#autotoc_md285", null ],
-          [ "Render the light geometries", "deferred.html#autotoc_md286", null ],
-          [ "Rendering shadow casting lights", "deferred.html#autotoc_md287", null ],
-          [ "Putting it all together", "deferred.html#autotoc_md288", null ],
-          [ "Seeing it in action", "deferred.html#autotoc_md289", null ]
+          [ "Prepare ambient colour and rebuild original depth buffer", "deferred.html#autotoc_md284", null ],
+          [ "Render the light geometries", "deferred.html#autotoc_md285", null ],
+          [ "Rendering shadow casting lights", "deferred.html#autotoc_md286", null ],
+          [ "Putting it all together", "deferred.html#autotoc_md287", null ],
+          [ "Seeing it in action", "deferred.html#autotoc_md288", null ]
         ] ]
       ] ],
       [ "Post Processing", "deferred.html#post", [
-        [ "Screen Space Ambient Occlusion", "deferred.html#autotoc_md290", null ]
+        [ "Screen Space Ambient Occlusion", "deferred.html#autotoc_md289", null ]
       ] ],
       [ "Integration in real projects", "deferred.html#realprojects", [
-        [ "Integration steps", "deferred.html#autotoc_md291", null ],
-        [ "Adapting the framework", "deferred.html#autotoc_md292", null ],
-        [ "Adding features to the framework", "deferred.html#autotoc_md293", null ]
+        [ "Integration steps", "deferred.html#autotoc_md290", null ],
+        [ "Adapting the framework", "deferred.html#autotoc_md291", null ],
+        [ "Adding features to the framework", "deferred.html#autotoc_md292", null ]
       ] ],
       [ "Summary", "deferred.html#summary", [
         [ "Further reading", "deferred.html#further", null ]
       ] ]
-    ] ],
-    [ "Using the PCZ Scene Manager", "pczscenemanager.html", [
-      [ "LOADING & INITIALIZATION", "pczscenemanager.html#autotoc_md2", null ],
-      [ "CREATING ZONES", "pczscenemanager.html#autotoc_md3", null ],
-      [ "CREATING PORTALS", "pczscenemanager.html#autotoc_md4", null ],
-      [ "ANTIPORTALS", "pczscenemanager.html#autotoc_md5", null ],
-      [ "CREATING OBJECTS/ENTITIES", "pczscenemanager.html#autotoc_md6", null ],
-      [ "SCENE QUERIES", "pczscenemanager.html#autotoc_md7", null ],
-      [ "KNOWN BUGS", "pczscenemanager.html#autotoc_md8", null ]
     ] ]
 ];
\ No newline at end of file
